@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ *  copyright : (C) 2003 - 2010 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -39,19 +39,63 @@
  */
 
 
+
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+#include <string.h>
+#include <pthread.h>
+#include <stdlib.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <alsa/asoundlib.h>
+
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
+#include "global.h"
 #include "alsa_audio.h"
 
 
 
 
-VAR_ALSA VarAlsa;
-
+VAR_ALSA VarAlsa = {
+	NULL,		// snd_pcm_t	*playback_handle;			// Handle
+	0,		// guint	bytesPerFrame;				// 8, 16, 24, 32, 64 ...
+	0,		// guint	channels;				// 1, 2, 4 ...
+	0,		// gint		SampleRate;				// Frequence: 44100 ...
+	0,		// gint		TotalChunckSize;			// 
+	NULL,		// guchar	*buffer;				// Pointeur de buffer
+	0,		// guint	SizeBuffer;				// Taille requise du buffer
+	0,		// gint		Sec;					// Duree total en secondes
+	0.0,		// gdouble	Percent;				// Poucentage en retour sur la duree total
+	0.0,		// gdouble	PercentSel;				// Poucentage en retour depuis la selection
+	
+	0.0,		// gdouble	PercentBegin;				// 
+	0.0,		// gdouble	PercentEnd;				// 
+	
+	FALSE,		// gboolean	BoolThreadEnd;				// 
+	0,		// guint	HandlerTimeout;				// 
+	
+	TRUE,		// gboolean	StopPlay;				// 
+	TRUE,		// gboolean	PauseAlsa;				// 
+	NULL,		// void		(*FuncSetValueTime) (gdouble p_value);	// 
+	NULL,		// void		(*FuncIconeStop) (void);		// 
+	
+	NULL		// FILE		*pFile;					// Handler du fichier ouvert
+};
 
 
 void AlsaAudio_close_device (void)
@@ -103,9 +147,9 @@ gboolean AlsaAudio_write(int size)
 gboolean AlsaAudio_open_device(
 	const gchar *audio_dev,		// "default"
 	gint p_bitsPerSample,		// 8, 16, 24, ...
-	gint p_channels,			// 1, 2, 4, , ...
-	guint p_samplesPerSec,	// 44100, ...
-	guint *p_bufferSize	// Taille buffer retournee
+	gint p_channels,		// 1, 2, 4, , ...
+	guint p_samplesPerSec,		// 44100, ...
+	guint *p_bufferSize		// Taille buffer retournee
 	)
 {
 	gint err;
@@ -120,18 +164,30 @@ gboolean AlsaAudio_open_device(
 	guint buffer_time = 500000;         /* ring buffer length in us */
 	guint period_time = 100000;         /* period time in us */
 
+	VarAlsa.bytesPerFrame = 2;
 	format = SND_PCM_FORMAT_S16_LE;
 
-	if (p_bitsPerSample == 16) {
-		VarAlsa.bytesPerFrame = 2;
-		format = SND_PCM_FORMAT_S16_LE;
-	} else if (p_bitsPerSample == 8) {
+	if (p_bitsPerSample == 8) {
 		VarAlsa.bytesPerFrame = 1;
 		format = SND_PCM_FORMAT_U8;
-	} else if (p_bitsPerSample == 24) {
+	}
+	else if (p_bitsPerSample == 16) {
+		VarAlsa.bytesPerFrame = 2;
+		format = SND_PCM_FORMAT_S16_LE;
+	}
+	else if (p_bitsPerSample == 24) {
 		VarAlsa.bytesPerFrame = 3;
 		format = SND_PCM_FORMAT_S24_3LE;
 	}
+	else if (p_bitsPerSample == 32) {
+		VarAlsa.bytesPerFrame = 4;
+		format = SND_PCM_FORMAT_S32;
+	}
+	else {
+		PRINT_FUNC_LF();
+		g_print("Format de bitrate [ %d ] non prit en charge\n", p_bitsPerSample);
+		return (FALSE);	
+	}
 	
 	VarAlsa.SampleRate = p_samplesPerSec;
 	rate = p_samplesPerSec;
