@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ *  copyright : (C) 2003 - 2010 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -46,26 +46,29 @@
 #include <alsa/asoundlib.h>
 
 typedef struct {
-	snd_pcm_t	*playback_handle;	// Handle
-	guint		bytesPerFrame;		// 8, 16, 24, 32, 64 ...
-	guint		channels;		// 1, 2, 4 ...
-	gint		SampleRate;		// Frequence: 44100 ...
-	gint		TotalChunckSize;	// 
-	guchar		*buffer;		// Pointeur de buffer
-	guint		SizeBuffer;		// Taille requise du buffer
-	gint		Sec;			// Duree total en secondes
-	gdouble		Percent;		// Poucentage en retour sur la duree total
-	gdouble		PercentSel;		// Poucentage en retour depuis la selection
+	snd_pcm_t	*playback_handle;			// Handle
+	guint		bytesPerFrame;				// 8, 16, 24, 32, 64 ...
+	guint		channels;				// 1, 2, 4 ...
+	gint		SampleRate;				// Frequence: 44100 ...
+	gint		TotalChunckSize;			// 
+	guchar		*buffer;				// Pointeur de buffer
+	guint		SizeBuffer;				// Taille requise du buffer
+	gint		Sec;					// Duree total en secondes
+	gdouble		Percent;				// Poucentage en retour sur la duree total
+	gdouble		PercentSel;				// Poucentage en retour depuis la selection
 	
-	gdouble		PercentBegin;		// 
-	gdouble		PercentEnd;		// 
+	gdouble		PercentBegin;				// 
+	gdouble		PercentEnd;				// 
 	
-	gboolean	BoolThreadEnd;		// 
-	guint		HandlerTimeout;		// 
+	gboolean	BoolThreadEnd;				// 
+	guint		HandlerTimeout;				// 
 	
-	gboolean	StopPlay;		// 
+	gboolean	StopPlay;				// 
+	gboolean	PauseAlsa;				// 
+	void		(*FuncSetValueTime) (gdouble p_value);	// 
+	void		(*FuncIconeStop) (void);		// 
 	
-	FILE		*pFile;			// Handler du fichier ouvert
+	FILE		*pFile;					// Handler du fichier ouvert
 } VAR_ALSA;
 
 extern VAR_ALSA VarAlsa;
@@ -73,9 +76,9 @@ extern VAR_ALSA VarAlsa;
 void     AlsaAudio_close_device (void);
 gboolean AlsaAudio_open_device (const gchar *audio_dev,		// default
 				gint p_bitsPerSample,		// 8, 16, 24, ...
-				gint p_channels,			// 1, 2, 4, ...
-				guint p_samplesPerSec,	// 44100, ...
-				guint *p_bufferSize);	// Taille buffer retournee
+				gint p_channels,		// 1, 2, 4, ...
+				guint p_samplesPerSec,		// 44100, ...
+				guint *p_bufferSize);		// Taille buffer retournee
 gboolean AlsaAudio_write (gint size);
 
 
