@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __cd_audio_extract_h__
-#define __cd_audio_extract_h__ 1
+#ifndef cd_audio_extract_h
+#define cd_audio_extract_h 1
 
 
 void cdaudioextract_extraction_cd_to_file_action (void);
