@@ -31,29 +31,34 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-
 #include <string.h>
 #include <string.h>
 #include <stdlib.h>
 
-#include "utils.h"
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "secu.h"
 #include "cd_audio.h"
 #include "cdtoc.h"
-#include "get.h"
-#include "scan_cd.h"
+#include "get_info.h"
+#include "scan.h"
+#include "configuser.h"
 #include "cd_cue.h"
-#include "options.h"
-#include "config_user.h"
-#include "win_info.h"
-#include "win_choice.h"
+
 
 
 
@@ -70,11 +75,14 @@ BASE_IOCTL BaseIoctl = { 0, NULL, NULL, NULL, NULL, NULL };
 
 
 
+// 
+// 
 gboolean cdcue_is_alloc (void)
 {
 	return ((BaseIoctl.Cue == NULL) ? FALSE : TRUE);
 }
-
+// 
+// 
 gint cdcue_get_total_tracks (gchar *buffer)
 {
 	gchar  **Larrbuf = NULL;
@@ -95,7 +103,8 @@ gint cdcue_get_total_tracks (gchar *buffer)
 	g_strfreev(Larrbuf);
 	return (piste);
 }
-
+// 
+// 
 void cdcue_make_cue_with_cdtoc (CD_TOC *CdToc)
 {
 	gint	i;
@@ -174,8 +183,8 @@ void cdcue_make_cue_with_cdtoc (CD_TOC *CdToc)
 	g_free (Title);
 	Title = NULL;
 }
-
-
+// 
+// 
 void cdcue_remove_base_ioctl (void)
 {
 	BaseIoctl.TotalTracks = 0;
@@ -200,7 +209,8 @@ void cdcue_remove_base_ioctl (void)
 		BaseIoctl.Cue = NULL;
 	}
 }
-
+// 
+// 
 void cdcue_alloc_base_ioctl (gint p_taille)
 {
 	gint	index;
@@ -216,12 +226,14 @@ void cdcue_alloc_base_ioctl (gint p_taille)
 	for (index = 0; index < p_taille; index ++)
 		BaseIoctl.Cue [ index ].BoolExtract = FALSE;
 }
-
+// 
+// 
 void cdcue_set_BoolExtract (gint p_index, gboolean p_flag)
 {
 	BaseIoctl.Cue [ p_index ].BoolExtract = p_flag;
 }
-
+// 
+// 
 void cdcue_print_base_ioctl (void)
 {
 	gint   base;
@@ -282,7 +294,8 @@ void cdcue_print_base_ioctl (void)
 			BaseIoctl.Datas[ BaseIoctl.TotalTracks ].begin_cent);
 	g_print("\n\n");
 }
-
+// 
+// 
 void cdcue_set_base_ioctl (gchar *p_buffer,	/* Lerr			*/
 			   gint p_TotalTracks)	/* CdToc->TotalTracks	*/
 {
@@ -384,8 +397,8 @@ void cdcue_set_base_ioctl (gchar *p_buffer,	/* Lerr			*/
 		cdcue_print_base_ioctl ();
 	}
 }
-			   
-
+// 
+// 
 void cdcue_make_cue (void)
 {
 	gint	piste;
@@ -414,14 +427,15 @@ void cdcue_make_cue (void)
 		}
 	}
 }
-
+// 
+// 
 void cdcue_write_cue_ok (void)
 {
 	gint	 piste;
 	gchar	*PathName = NULL;
 	FILE	*fp;
 	
-	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config_User.Path_Destination_CD, BaseIoctl.Performer);
+	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, BaseIoctl.Performer);
 	
 	PRINT("Production du fichier");
 
@@ -456,11 +470,12 @@ g_print ("    INDEX 01 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].DMin, BaseIoct
 	/* FIN de creation CUE-FILE */
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 }
-
 /* ADD == 0 : no change
    ADD == 1 : + 3 secondes
    ADD == 2 : - 3 secondes
 */
+// 
+// 
 void cdcue_calcul_start (gint piste, gint Add)
 {
 	gint	 TempDiv = 0;
@@ -482,7 +497,6 @@ void cdcue_calcul_start (gint piste, gint Add)
 	BaseIoctl.Cue [ piste ].CuePartiel.StartSec  = TempDiv % 60;
 	BaseIoctl.Cue [ piste ].CuePartiel.StartCent = TempMod;
 }
-
 /*
 REM Cue file written by Xcfa
 
@@ -561,7 +575,7 @@ void cdcue_write_cue_ok_partiel (void)
 	}
 	
 	Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
-	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config_User.Path_Destination_CD, Ptr);
+	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, Ptr);
 	
 	/*fp = fopen (PathName, "w");*/
 	fp = fopen (BaseIoctl.PathNameDestFileCue, "w");
@@ -575,7 +589,7 @@ void cdcue_write_cue_ok_partiel (void)
 	fprintf (fp,   "TITLE \"%s\"\n", BaseIoctl.Title);
 
 
-	switch (gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (XCFA_GET_OBJECT("combobox_choice_file_cue"))))) {
+	switch (gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (GLADE_GET_OBJECT("combobox_choice_file_cue"))))) {
 	case 0 : fprintf (fp,   "FILE \"%s.wav\" WAVE\n", Ptr);	break;
 	case 1 : fprintf (fp,   "FILE \"%s.flac\" WAVE\n", Ptr);	break;
 	case 2 : fprintf (fp,   "FILE \"%s.ogg\" WAVE\n", Ptr);	break;
@@ -628,7 +642,8 @@ void cdcue_write_cue_ok_partiel (void)
 	/* FIN de creation CUE-FILE */
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 }
-
+// 
+// 
 void cdcue_write_cue (void)
 {
 	gchar	*PathName = NULL;
@@ -642,22 +657,20 @@ void cdcue_write_cue (void)
 		break;
 		
 	case TYPE_CUE_FILE :
-		/*
-		Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
-		PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config_User.Path_Destination_CD, Ptr);
-		*/
-		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_cue"))) == TRUE) {
+		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_cue"))) == TRUE) {
 			
-			/*if (infosong_file_is_reg (PathName) == TRUE) {*/
-			if (infosong_file_is_reg (BaseIoctl.PathNameDestFileCue) == TRUE) {
+			/*if (libutils_test_file_exist (PathName) == TRUE) {*/
+			if (libutils_test_file_exist (BaseIoctl.PathNameDestFileCue) == TRUE) {
 				
 				Str = g_strdup_printf (_("<b>\nLe fichier existe:\n%s       \nVoulez vous le remplacer  ?       \n</b>"), BaseIoctl.PathNameDestFileCue);
+				/*
 				windchoice_open (
 					_("Le fichier existe"),
 					Str,
 					TRUE,
 					cdcue_write_cue_ok_partiel
 					);
+				*/
 				break;
 			}
 			cdcue_write_cue_ok_partiel ();
@@ -665,17 +678,19 @@ void cdcue_write_cue (void)
 		break;
 		
 	case TYPE_CUE_CD :
-		PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config_User.Path_Destination_CD, BaseIoctl.Performer);
+		PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, BaseIoctl.Performer);
 		
-		if (infosong_file_is_reg (PathName) == TRUE) {
+		if (libutils_test_file_exist (PathName) == TRUE) {
 			
 			Str = g_strdup_printf (_("<b>\nLe fichier existe:\n%s       \nVoulez vous le remplacer  ?       \n</b>"), PathName);
+			/*
 			windchoice_open (
 				_("Le fichier existe"),
 				Str,
 				TRUE,
 				cdcue_write_cue_ok
 				);
+			*/
 			break;
 		}
 		cdcue_write_cue_ok ();
@@ -695,7 +710,8 @@ void cdcue_write_cue (void)
 	}
 	Ptr = NULL;
 }
-
+// 
+// 
 static gint cdcue_timeout (gpointer data)
 {
 	if (var_cd.bool_timeout_read_toc_cd == FALSE) {
@@ -709,10 +725,9 @@ static gint cdcue_timeout (gpointer data)
 	
 	return (TRUE);
 }
-
-/* Demande de creation CUE totale
-*/
-void cdcue_button_cue_creation_from_cd_clicked (void)
+// Demande de creation CUE totale
+// 
+void on_button_cue_creation_from_cd_clicked (GtkButton *button, gpointer user_data)
 {
 	
 	if (cdcue_is_alloc () == TRUE) {
@@ -738,8 +753,15 @@ void cdcue_button_cue_creation_from_cd_clicked (void)
 		cdaudiotoc_reffresh_list_cd ();
 	}
 }
-
-void cdcue_entry_name_fichier_unique_cue_changed (void)
+// 
+// 
+void on_entry_name_fichier_unique_cue_realize (GtkWidget *widget, gpointer user_data)
+{
+	var_cd.Adr_entry_name_file_cue = widget;
+}
+// 
+// 
+void on_entry_name_fichier_unique_cue_changed (GtkEditable *editable, gpointer user_data)
 {
 	gchar        *ptr_template = NULL;
 	gchar        *str = NULL;
@@ -758,13 +780,20 @@ void cdcue_entry_name_fichier_unique_cue_changed (void)
 		}
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue), str);
 
-		utils_puts_statusbar_global (_("Le caractere  /  est interdit  !!!"));
+		// utils_puts_statusbar_global (_("Le caractere  /  est interdit  !!!"));
 	}
 
 	g_free (str);
 	str = NULL;
 
 }
+// 
+// 
+void on_checkbutton_creation_fichier_cue_clicked (GtkButton *button, gpointer user_data)
+{
+	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (button)) == TRUE)
+		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_unique_cue")), TRUE);
+}
 
 
 
