@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __cd_cue_h__
-#define __cd_cue_h__ 1
+#ifndef cd_cue_h
+#define cd_cue_h 1
 
 #include "cdtoc.h"
 
