@@ -31,13 +31,18 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <string.h>
 #include <stdlib.h>
 #include <pthread.h>
@@ -49,28 +54,24 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
-#include <string.h>
-
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <sys/wait.h>
 
-#include "utils.h"
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
+#include "configuser.h"
 #include "global.h"
 #include "cd_audio.h"
-#include "info_song.h"
 #include "cdtoc.h"
-#include "get.h"
-#include "scan_cd.h"
+#include "get_info.h"
+#include "scan.h"
 
 
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
 
 typedef struct {
 	
@@ -84,29 +85,27 @@ VAR_CDDB VarCddb = { NULL, NULL, NULL };
 
 gboolean bool_cancel_cddb = FALSE;	/* FALSE = continue ELSE STOP */
 
-
 int strcasecmp (const char *s1, const char *s2);
 int strncasecmp (const char *s1, const char *s2, size_t n);
 
 
 
-/* Si 'FLAG == FALSE', force l'arret de la recherche sur le serveur freedb
-*  --
-*  entree :
-*      gboolean FLAG : TRUE or FALSE
-*  retour : -
-*/
+
+// Si 'FLAG == FALSE', force l'arret de la recherche sur le serveur freedb
+// 
 void cddb_set_bool_cancel_cddb (gboolean FLAG)
 {
 	/*PRINT_FUNC_LF();*/
 	bool_cancel_cddb = FLAG;
 }
-
+// 
+// 
 gboolean cddb_get_bool_cancel_cddb (void)
 {
 	return (bool_cancel_cddb);
 }
-
+// 
+// 
 gboolean cddb_is_ok (gchar *name)
 {
 	FILE      *fp = NULL;
@@ -114,12 +113,12 @@ gboolean cddb_is_ok (gchar *name)
 	size_t     size = 0;
 	gboolean   RetFunc = TRUE;
 
-	if (infosong_get_size_file (name) == 0) return (FALSE);;
+	if (libutils_get_size_file (name) == 0) return (FALSE);;
 	
 	if ((fp = fopen (name, "r"))) {
 		size_t dummy;
 		
-		size = infosong_get_size_file (name);
+		size = libutils_get_size_file (name);
 		if ((buf = (gchar *)g_malloc0 (sizeof (gchar) * (size + 10))) == NULL) {
 			fclose (fp);
 			return (FALSE);
@@ -138,23 +137,22 @@ gboolean cddb_is_ok (gchar *name)
 	
 	return (RetFunc);
 }
-
+// 
+// 
 gboolean cddb_test_access_web (void)
 {
 	static gboolean   bool_access_ok = FALSE;
 
-	if (utils_scan_by_which ("wget", NULL) == FALSE) {
+	if (libutils_find_file ("wget") == FALSE) {
 		g_print ("WGET absent !\n");
 		return (bool_access_ok);
 	}
 	
-	get_with_wget ();
-	bool_access_ok = cddb_is_ok ("/tmp/index.html");
-	infosong_delete_file ("/tmp/index.html");
-	
+	bool_access_ok = GetInfo_wget ();
 	return (bool_access_ok);
 }
-
+// 
+// 
 void cddb_get_datas_on_disk (gchar *PathNameFile)
 {
 #define MAX_CARS_CDDB 255
@@ -166,8 +164,8 @@ void cddb_get_datas_on_disk (gchar *PathNameFile)
 	CdToc->BoolMultiArtiste = FALSE;
 	
 	// IF FILE EXIST and SIZE FILE > 0
-	if (infosong_file_is_reg (PathNameFile) == TRUE &&
-	    infosong_get_size_file (PathNameFile) > 0) {
+	if (libutils_test_file_exist (PathNameFile) == TRUE &&
+	    libutils_get_size_file (PathNameFile) > 0) {
 	
 		if ((fp = fopen (PathNameFile, "r")) != NULL) {
 			while (fgets (buf, MAX_CARS_CDDB, fp) != NULL) {
@@ -193,7 +191,7 @@ void cddb_get_datas_on_disk (gchar *PathNameFile)
 					} else {
 						CdToc->StrGenre = g_strdup (Ptr +7);
 					}
-					CdToc->NumGenre = infosong_get_genre_by_value (CdToc->StrGenre);
+					CdToc->NumGenre = tags_get_genre_by_value (CdToc->StrGenre);
 				}
 				else if ((Ptr = strstr (buf, "DYEAR")) != NULL) {
 					
@@ -245,18 +243,18 @@ void cddb_get_datas_on_disk (gchar *PathNameFile)
 		}
 	}
 }
-
+// 
+// 
 CD_TOC *cddb_get_datas_cddb (CD_TOC *CdToc)
 {
-	GList	*list = NULL;
+	gint		Dummy = 0;
+	gint		pos = 0;
+	gboolean	BoolNoErrorRead;
 	
-	VarCddb.TmpRep = utils_create_temporary_rep (PATH_TMP_XCFA_ICEDAX);
+	VarCddb.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_ICEDAX);
 	VarCddb.TmpActuel = g_get_current_dir ();
 	g_chdir (VarCddb.TmpRep);
 	
-	conv.ArgConv = (ARGS_TO_EXEC *)g_malloc0(sizeof(ARGS_TO_EXEC) * 100);
-	GDK_THREADS_ENTER();
-
 	// icedax --cddb 1 -device /dev/hda --verbose-level title --info-only
 	// --cddb 1
 	// 	first fit mode. The first entry is taken unconditionally
@@ -275,16 +273,15 @@ CD_TOC *cddb_get_datas_cddb (CD_TOC *CdToc)
 	// --info-only
 	// 	does not write to a file, it just gives information about the disc
 	
-	list = g_list_append (list, g_strdup ("icedax"));
-	list = g_list_append (list, g_strdup ("--cddb"));
-	list = g_list_append (list, g_strdup ("1"));
-	list = g_list_append (list, g_strdup ("-device"));
-	// list = g_list_append (list, g_strdup ("/dev/hda"));
-	list = g_list_append (list, g_strdup_printf ("%s", scancd_get_text_combo_cd (_CD_)));
-	list = g_list_append (list, g_strdup ("--verbose-level"));
-	list = g_list_append (list, g_strdup ("title"));
-	list = g_list_append (list, g_strdup ("--info-only"));
-	
+	pos = 0;
+	conv.ArgConv [ pos++ ] = g_strdup ("icedax");
+	conv.ArgConv [ pos++ ] = g_strdup ("--cddb");
+	conv.ArgConv [ pos++ ] = g_strdup ("1");
+	conv.ArgConv [ pos++ ] = g_strdup ("-device");
+	conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", scan_get_text_combo_cd (_CD_));
+	conv.ArgConv [ pos++ ] = g_strdup ("--verbose-level");
+	conv.ArgConv [ pos++ ] = g_strdup ("title");
+	conv.ArgConv [ pos++ ] = g_strdup ("--info-only");	
 	/*
 	http://at.freedb.org/~cddb
 	http://ca.freedb.org/~cddb
@@ -326,22 +323,20 @@ CD_TOC *cddb_get_datas_cddb (CD_TOC *CdToc)
 	) or die $!;
 
 	*/
-	list = g_list_append (list, g_strdup ("cddbp-server=freedb.freedb.org/"));
-	list = g_list_append (list, g_strdup ("cddbp-port=8880"));
-	// TODO: ICEDAX => ADD Command line --Recover_noprintable
-	
-	GDK_THREADS_LEAVE();
+	conv.ArgConv [ pos++ ] = g_strdup ("cddbp-server=freedb.freedb.org/");
+	conv.ArgConv [ pos++ ] = g_strdup ("cddbp-port=8880");
 
-	conv_exec (FALSE, ICEDAX, list, "ICEDAX");
-	list = filelc_remove_glist (list);
-	g_free (conv.ArgConv);
-	conv.ArgConv = NULL;
+	conv.ArgConv [ pos++ ] = NULL;
 	
-	if (infosong_file_is_reg ("audio.cddb") == TRUE) {
-		system ("iconv -f iso-8859-1 -t utf-8 ./audio.cddb  -o ./audio.t");
-		// TRAITEMENT FICHIER: VarCddb.PathNameCdIndex (audio.cddb)
-		VarCddb.PathNameCdIndex = g_strdup_printf ("%s/audio.t", VarCddb.TmpRep);
-		cddb_get_datas_on_disk (VarCddb.PathNameCdIndex);
+	BoolNoErrorRead = conv_to_convert (FALSE, ICEDAX, "ICEDAX");
+	filelc_get_command_line_remove ();
+	if (TRUE == BoolNoErrorRead) {
+		if (libutils_test_file_exist ("audio.cddb") == TRUE) {
+			Dummy = system ("iconv -f iso-8859-1 -t utf-8 ./audio.cddb  -o ./audio.t");
+			// TRAITEMENT FICHIER: VarCddb.PathNameCdIndex (audio.cddb)
+			VarCddb.PathNameCdIndex = g_strdup_printf ("%s/audio.t", VarCddb.TmpRep);
+			cddb_get_datas_on_disk (VarCddb.PathNameCdIndex);
+		}
 	}
 	
 	if (CdToc->TitleCD == NULL)	CdToc->TitleCD = g_strdup ("");
@@ -349,7 +344,7 @@ CD_TOC *cddb_get_datas_cddb (CD_TOC *CdToc)
 	g_chdir (VarCddb.TmpActuel);
 	g_free (VarCddb.TmpActuel);
 	VarCddb.TmpActuel = NULL;
-	VarCddb.TmpRep = utils_remove_temporary_rep (VarCddb.TmpRep);
+	VarCddb.TmpRep = libutils_remove_temporary_rep (VarCddb.TmpRep);
 	
 	if (VarCddb.PathNameCdIndex != NULL) {
 		g_free (VarCddb.PathNameCdIndex);
@@ -358,46 +353,6 @@ CD_TOC *cddb_get_datas_cddb (CD_TOC *CdToc)
 	
 	return (CdToc);
 }
-/*
-
-	// Create tmp rep
-	if (!conv.TmpRep)  {
-		// #define PATH_TMP_XCFA_AUDIOCD "xcfa_cdaudio"
-		// #define PATH_TMP_XCFA_ICEDAX "XcfaIcedax"
-		conv.TmpRep  = utils_create_temporary_rep (PATH_TMP_XCFA_ICEDAX);
-	}
-	// Delete tmp rep
-	if (conv.TmpRep)   {
-		conv.TmpRep  = utils_remove_temporary_rep (conv.TmpRep);
-	}
-	VarCdExtract.PtrDirActuel = g_get_current_dir ();
-	g_chdir (conv.TmpRep);
-	
-	OldRep = GET OLD REP
-	CHANGE REP TO: /tmp/XcfaIcedax
-	ADJUST [ -device ]
-	
-	icedax --cddb 0 -device /dev/hda --verbose-level title --info-only
-	--cddb 0
-		interactive mode. The user selects the entry to use
-	-device /dev/hda
-		uses device as the source for CDDA reading
-	--verbose-level title
-		prints verbose information about the CD
-	--info-only
-		does not write to a file, it just gives information about the disc
-	
-	READ OF: audio.cddb
-	CHANGE REP TO: OldRep
-*/
-
-
-
-
-
-
-
-
 
 
 
