@@ -31,65 +31,57 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-
 #include <string.h>
 #include <stdlib.h>
 
-#include "utils.h"
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "cd_audio.h"
-#include "config_user.h"
+#include "configuser.h"
 #include "parse.h"
 
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
 
-/*
-*---------------------------------------------------------------------------
-* DEFINITION TITRES CD-AUDIO
-*---------------------------------------------------------------------------
-*/
+
 gboolean Bool_Changed_Ok = TRUE;
 
-/*
-*---------------------------------------------------------------------------
-* MODIF WIDGET
-*---------------------------------------------------------------------------
-*/
+
+
+// 
+// 
 void cdexpander_set_sensitive_notebook (void)
 {
 	AUDIO            *Audio = NULL;
 	
-	if (!var_cd.Adr_notebook) return;
+	if (NULL == var_cd.Adr_notebook) return;
 	Audio = cdaudio_get_line_selected ();
-	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("table_tags_expanderCD")), Audio ? TRUE : FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("vbox_titres_expanderCD")), Audio ? TRUE : FALSE);
-	
-	/*
-	if (!Audio) return;
-	vbox_action_expanderCD
-	table_tags_expanderCD
-	vbox_titres_expanderCD
-	*/
+	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("table_tags_expanderCD")), Audio ? TRUE : FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("vbox_titres_expanderCD")), Audio ? TRUE : FALSE);
 }
-
+// 
+// 
 void cdexpander_set_entry_tag_titre_album (void)
 {
 	AUDIO            *Audio = NULL;
 	
-	if (!var_cd.Adr_entry_tag_titre_album) return;
-	if ((Audio = cdaudio_get_line_selected ())) {
+	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
+	if (NULL != (Audio = cdaudio_get_line_selected ())) {
 		Bool_Changed_Ok = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_album), Audio->tags->Album);
 		Bool_Changed_Ok = TRUE;
@@ -100,12 +92,14 @@ void cdexpander_set_entry_tag_titre_album (void)
 		Bool_Changed_Ok = TRUE;
 	}
 }
+// 
+// 
 void cdexpander_set_entry_tag_nom_artiste (void)
 {
 	AUDIO            *Audio = NULL;
 	
-	if (!var_cd.Adr_entry_tag_nom_artiste) return;
-	if ((Audio = cdaudio_get_line_selected ())) {
+	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
+	if (NULL != (Audio = cdaudio_get_line_selected ())) {
 		Bool_Changed_Ok = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_nom_artiste), Audio->tags->Artist);
 		Bool_Changed_Ok = TRUE;
@@ -116,40 +110,46 @@ void cdexpander_set_entry_tag_nom_artiste (void)
 		Bool_Changed_Ok = TRUE;
 	}
 }
-
+// 
+// 
 void cdexpander_set_spinbutton_tag_piste (void)
 {
 	AUDIO        *Audio = NULL;
 	
-	if ((Audio = cdaudio_get_line_selected ()) && var_cd.Adr_spinbutton_tag_piste) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_piste) {
 		Bool_Changed_Ok = FALSE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_cd.Adr_spinbutton_tag_piste), (gdouble)Audio->tags->IntNumber);
 		Bool_Changed_Ok = TRUE;
 	}
 }
-
+// 
+// 
 void cdexpander_set_spinbutton_tag_annee (void)
 {
 	AUDIO        *Audio = NULL;
 	
-	if ((Audio = cdaudio_get_line_selected ()) && var_cd.Adr_spinbutton_tag_annee) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_annee) {
 		Bool_Changed_Ok = FALSE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_cd.Adr_spinbutton_tag_annee), (gdouble)Audio->tags->IntYear);
 		Bool_Changed_Ok = TRUE;
 	}
 }
+// 
+// 
 gint cdexpander_get_spinbutton_tag_annee (void)
 {
-	if (var_cd.Adr_spinbutton_tag_annee) {
+	if (NULL != var_cd.Adr_spinbutton_tag_annee) {
 		return (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(var_cd.Adr_spinbutton_tag_annee)));
 	}
 	return (0);
 }
+// 
+// 
 void cdexpander_set_entry_tag_titre_chanson (void)
 {
 	AUDIO            *Audio = NULL;
 	
-	if ((Audio = cdaudio_get_line_selected ()) && var_cd.Adr_entry_tag_titre_chanson) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_titre_chanson) {
 		Bool_Changed_Ok = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_chanson), Audio->tags->Title);
 		Bool_Changed_Ok = TRUE;		
@@ -160,27 +160,33 @@ void cdexpander_set_entry_tag_titre_chanson (void)
 		Bool_Changed_Ok = TRUE;
 	}
 }
+// 
+// 
 void cdexpander_set_new_genre (void)
 {
 	AUDIO            *Audio = NULL;
 
-	if ((Audio = cdaudio_get_line_selected ()) && var_cd.Adr_combobox_tag_genre_cd) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_combobox_tag_genre_cd) {
 		Bool_Changed_Ok = FALSE;
-		gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_tag_genre_cd), infosong_get_elements_combobox (Audio->tags->IntGenre));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_tag_genre_cd), tags_get_elements_combobox (Audio->tags->IntGenre));
 		Bool_Changed_Ok = TRUE;
 	}
 }
+// 
+// 
 void cdexpander_set_entry_new_titre_cdaudio (gchar *p_str)
 {
-	if (var_cd.Adr_entry_new_titre_cdaudio && p_str) {
+	if (NULL != var_cd.Adr_entry_new_titre_cdaudio && NULL != p_str) {
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio), p_str);
 	}
 }
+// 
+// 
 void cdexpander_set_entry_tag_commentaire (void)
 {
 	AUDIO            *Audio = NULL;
 	
-	if ((Audio = cdaudio_get_line_selected ()) && var_cd.Adr_entry_tag_commentaire) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_commentaire) {
 		Bool_Changed_Ok = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), Audio->tags->Comment);
 		Bool_Changed_Ok = TRUE;		
@@ -191,22 +197,22 @@ void cdexpander_set_entry_tag_commentaire (void)
 		Bool_Changed_Ok = TRUE;
 	}
 }
-
+// 
+// 
 void cdexpander_set_entry_tag_titre_fichier_m3u (void)
 {
-	if (Bool_Changed_Ok == FALSE) return;
-	if (var_cd.Adr_entry_tag_titre_fichier) {
+	if (FALSE == Bool_Changed_Ok) return;
+	if (NULL != var_cd.Adr_entry_tag_titre_fichier) {
 		Bool_Changed_Ok = FALSE;
-		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_fichier), Config_User.Name_file_m3u ? Config_User.Name_file_m3u : "");
+		// m3u
+		// xspf
+		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_fichier), Config.StringNameFile_m3u_xspf ? Config.StringNameFile_m3u_xspf : "");
 		Bool_Changed_Ok = TRUE;		
 	}
 }
-
-
-/* FROM CALLBACKS.C CHANGED
-*/
-
-void cdexpander_entry_tag_titre_chanson_changed (void)
+// 
+// 
+void on_entry_tag_titre_chanson_changed (GtkEditable *editable, gpointer user_data)
 {
 	gchar        *ptr_template = NULL;
 	AUDIO        *Audio = NULL;
@@ -226,16 +232,18 @@ void cdexpander_entry_tag_titre_chanson_changed (void)
 	}
 	g_free (str);
 	str = NULL;
-	
-	if (Bool_Changed_Ok == FALSE) return;
-	if ((Audio = cdaudio_get_line_selected ())) {
+
+	if (FALSE == Bool_Changed_Ok) return;
+	if (NULL != (Audio = cdaudio_get_line_selected ())) {
 		g_free (Audio->tags->Title);
 		Audio->tags->Title = NULL;
 		Audio->tags->Title = g_strdup (ptr_template);
 	}
 	cdaudio_set_titre_chanson ();
 }
-void cdexpander_entry_tag_titre_album_changed (void)
+// 
+// 
+void on_entry_tag_titre_album_changed (GtkEditable *editable, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -244,14 +252,14 @@ void cdexpander_entry_tag_titre_album_changed (void)
 	gchar        *ptr_template = NULL;
 	AUDIO        *Audio = NULL;
 	
-	if (!var_cd.Adr_entry_tag_titre_album) return;
-	if (Bool_Changed_Ok == FALSE) return;
+	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
+	if (FALSE == Bool_Changed_Ok) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_album));
 
 	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 	while (valid) {
 		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-		if ((Audio = (AUDIO *)List->data)) {
+		if (NULL != (Audio = (AUDIO *)List->data)) {
 			g_free (Audio->tags->Album);
 			Audio->tags->Album = NULL;
 			Audio->tags->Album = g_strdup (ptr_template);
@@ -262,7 +270,9 @@ void cdexpander_entry_tag_titre_album_changed (void)
 
 	cdaudio_set_titre_chanson ();
 }
-void cdexpander_entry_tag_nom_artiste_changed (void)
+// 
+// 
+void on_entry_tag_nom_artiste_changed (GtkEditable *editable, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -271,11 +281,11 @@ void cdexpander_entry_tag_nom_artiste_changed (void)
 	gchar        *ptr_template = NULL;
 	AUDIO        *Audio = NULL;
 	
-	if (!var_cd.Adr_entry_tag_nom_artiste) return;
-	if (Bool_Changed_Ok == FALSE) return;
+	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
+	if (FALSE == Bool_Changed_Ok) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_nom_artiste));
 	
-	if (EnteteCD.BoolMultiArtiste == TRUE) {
+	if (TRUE == EnteteCD.BoolMultiArtiste) {
 		if ((Audio = cdaudio_get_line_selected ())) {
 			g_free (Audio->tags->Artist);
 			Audio->tags->Artist = NULL;
@@ -286,7 +296,7 @@ void cdexpander_entry_tag_nom_artiste_changed (void)
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if ((Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (AUDIO *)List->data)) {
 				g_free (Audio->tags->Artist);
 				Audio->tags->Artist = NULL;
 				Audio->tags->Artist = g_strdup (ptr_template);
@@ -297,21 +307,24 @@ void cdexpander_entry_tag_nom_artiste_changed (void)
 	}
 	cdaudio_set_titre_chanson ();
 }
-
-void cdexpander_entry_copy_tag_commentaire (void)
+// 
+// 
+void on_button_copy_commentaire_clicked (GtkButton *button, gpointer user_data)
 {
 	gchar        *ptr_template = NULL;
 	
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire));
-	if (EnteteCD.StrMemoTagComment != NULL) {
+	if (NULL != EnteteCD.StrMemoTagComment) {
 		g_free (EnteteCD.StrMemoTagComment);
 		EnteteCD.StrMemoTagComment = NULL;
 	}
 	EnteteCD.StrMemoTagComment = g_strdup (ptr_template);
 	
-	cdaudio_set_flag_buttons_audio_cd ();
+	cdaudio_set_flag_buttons ();
 }
-void cdexpander_entry_paste_tag_commentaire (void)
+// 
+// 
+void on_button_paste_comment_clicked (GtkButton *button, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -322,7 +335,7 @@ void cdexpander_entry_paste_tag_commentaire (void)
 	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 	while (valid) {
 		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-		if ((Audio = (AUDIO *)List->data)) {
+		if (NULL != (Audio = (AUDIO *)List->data)) {
 			g_free (Audio->tags->Comment);
 			Audio->tags->Comment = NULL;
 			Audio->tags->Comment = g_strdup (EnteteCD.StrMemoTagComment);
@@ -333,8 +346,9 @@ void cdexpander_entry_paste_tag_commentaire (void)
 	gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), EnteteCD.StrMemoTagComment);
 	cdaudio_set_titre_chanson ();
 }
-
-void cdexpander_entry_tag_commentaire_changed (void)
+// 
+// 
+void on_entry_tag_commentaire_changed (GtkEditable *editable, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -343,12 +357,12 @@ void cdexpander_entry_tag_commentaire_changed (void)
 	gchar        *ptr_template = NULL;
 	AUDIO        *Audio = NULL;
 	
-	if (!var_cd.Adr_entry_tag_commentaire) return;
-	if (Bool_Changed_Ok == FALSE) return;
+	if (NULL == var_cd.Adr_entry_tag_commentaire) return;
+	if (FALSE == Bool_Changed_Ok) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire));
 		
-	if (EnteteCD.BoolMultiArtiste == TRUE) {
-		if ((Audio = cdaudio_get_line_selected ())) {
+	if (TRUE == EnteteCD.BoolMultiArtiste) {
+		if (NULL != (Audio = cdaudio_get_line_selected ())) {
 			g_free (Audio->tags->Comment);
 			Audio->tags->Comment = NULL;
 			Audio->tags->Comment = g_strdup (ptr_template);
@@ -358,7 +372,7 @@ void cdexpander_entry_tag_commentaire_changed (void)
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if ((Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (AUDIO *)List->data)) {
 				g_free (Audio->tags->Comment);
 				Audio->tags->Comment = NULL;
 				Audio->tags->Comment = g_strdup (ptr_template);
@@ -369,7 +383,9 @@ void cdexpander_entry_tag_commentaire_changed (void)
 	}
 	cdaudio_set_titre_chanson ();
 }
-void cdexpander_spinbutton_tag_annee_value_changed (void)
+// 
+// 
+void on_spinbutton_tag_annee_value_changed (GtkSpinButton *spinbutton, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -378,11 +394,11 @@ void cdexpander_spinbutton_tag_annee_value_changed (void)
 	AUDIO        *Audio = NULL;
 	gint          Value;
 	
-	if (!var_cd.Adr_spinbutton_tag_annee) return;
+	if (NULL == var_cd.Adr_spinbutton_tag_annee) return;
 	Value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(var_cd.Adr_spinbutton_tag_annee));
 	
-	if (EnteteCD.BoolMultiArtiste == TRUE) {
-		if ((Audio = cdaudio_get_line_selected ())) {
+	if (TRUE == EnteteCD.BoolMultiArtiste) {
+		if (NULL != (Audio = cdaudio_get_line_selected ())) {
 			g_free (Audio->tags->Year);
 			Audio->tags->Year = NULL;
 			Audio->tags->Year = g_strdup_printf ("%d", Value);
@@ -393,7 +409,7 @@ void cdexpander_spinbutton_tag_annee_value_changed (void)
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if ((Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (AUDIO *)List->data)) {
 				g_free (Audio->tags->Year);
 				Audio->tags->Year = NULL;
 				Audio->tags->Year = g_strdup_printf ("%d", Value);
@@ -405,15 +421,17 @@ void cdexpander_spinbutton_tag_annee_value_changed (void)
 	}
 	cdaudio_set_titre_chanson ();
 }
-void cdexpander_spinbutton_tag_piste_value_changed (void)
+// 
+// 
+void on_spinbutton_tag_piste_value_changed (GtkSpinButton *spinbutton, gpointer user_data)
 {
 	AUDIO        *Audio = NULL;
 	gint          Value;
 	
-	if (!var_cd.Adr_spinbutton_tag_piste) return;
+	if (NULL == var_cd.Adr_spinbutton_tag_piste) return;
 	Value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(var_cd.Adr_spinbutton_tag_piste));
 	
-		if ((Audio = cdaudio_get_line_selected ())) {
+		if (NULL != (Audio = cdaudio_get_line_selected ())) {
 			g_free (Audio->tags->Number);
 			Audio->tags->Number = NULL;
 			Audio->tags->Number = g_strdup_printf ("%d", Value);
@@ -421,15 +439,17 @@ void cdexpander_spinbutton_tag_piste_value_changed (void)
 		}
 	cdaudio_set_titre_chanson ();
 }
-void cdexpander_entry_tag_titre_fichier_m3u_changed (void)
+// 
+// 
+void on_entry_tag_titre_fichier_m3u_changed (GtkEditable *editable, gpointer user_data)
 {
-	if (Bool_Changed_Ok == FALSE) return;
-	if (var_cd.Adr_entry_tag_titre_fichier) {
-		g_free (Config_User.Name_file_m3u);
-		Config_User.Name_file_m3u = NULL;
-		Config_User.Name_file_m3u = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_fichier)));
+	if (FALSE == Bool_Changed_Ok) return;
+	if (NULL != var_cd.Adr_entry_tag_titre_fichier) {
+		g_free (Config.StringNameFile_m3u_xspf);
+		Config.StringNameFile_m3u_xspf = NULL;
+		Config.StringNameFile_m3u_xspf = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_fichier)));
 		
-		if (strstr (gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)), "%f") == NULL) {
+		if (NULL == strstr (gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)), "%f")) {
 
 			gchar *Str = NULL;
 		
@@ -440,7 +460,9 @@ void cdexpander_entry_tag_titre_fichier_m3u_changed (void)
 		}
 	}
 }
-void cdexpander_combobox_tag_genre_cd_changed (void)
+// 
+// 
+void on_combobox_tag_genre_cd_changed (GtkComboBox *combobox, gpointer user_data)
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
@@ -450,28 +472,28 @@ void cdexpander_combobox_tag_genre_cd_changed (void)
 	AUDIO        *Audio = NULL;
 	gint          IntGenre;
 	
-	if (!var_cd.Adr_combobox_tag_genre_cd) return;
+	if (NULL == var_cd.Adr_combobox_tag_genre_cd) return;
 	
 	IntGenre = gtk_combo_box_get_active (var_cd.Adr_combobox_tag_genre_cd);
 	ptr_template = (gchar *)gtk_combo_box_get_active_text (var_cd.Adr_combobox_tag_genre_cd);
 
-	if (EnteteCD.BoolMultiArtiste == TRUE) {
-		if ((Audio = cdaudio_get_line_selected ())) {
+	if (TRUE == EnteteCD.BoolMultiArtiste) {
+		if (NULL != (Audio = cdaudio_get_line_selected ())) {
 			g_free (Audio->tags->Genre);
 			Audio->tags->Genre = NULL;
 			Audio->tags->Genre = g_strdup (ptr_template);
-			Audio->tags->IntGenre = infosong_get_num_combobox (IntGenre);
+			Audio->tags->IntGenre = tags_get_num_combobox (IntGenre);
 		}
 	}
 	else {
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if ((Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (AUDIO *)List->data)) {
 				g_free (Audio->tags->Genre);
 				Audio->tags->Genre = NULL;
 				Audio->tags->Genre = g_strdup (ptr_template);
-				Audio->tags->IntGenre = infosong_get_num_combobox (IntGenre);
+				Audio->tags->IntGenre = tags_get_num_combobox (IntGenre);
 			}
 			valid = gtk_tree_model_iter_next (var_cd.Adr_Tree_Model, &iter);
 			Num_cell ++;
@@ -479,17 +501,24 @@ void cdexpander_combobox_tag_genre_cd_changed (void)
 	}
 	cdaudio_set_titre_chanson ();
 }
-
+// 
+// 
 gboolean cdexpander_bool_entree_cd_verif_car = TRUE;
-void cdexpander_entry_new_titre_cdaudio_changed (void)
+// 
+// 
+void on_entry_new_titre_cdaudio_changed (GtkEditable *editable, gpointer user_data)
 {
 	if (cdexpander_bool_entree_cd_verif_car == FALSE) return;
 	
-	if (var_cd.Adr_entry_new_titre_cdaudio != NULL) {
+	if (NULL != var_cd.Adr_entry_new_titre_cdaudio) {
 		gchar	*StrVerif = NULL;
 		gchar	*ptr = NULL;
 		
-		// PRINT_FUNC_LF();
+		// SUPPRESSION DE LA LIGNE SAISIE PAR L UTILISTATEUR
+		if (NULL != Config.Templates_title_cdaudio) {
+			g_free (Config.Templates_title_cdaudio);
+			Config.Templates_title_cdaudio = NULL;
+		}
 		
 		// LA CARACTERE / EST INTERDIT
 		StrVerif = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)));
@@ -501,6 +530,9 @@ void cdexpander_entry_new_titre_cdaudio_changed (void)
 			gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio), StrVerif);
 			cdexpander_bool_entree_cd_verif_car = TRUE;
 		}
+		// STOCKAGE DE LA LIGNE SAISIE PAR L UTILISTATEUR
+		Config.Templates_title_cdaudio = g_strdup (StrVerif);
+		
 		g_free (StrVerif);
 		StrVerif = NULL;
 		
@@ -509,62 +541,101 @@ void cdexpander_entry_new_titre_cdaudio_changed (void)
 		cdaudio_set_titre_chanson ();
 	}
 }
-
-/* FROM CALLBACKS.C REALIZE
-*/
-
-void cdexpander_expander_cd_realize (GtkWidget *widget)
+// 
+// 
+void on_expander_cd_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_Expander = widget;
+	gtk_expander_set_expanded (GTK_EXPANDER (var_cd.Adr_Expander), Config.BoolEtatExpanderCd);
 }
-void cdexpander_notebook_expander_cd_realize (GtkWidget *widget)
+// 
+// 
+void on_notebook_expander_cd_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_notebook = widget;
 }
-void cdexpander_entry_tag_titre_chanson_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_tag_titre_chanson_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_titre_chanson = widget;
 }
-void cdexpander_entry_tag_titre_album_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_tag_titre_album_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_titre_album = widget;
 }
-void cdexpander_entry_tag_nom_artiste_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_tag_nom_artiste_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_nom_artiste = widget;
 }
-void cdexpander_entry_tag_commentaire_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_tag_commentaire_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_commentaire = widget;
 }
-void cdexpander_spinbutton_tag_annee_realize (GtkWidget *widget)
+// 
+// 
+void on_spinbutton_tag_annee_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_spinbutton_tag_annee = widget;
 }
-void cdexpander_spinbutton_tag_piste_realize (GtkWidget *widget)
+// 
+// 
+void on_spinbutton_tag_piste_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_spinbutton_tag_piste = widget;
 }
-void cdexpander_entry_tag_titre_fichier_m3u_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_tag_titre_fichier_m3u_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_titre_fichier = widget;
 }
-void cdexpander_combobox_tag_genre_cd_realize (GtkWidget *widget)
+// 
+// 
+void on_combobox_tag_genre_cd_realize (GtkWidget *widget, gpointer user_data)
 {
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
-	infosong_set_elements_combobox (widget);
+	tags_set_elements_combobox (widget);
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	var_cd.Adr_combobox_tag_genre_cd = GTK_COMBO_BOX (widget);
 }
-void cdexpander_entry_new_titre_cdaudio_realize (GtkWidget *widget)
+// 
+// 
+void on_entry_new_titre_cdaudio_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_new_titre_cdaudio = widget;
-	gtk_entry_set_text (GTK_ENTRY (widget), Config_User.Templates_title_cdaudio);
+	if (NULL == Config.Templates_title_cdaudio) {
+		Config.Templates_title_cdaudio = g_strdup ("%c %d");
+	}
+	gtk_entry_set_text (GTK_ENTRY (widget), Config.Templates_title_cdaudio);
 	var_cd.Bool_create_file_m3u = FALSE;
 	var_cd.Pathname_m3u = NULL;
 }
+// 
+// 
+void on_checkbutton_creation_fichier_unique_cue_clicked (GtkButton *button, gpointer user_data)
+{
+	if (FALSE == gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (button)))
+		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_cue")), FALSE);
+}
+// 
+// 
+void on_combobox_choice_file_cue_realize (GtkWidget *widget, gpointer user_data)
+{
+	libcombo_alloc (GTK_COMBO_BOX (widget));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "WAV");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "FLAC");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "OGG");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "MPC");
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+}
 
 
