@@ -31,8 +31,14 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
@@ -48,22 +54,19 @@
 #include <unistd.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "cd_audio.h"
-#include "scan_cd.h"
+#include "scan.h"
 #include "cdtoc.h"
 #include "cd_cue.h"
 
 
 
 
-/*
-*---------------------------------------------------------------------------
-* FUNCTIONS
-*---------------------------------------------------------------------------
-*/
-
-
 /*---------------------------------------------------
  * -   Original Routines for calculating disc-id   -
  * -   see "cddb.howto" for copyright              -
@@ -139,8 +142,8 @@ gint cdioctl_read_toc (void) {
 	/*PRINT_FUNC_LF();*/
 
 	cdsc.cdsc_format=CDROM_MSF;
-
 	i = ioctl(drive,CDROMSUBCHNL,&cdsc);
+	
 	if (i < 0) {
  		g_print ("\nCD NON AUDIO OU ABSENT DANS LE LECTEUR\n");
    		close(drive);
