@@ -31,8 +31,17 @@
  */
 
 
-#include <gtk/gtk.h>
 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <pthread.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -42,9 +51,13 @@
 #include <stdio.h>
 #include <signal.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "cd_audio.h"
-#include "utils.h"
+#include "configuser.h"
 #include "cd_normalise.h"
 
 
@@ -79,7 +92,9 @@ void CdNormalise_set_list_PeakGroup (AUDIO *Audio)
 	
 	// PRINT_FUNC_LF();
 	
-	if (VarCdNormalise.TmpRep == NULL)  VarCdNormalise.TmpRep = utils_create_temporary_rep (PATH_TMP_XCFA_CD_NORMALISE_PEAK_ALBUM );
+	if (VarCdNormalise.TmpRep == NULL) {
+		VarCdNormalise.TmpRep = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_CD_NORMALISE_PEAK_ALBUM );
+	}
 	
 	VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)g_malloc0 (sizeof (VAR_CD_NORMALISE_ELEMENT));
 	VarCDNormaliseElement->PathNameSrc  = g_strdup_printf ("%s/%d.wav", VarCdNormalise.TmpRep, VarCdNormalise.MaxElements);
@@ -88,12 +103,14 @@ void CdNormalise_set_list_PeakGroup (AUDIO *Audio)
 	VarCdNormalise.ListPeakGroup = g_list_append (VarCdNormalise.ListPeakGroup, VarCDNormaliseElement);
 	VarCdNormalise.MaxElements ++;
 }
-
+// 
+// 
 void CdNormalise_add_PeakGroup (void)
 {
 	VarCdNormalise.NumExtract ++;
 }
-
+// 
+// 
 void CdNormalise_set_list_collectif_remove (void)
 {
 	GList         			*List = NULL;
@@ -115,40 +132,45 @@ void CdNormalise_set_list_collectif_remove (void)
 	VarCdNormalise.MaxElements = 0;
 	VarCdNormalise.NumExtract = 0;
 	
-	if (VarCdNormalise.TmpRep != NULL)  VarCdNormalise.TmpRep = utils_remove_temporary_rep (VarCdNormalise.TmpRep);
+	if (VarCdNormalise.TmpRep != NULL) {
+		VarCdNormalise.TmpRep = libutils_remove_temporary_rep (VarCdNormalise.TmpRep);
+	}
 }
-
+// 
+// 
 gboolean CdNormalise_list_PeakGroup_is_ready (void)
 {
 	if (VarCdNormalise.MaxElements == VarCdNormalise.NumExtract) return (TRUE);
 	return (FALSE);
 }
-
+// 
+// 
 gboolean CdNormalise_get_is_list_PeakGroup (void)
 {
 	return (VarCdNormalise.ListPeakGroup == NULL ? FALSE : TRUE);
 }
-
+// 
+// 
 GList *CdNormalise_get_list_PeakGroup (void)
 {
 	return ((GList *)VarCdNormalise.ListPeakGroup);
 }
-
+// 
+// 
 void CdNormalise_set_normalise_ok (void)
 {
-	GList	*List = NULL;
-	// AUDIO	*Audio = NULL;
+	GList				*List = NULL;
 	VAR_CD_NORMALISE_ELEMENT	*VarCDNormaliseElement = NULL;
 	
 	List = g_list_first (VarCdNormalise.ListPeakGroup);
 	while (List) {
-		if ((VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List->data)) {
+		if (NULL != (VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List->data)) {
 			VarCDNormaliseElement->Audio->EtatNormalise = FALSE;
 			VarCDNormaliseElement->Audio->EtatPeak = CD_NORM_PEAK_NONE;
 		}
 		List = g_list_next(List);
 	}
-	gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_normalise_cd), 0);
+	// gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_normalise_cd), 0);
 }
 
 
