@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __cd_normalise_h__
-#define __cd_normalise_h__ 1
+#ifndef cd_normalise_h
+#define cd_normalise_h 1
 
 
 typedef struct {
