@@ -31,23 +31,30 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-
 #include <string.h>
 #include <string.h>
 #include <stdlib.h>
 
-#include "utils.h"
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "secu.h"
 #include "cd_audio.h"
 #include "cdtoc.h"
-#include "get.h"
+#include "get_info.h"
 #include "cd_cue.h"
 
 
@@ -144,7 +151,7 @@ gint cdparanoia_read_toc (void)
 
 	/*PRINT_FUNC_LF();*/
 
-	gstr = get_with_cdparanoia (EnteteCD.NameCD_Device);
+	gstr = GetInfo_cdparanoia (EnteteCD.NameCD_Device);
 	Lerr = gstr->str;
 	if (*Lerr) {
 
