@@ -32,24 +32,32 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-
 #include <string.h>
 #include <stdlib.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "cd_audio.h"
-#include "options.h"
-#include "info_song.h"
-#include "cdtoc.h"
+#include "configuser.h"
 #include "tags.h"
 #include "cd_cue.h"
+#include "cdtoc.h"
 
 /*
 *---------------------------------------------------------------------------
@@ -213,22 +221,21 @@ GList *cdtoc_set_toc_to_glist_audio (void)
 				
 		Audio->tags = (TAGS *)tags_alloc (TRUE);
 	
-		Audio->Num_Track   = NumList + 1;
-		Audio->Str_Track   = g_strdup_printf ("%02d", NumList + 1);
-		Audio->Duree       = g_strdup_printf ("%02d:%02d",
+		Audio->Num_Track      = NumList + 1;
+		Audio->Str_Track      = g_strdup_printf ("%02d", NumList + 1);
+		Audio->Duree          = g_strdup_printf ("%02d:%02d",
 							CdToc->TimeTrack[ NumList ].Min,
 								CdToc->TimeTrack[ NumList ].Sec);
-		Audio->NameSong    = g_strdup_printf ("Track_%02d", NumList + 1);
+		Audio->NameSong       = g_strdup_printf ("Track_%02d", NumList + 1);
 
 		if (CdToc->Bool_Connected == CONNECT_IS_TRUE) {
 
 				if (Audio->NameSong != NULL) {
-					g_free (Audio->NameSong);
-					Audio->NameSong = NULL;
+					g_free (Audio->NameSong);	Audio->NameSong = NULL;
 				}
 				
 				if (CdToc->TimeTrack[ NumList ].TitleTrack == NULL) {
-					Audio->NameSong    = g_strdup_printf ("Track_%02d", NumList +1);
+					Audio->NameSong       = g_strdup_printf ("Track_%02d", NumList +1);
 				} else {
 					/*
 					Muddy Waters / Mannish boy
@@ -243,7 +250,7 @@ GList *cdtoc_set_toc_to_glist_audio (void)
 					Law of Balance/Figit Time
 					*/
 					
-					Audio->NameSong    = g_strdup (CdToc->TimeTrack[ NumList ].TitleTrack);
+					Audio->NameSong       = g_strdup (CdToc->TimeTrack[ NumList ].TitleTrack);
 				}
 
 				Audio->tags = (TAGS *)tags_remove (Audio->tags);
@@ -331,6 +338,7 @@ GList *cdtoc_set_toc_to_glist_audio (void)
 				Audio->tags->IntNumber = NumList +1;
 				Audio->tags->Comment = g_strdup ("By Xcfa");
 				
+				
 				/*
 				g_print("[%02d]----", NumList +1);
 				g_print (  "Artist  = '%s'\n", Audio->tags->Artist  ? Audio->tags->Artist  : "");
@@ -355,8 +363,7 @@ GList *cdtoc_set_toc_to_glist_audio (void)
 				Audio->tags = (TAGS *)tags_alloc (TRUE);
 				
 				if (Audio->NameSong != NULL) {
-					g_free (Audio->NameSong);
-					Audio->NameSong = NULL;
+					g_free (Audio->NameSong);	Audio->NameSong = NULL;
 				}
 				
 				Audio->NameSong          = g_strdup_printf ("Track_%02d", NumList +1);
@@ -378,8 +385,7 @@ GList *cdtoc_set_toc_to_glist_audio (void)
 				Audio->tags = (TAGS *)tags_alloc (TRUE);
 				
 				if (Audio->NameSong != NULL) {
-					g_free (Audio->NameSong);
-					Audio->NameSong = NULL;
+					g_free (Audio->NameSong);	Audio->NameSong = NULL;
 				}
 				
 				Audio->NameSong          = g_strdup_printf ("Track_%02d", NumList +1);
@@ -455,7 +461,7 @@ GList *cdtoc_read (void)
 	/* Lecture base CD-AUDIO
 	*/
 #ifdef HAVE_LINUX_CDROM_H
-	if (options_get_readdir_cdaudio_by_ioctl ()) {
+	if (TRUE == Config.ReadCdByIoctl) {
 		PRINT("ret = cdioctl_read_toc ();");
 		// LIRE TOC DEPUIS IOCTL
 		// RENSEIGNER LA BASE toc
@@ -473,7 +479,7 @@ GList *cdtoc_read (void)
 	// RENSEIGNER LA BASE toc
 	ret = cdparanoia_read_toc ();
 #endif
-
+	g_print("\tRET = %d\n", ret);
 	/* Prend les infos de base, allocmem, stock et retour
 	 *
 	 * RETURN
@@ -482,7 +488,6 @@ GList *cdtoc_read (void)
 	 *    2  CD-ROM AUDIO ABSENT DU LECTEUR
 	 *    3  LE CD DANS LECTEUR N'EST PAS UN CD-AUDIO
 	 */
-
 	switch (ret) {
 	case 0 :
 
@@ -492,7 +497,6 @@ GList *cdtoc_read (void)
 			CdToc = cddb_get_datas_cddb (CdToc);
 		}
 		else {
-			
 			CdToc->Bool_Connected = CONNECT_IS_FALSE;
 		}
 		
