@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __cdtoc_h__
-#define __cdtoc_h__ 1
+#ifndef cdtoc_h
+#define cdtoc_h 1
 
 
 /*
