@@ -30,14 +30,24 @@
  * 
  */
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gprintf.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "cursor.h"
 
@@ -51,123 +61,163 @@ GdkCursorType     cursor_type = GDK_LEFT_PTR;
 
 
 
+
+// 
+// 
+void cursor_set_hand (void)
+{
+	if (cursor_type != GDK_HAND2) {
+		cursor_type = GDK_HAND2;
+		_cursor = gdk_cursor_new (cursor_type);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
+		gdk_flush ();
+	}
+}
+// 
+// 
 void cursor_set_saisie (void)
 {
 	if (cursor_type != GDK_XTERM) {
 		cursor_type = GDK_XTERM;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_gauche_droite (void)
 {
 	if (cursor_type != GDK_SB_H_DOUBLE_ARROW) {
 		cursor_type = GDK_SB_H_DOUBLE_ARROW;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_haut (void)
 {
 	if (cursor_type != GDK_TOP_SIDE) {
 		cursor_type = GDK_TOP_SIDE;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_bas (void)
 {
 	if (cursor_type != GDK_BOTTOM_SIDE) {
 		cursor_type = GDK_BOTTOM_SIDE;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_gauche (void)
 {
 	if (cursor_type != GDK_LEFT_SIDE) {
 		cursor_type = GDK_LEFT_SIDE;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_droit (void)
 {
 	if (cursor_type != GDK_RIGHT_SIDE) {
 		cursor_type = GDK_RIGHT_SIDE;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_haut_gauche (void)
 {
 	if (cursor_type != GDK_TOP_LEFT_CORNER) {
 		cursor_type = GDK_TOP_LEFT_CORNER;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_haut_droit (void)
 {
 	if (cursor_type != GDK_TOP_RIGHT_CORNER) {
 		cursor_type = GDK_TOP_RIGHT_CORNER;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_bas_gauche (void)
 {
 	if (cursor_type != GDK_BOTTOM_LEFT_CORNER) {
 		cursor_type = GDK_BOTTOM_LEFT_CORNER;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_bas_droit (void)
 {
 	if (cursor_type != GDK_BOTTOM_RIGHT_CORNER) {
 		cursor_type = GDK_BOTTOM_RIGHT_CORNER;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_move (void)
 {
 	if (cursor_type != GDK_FLEUR) {
 		cursor_type = GDK_FLEUR;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_old (void)
 {
 	if (cursor_type != GDK_LEFT_PTR) {
 		cursor_type = GDK_LEFT_PTR;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 void cursor_set_watch (void)
 {
 	if (cursor_type != GDK_WATCH) {
 		cursor_type = GDK_WATCH;
 		_cursor = gdk_cursor_new (cursor_type);
-		gdk_window_set_cursor (GDK_WINDOW(wind_main.AdrWin->window), _cursor);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
 		gdk_flush ();
 	}
 }
+// 
+// 
 gboolean cursor_get_watch (void)
 {
 	return (cursor_type == GDK_WATCH ? TRUE : FALSE);
