@@ -31,17 +31,30 @@
  */
 
 
+
+
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "utils.h"
 #include "file.h"
+#include "fileselect.h"
 #include "poche.h"
 #include "split.h"
-#include "fileselect.h"
 #include "dragNdrop.h"
 
 
@@ -52,6 +65,8 @@
 *---------------------------------------------------------------------------
 */
 
+extern VAR_SPLIT VarSplit;
+
 enum
 {
 	TARGET_URI_LIST = 100
@@ -98,80 +113,78 @@ gint n_drag_types = sizeof (drag_types) / sizeof (drag_types [0]);
 */
 void dragndrop_list_drag_data (GtkWidget *widget, gchar *string)
 {
-	gboolean   Bool_add_ok = FALSE;
-	gchar     *Ptr = NULL;
-	gchar     *temp = NULL;
+	gboolean	Bool_add_ok = FALSE;
+	gchar		*Src = NULL;
+	gchar		*Ptr = NULL;
+	gchar		*temp = NULL;
+	GSList		*List = NULL;
 
-	/*PRINT_FUNC_LF();*/
-
-	/* test for input
-	*/
-	if ((widget != var_file.Adr_TreeView) &&
-	    (widget != VarSplit.Adr_TreeView) &&
-	    (widget != poche.Adr_viewport_image_preview)) {
-		PRINT_FUNC_LF();
-		g_print ("\tERREUR DRAG N DROP : WIDGET(dragndrop_list_drag_data) INCONNU --> RETOUR\n");
+	// test for input
+	if (widget != var_file.Adr_TreeView &&
+	    widget != var_file_wav.Adr_TreeView &&
+	    widget != var_file_mp3ogg.Adr_TreeView &&
+	    widget != var_file_tags.Adr_TreeView &&
+	    widget != poche.Adr_viewport_image_preview &&
+	    widget != VarSplit.AdrWidgetSpectre) {
+		PRINT("ERREUR DRAG N DROP : WIDGET(dragndrop_list_drag_data) INCONNU --> RETOUR\n");
 		return;
 	}
 		
-	Ptr = dragndrop_xcfa_convert_utf8 (string);
-	
-	fileselect_clear_glist ();
+	// ALLOC CHAINE
+	Src = dragndrop_xcfa_convert_utf8 (string);
 	
+	// POINTEUR SUR LA CHAINE TRADUITE
+	Ptr = Src;
 	while (*Ptr)
 	{
-		temp = strchr (Ptr, '\n');
-		if (temp)
-		{
+		if (NULL != (temp = strchr (Ptr, '\n'))) {
 			if (*(temp - 1) == '\r') *(temp - 1) = '\0';
 			*temp = '\0';
 		}
-
-		if (widget == poche.Adr_viewport_image_preview) {
-			if (pochedir_create_glist (Ptr, TRUE)) Bool_add_ok = TRUE;
-		}
+		// if (widget == VarSplit.AdrWidgetSpectre)
+		// 	g_print("PTR = %s\n", Ptr);
+		List = g_slist_append (List, Ptr);
+		Bool_add_ok = TRUE;
 		
-		else {
-			Bool_add_ok = TRUE;
-			/*
-			if (widget == VarSplit.Adr_TreeView) {
-				
-				if (infosong_g_str_has_suffix (Ptr, ".CUE") == TRUE) {
-					
-					splitcue_import_file_cue (Ptr);
-					
-					// UN SEUL FICHIER CUE A LA FOIS
-					break;
-				}
-				else if (fileanalyze_create_glist_analyze_file (NULL, Ptr, FALSE)) Bool_add_ok = TRUE;
-			}
-			else if (fileanalyze_create_glist_analyze_file (NULL, Ptr, FALSE)) Bool_add_ok = TRUE;
-			*/
-			
-			fileselect_set_glist_from_str (Ptr);
-		}
-		
-		if (!temp) break;
+		if (NULL == temp) break;
 
 		Ptr = temp + 1;
 	}
 	
-	if (Bool_add_ok == TRUE) {
+	if (TRUE == Bool_add_ok) {
 	
 		if (widget == var_file.Adr_TreeView) {
 
-			fileanalyze_add_file_to_treeview_ (_TREEVIEW_ALL_, FALSE);
+			fileanalyze_add_file_to_treeview (_PATH_LOAD_FILE_ALL_, List);
 		}
-		else if (widget == VarSplit.Adr_TreeView) {
-		
-			fileanalyze_add_file_to_treeview_ (_TREEVIEW_SPLIT_, TRUE);
-
+		else if (widget == var_file_wav.Adr_TreeView) {
+			
+			fileanalyze_add_file_to_treeview (_PATH_LOAD_FILE_WAV_, List);
+		}
+		else if (widget == var_file_mp3ogg.Adr_TreeView) {
+			
+			fileanalyze_add_file_to_treeview (_PATH_LOAD_FILE_MP3OGG_, List);
+		}
+		else if (widget == var_file_tags.Adr_TreeView) {
+			
+			fileanalyze_add_file_to_treeview (_PATH_LOAD_FILE_TAGS_, List);
 		}
 		else if (widget == poche.Adr_viewport_image_preview) {
-		
-			pochedir_search ();
+			
+			pochedir_add_img_file (List);
 		}
+		else if (widget == VarSplit.AdrWidgetSpectre) {
+			
+			split_load_from_dnd (List);
+		}
+		
+		g_slist_free (List);
+		List = NULL;
 	}
+	
+	// LIBERATION CHAINE
+	g_free (Src);
+	Src = Ptr = NULL;
 }
 
 /* Lors d'un drag and drop, les caracteres sont curieusements transformés en CAR utf-8,
@@ -191,8 +204,6 @@ gchar *dragndrop_xcfa_convert_utf8 (gchar *Texte)
 	gchar     Str [ 8 ];
 	size_t    Len;
 	
-	/* PRINT_FUNC_LF(); */
-
 	/* allocate new string
 	*/
 	Len = strlen (Texte);
@@ -202,8 +213,9 @@ gchar *dragndrop_xcfa_convert_utf8 (gchar *Texte)
 
 	/* delette this 'file://' in old string
 	*/
-	while ( (Ptr_Txt = strstr (Texte, "file://")) != NULL)
+	while (NULL != (Ptr_Txt = strstr (Texte, "file://"))) {
 		strcpy (Ptr_Txt, Ptr_Txt + 7);
+	}
 	Ptr_Txt = Texte;
 
 	Str [ 0 ] = '0';
@@ -218,7 +230,7 @@ gchar *dragndrop_xcfa_convert_utf8 (gchar *Texte)
 			Ptr_Txt ++;
 			Str [ 2 ] = *Ptr_Txt ++;
 			Str [ 3 ] = *Ptr_Txt ++;
-			*Ptr = (gint)utils_hexa_to_int (Str);
+			*Ptr = (gint)libutils_hexa_to_int (Str);
 			Ptr ++;
 		}
 		else {
