@@ -31,14 +31,15 @@
  */
 
 
-#ifndef __dragNdrop_h__
-#define __dragNdrop_h__ 1
+#ifndef dragNdrop_h
+#define dragNdrop_h 1
 
 
 #include <gtk/gtk.h>
 
 
-extern const GtkTargetEntry drag_types [];
+extern	const	GtkTargetEntry drag_types [];
+extern	gint	n_drag_types;
 
 void   dragndrop_list_drag_data (GtkWidget *widget, gchar *string);
 gchar *dragndrop_xcfa_convert_utf8 (gchar *Texte);
