@@ -30,18 +30,26 @@
  * 
  */
 
-
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
-#include "info_song.h"
+
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "config_user.h"
-#include "dvd_audio.h"
+#include "configuser.h"
+#include "dvd.h"
 
 
 /*
@@ -234,8 +242,8 @@ gchar *dvdtable_get (gint channel, gint pan)
 	/* -- MENU VALIDE POUR channel > 2 VERS 2 */
 	if (pan == 2 && channel >= 4) {
 
-		cpt_sub = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvdaudio.Adr_combobox_sub_dvd));
-		cpt_ambiance = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvdaudio.Adr_combobox_ambiance_dvd));
+		cpt_sub = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvd.Adr_combobox_sub_dvd));
+		cpt_ambiance = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvd.Adr_combobox_ambiance_dvd));
 		
 		if (channel == 4) {
 			if (cpt_ambiance == 0) {
