@@ -62,20 +62,29 @@
 
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
-#include <pthread.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
+#include <pthread.h>
 #include "global.h"
 #include "file.h"
 #include "replaygain.h"
+#include "win_scan.h"
 #include "normalise.h"
 
 
@@ -102,89 +111,132 @@ typedef struct {
 FILE_ACTION FileAction;
 
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-void fileaction_set_end (void)
+
+// 
+// 
+void fileaction_set_end (FILEACTION_TYPE FileActionType)
 {
 	FileAction.dedans = FALSE;
+	
+	switch (FileActionType) {
+	case TYPE_REPLAYGAINCLEAR :
+		FileAction.bool_ReplaygainClear =  FALSE;
+		break;
+	case TYPE_NORMALISE :
+		FileAction.bool_normalize       =  FALSE;
+		break;
+	case TYPE_CONVERSION :
+		FileAction.bool_conversion      =  FALSE;
+		break;
+	case TYPE_REPLAYGAINAPPLY :
+		FileAction.bool_ReplaygainApply =  FALSE;
+		break;
+	case TYPE_TRASH :
+		FileAction.bool_trash		=  FALSE;
+		break;
+	}
 }
-
-/*
-*---------------------------------------------------------------------------
-* TIMEOUT
-*---------------------------------------------------------------------------
-*/
+// 
+// 
 static gint fileaction_timeout (gpointer data)
 {
 	if (FileAction.dedans == TRUE) return (TRUE);
 	
+	if (TRUE == conv.bool_stop) {
+		FileAction.bool_ReplaygainClear =  FALSE;
+		FileAction.bool_normalize       =  FALSE;
+		FileAction.bool_conversion      =  FALSE;
+		FileAction.bool_ReplaygainApply =  FALSE;
+		FileAction.bool_trash		=  FALSE;
+	}
+	
 	if (FileAction.bool_ReplaygainClear == TRUE) {
 		FileAction.dedans = TRUE;
-		FileAction.bool_ReplaygainClear = FALSE;
 		replaygain_action (_CLEAR_REPLAYGAIN_);
+		// FileAction.bool_ReplaygainClear = FALSE;
 		return (TRUE);
 	}
 	if (FileAction.bool_normalize == TRUE) {
 		FileAction.dedans = TRUE;
-		FileAction.bool_normalize = FALSE;
-		normalise_file ();
+		normalise_action ();
+		// FileAction.bool_normalize = FALSE;
 		return (TRUE);
 	}
 	if (FileAction.bool_conversion == TRUE) {
 		FileAction.dedans = TRUE;
-		FileAction.bool_conversion = FALSE;
-		fileconv_conversion_file_to_file_action ();
+		fileconv_action ();
+		// FileAction.bool_conversion = FALSE;
 		return (TRUE);
-	}
+	}	
 	if (FileAction.bool_ReplaygainApply == TRUE) {
 		FileAction.dedans = TRUE;
-		FileAction.bool_ReplaygainApply = FALSE;
 		replaygain_action (_APPLY_REPLAYGAIN_);
+		// FileAction.bool_ReplaygainApply = FALSE;
 		return (TRUE);
 	}
-	
 	if (FileAction.bool_trash == TRUE) {
-	    FileAction.dedans = TRUE;
-	    FileAction.bool_trash = FALSE;
+		FileAction.dedans = TRUE;
 		filetrash_action ();
+		// FileAction.bool_trash = FALSE;
 		return (TRUE);
 	}
-	
-	if (!FileAction.bool_ReplaygainClear &&
-	    !FileAction.bool_normalize &&
-	    !FileAction.bool_conversion &&
-	    !FileAction.bool_ReplaygainApply) {
+	if (FALSE == FileAction.bool_ReplaygainClear &&
+	    FALSE == FileAction.bool_normalize &&
+	    FALSE == FileAction.bool_conversion &&
+	    FALSE == FileAction.bool_ReplaygainApply &&
+	    FALSE == FileAction.bool_trash) {
 		
+		WindScan_close ();
 		gtk_timeout_remove (FileAction.handler_timeout);
 	}
 	
 	return (TRUE);
 }
+// 
+// 
+gboolean fileaction_get_bool_Replaygain_Is_Clear (void)
+{
+	GList   *list = NULL;
+	DETAIL  *detail = NULL;
 
-
-
+	list = g_list_first (entetefile);
+	while (list) {
+		if (NULL != (detail = (DETAIL *)list->data)) {
+			if (detail->type_infosong_file_is == FILE_IS_OGG ||
+				detail->type_infosong_file_is == FILE_IS_MP3 ||
+				detail->type_infosong_file_is == FILE_IS_FLAC ||
+				detail->type_infosong_file_is == FILE_IS_WAVPACK) {
+				
+				if (detail->Etat_ReplayGain == RPG_EFFACER) return (TRUE);
+			}
+		}
+		list = g_list_next (list);
+	}
+	return (FALSE);
+}
+// 
+// 
 void fileaction_choice (void)
 {
-	/*PRINT_FUNC_LF();*/
-
 	FileAction.dedans = FALSE;
 	FileAction.NbrFileRemove = 0;
+	conv.bool_stop = FALSE;
 	
-	if ((FileAction.NbrFileRemove = file_verif_existing_file ()) > 0) {
-		file_verif_existing_file_alert (FileAction.NbrFileRemove);
-		return;
-	}
-	
-	FileAction.bool_ReplaygainClear    = file_get_bool_ReplaygainClear_file ();
-	FileAction.bool_normalize          = normalise_individuel ();
-	FileAction.bool_conversion         = file_get_bool_conversion_FILE ();
-	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply_file ();
+	// VERIFICATION DE LA PRESENCE DES FICHIERS SUR LA MEMOIRE DE MASSE
+	file_verify_before_conversion ();
+		
+	FileAction.bool_ReplaygainClear    = fileaction_get_bool_Replaygain_Is_Clear ();
+	FileAction.bool_normalize          = normalise_is_individuel ();
+	FileAction.bool_conversion         = file_get_bool_is_conversion ();
+	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply ();
 	FileAction.bool_trash              = filetrash_ok ();
 	
-	FileAction.handler_timeout = gtk_timeout_add (100, fileaction_timeout, 0);
+	// g_print("FileAction.bool_ReplaygainClear    = %s\n", FileAction.bool_ReplaygainClear ? "TRUE" : "FALSE");
+	// g_print("FileAction.bool_normalize          = %s\n", FileAction.bool_normalize ? "TRUE" : "FALSE");
+	// g_print("FileAction.bool_conversion         = %s\n", FileAction.bool_conversion ? "TRUE" : "FALSE");
+	// g_print("FileAction.bool_ReplaygainApply    = %s\n", FileAction.bool_ReplaygainApply ? "TRUE" : "FALSE");
+	
+	FileAction.handler_timeout = gtk_timeout_add (150, fileaction_timeout, 0);
 }
 
 
