@@ -31,31 +31,32 @@
  */
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <pthread.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "utils.h"
-#include "config_user.h"
-#include "dragNdrop.h"
-#include "info_song.h"
+#include "configuser.h"
+#include "get_info.h"
+#include "win_scan.h"
 #include "file.h"
-#include "options.h"
-#include "fileselect.h"
-#include "popup.h"
-#include "level.h"
-#include "win_control.h"
-#include "win_norm_replay.h"
-#include "secu.h"
 
 
 
@@ -75,7 +76,6 @@ typedef struct {
 	
 	pthread_t        nmr_tid;
 	guint            handler_timeout;
-	guint            handler_timeout_waiting;
 	gboolean         bool_thread_end;
 
 	gboolean         bool_compteur;
@@ -83,35 +83,31 @@ typedef struct {
 	
 	gboolean         bool_update;
 	
+	gboolean	 BoolWindScanUsed;
+	
 } VAR_FILE_SCAN_DB;
 
 VAR_FILE_SCAN_DB VarFileScanDB;
 
-/*
-*---------------------------------------------------------------------------
-* GESTION THREAD & TIMEOUT FOR LEVEL
-*---------------------------------------------------------------------------
-*/
 
 
 
+
+// 
+// 
 static void FileScanDB_thread (void *arg)
 {
-	DETAIL        *detail = NULL;
-	FIC           *fic = NULL;
-	GList         *list = NULL;
-	/*gint		FicLevelMix = ~((gint)gtk_spin_button_get_value (var_file.AdrSpinbuttonNormalise) -1);*/
-	gint		FicLevelMix = (gint)gtk_spin_button_get_value (var_file.AdrSpinbuttonNormalise);
+	DETAIL	*detail = NULL;
+	GList	*list = NULL;
+	gint	FicLevelMix = (gint)gtk_spin_button_get_value (var_file.AdrSpinbuttonNormalise);
 	
  	VarFileScanDB.bool_thread_end = FALSE;
 
 	list = g_list_first (entetefile);
 	while (list) {
 		
-		if ((detail = (DETAIL *)list->data) &&
-		    detail->choice_treeview != _TREEVIEW_SPLIT_ &&
-		    (fic = (FIC *)detail->fic) &&
-		    fic->Etat_Scan == ETAT_SCAN_DEMANDE &&
+		if (NULL != (detail = (DETAIL *)list->data) &&
+		    detail->Etat_Scan == ETAT_SCAN_DEMANDE &&
 		    (detail->type_infosong_file_is == FILE_IS_WAV ||
 		     detail->type_infosong_file_is == FILE_IS_OGG ||
 		     detail->type_infosong_file_is == FILE_IS_MP3)) {
@@ -122,11 +118,11 @@ static void FileScanDB_thread (void *arg)
 
 				VarFileScanDB.bool_compteur = TRUE;
 				
-				fic->LevelMix            = FicLevelMix;
+				detail->LevelMix          = FicLevelMix;
 				info->LevelDbfs.NewLevel = FicLevelMix;
-				info->LevelDbfs.level    = level_get_from (FILE_IS_WAV, detail->namefile);
+				info->LevelDbfs.level    = GetInfo_level_get_from (FILE_IS_WAV, detail->namefile);
 				
-				fic->Etat_Scan = ETAT_SCAN_OK;
+				detail->Etat_Scan = ETAT_SCAN_OK;
 				VarFileScanDB.ElementActif ++;
 				VarFileScanDB.bool_compteur = FALSE;
 				VarFileScanDB.bool_etat = TRUE;
@@ -138,11 +134,11 @@ static void FileScanDB_thread (void *arg)
 				
 				VarFileScanDB.bool_compteur = TRUE;
 			
-				fic->LevelMix            = FicLevelMix;
+				detail->LevelMix          = FicLevelMix;
 				info->LevelDbfs.NewLevel = FicLevelMix;
-				info->LevelDbfs.level    = level_get_from (FILE_IS_OGG, detail->namefile);
+				info->LevelDbfs.level    = GetInfo_level_get_from (FILE_IS_OGG, detail->namefile);
 				
-				fic->Etat_Scan = ETAT_SCAN_OK;
+				detail->Etat_Scan = ETAT_SCAN_OK;
 				VarFileScanDB.ElementActif ++;
 				VarFileScanDB.bool_compteur = FALSE;
 				VarFileScanDB.bool_etat = TRUE;
@@ -154,11 +150,11 @@ static void FileScanDB_thread (void *arg)
 				
 				VarFileScanDB.bool_compteur = TRUE;
 			
-				fic->LevelMix            = FicLevelMix;
+				detail->LevelMix         = FicLevelMix;
 				info->LevelDbfs.NewLevel = FicLevelMix;
-				info->LevelDbfs.level    = level_get_from (FILE_IS_MP3, detail->namefile);
+				info->LevelDbfs.level    = GetInfo_level_get_from (FILE_IS_MP3, detail->namefile);
 				
-				fic->Etat_Scan = ETAT_SCAN_OK;
+				detail->Etat_Scan = ETAT_SCAN_OK;
 				VarFileScanDB.ElementActif ++;
 				VarFileScanDB.bool_compteur = FALSE;
 				VarFileScanDB.bool_etat = TRUE;
@@ -169,103 +165,75 @@ static void FileScanDB_thread (void *arg)
 	} 
 	
 	VarFileScanDB.bool_thread_end = TRUE;
-	secu_thread_sub ();
 	pthread_exit(0);
 }
-
+// 
+// 
 static gint FileScanDB_timeout (gpointer data)
 {
-	if (WinNormReplay_is_get_close () == TRUE) {
-		conv_stop_conversion ();
-	}
-	
-	if (level_bool_percent () == TRUE) {
-		VarFileScanDB.total_percent = (double)(VarFileScanDB.ElementActif +1) / (double)VarFileScanDB.NbrElementsInList;
-		WinNormReplay_set_data_progressBar (VarFileScanDB.total_percent);
-	}
-	
 	if (VarFileScanDB.bool_etat == TRUE) {
-		/*WinNormReplay_set_etat (VarFileScanDB.MessUser);*/
 		g_free (VarFileScanDB.MessUser);
 		VarFileScanDB.MessUser = NULL;
 		VarFileScanDB.bool_etat = FALSE;
 	}
 	
-	if (VarFileScanDB.bool_compteur == TRUE) {
+	if (FALSE == VarFileScanDB.BoolWindScanUsed && VarFileScanDB.bool_compteur == TRUE) {
 		
 		gchar *str = NULL;
     		gchar *spinner="|/-\\";
-		// gchar *Ptr = NULL;
 		gchar  foo [ 2 ];
 		
 		foo [ 0 ] = spinner[VarFileScanDB.pass_conv++%4];
 		foo [ 1 ] = '\0';
-		// Ptr = utils_convert_string (foo, TRUE);
 		
 		str = g_strdup_printf ("<b>En cours: %d sur %d   %s</b>",
 					VarFileScanDB.ElementActif +1,
 					VarFileScanDB.NbrElementsInList,
 					foo
 					);
-		WinNormReplay_set_compteur (str);
+		WindScan_set_label (str);
+		g_free (str);
+		str = NULL;
+		VarFileScanDB.total_percent = (double)(VarFileScanDB.ElementActif +1) / (double)VarFileScanDB.NbrElementsInList;
+		str = g_strdup_printf ("%d%%", (int)(VarFileScanDB.total_percent*100));
+		WindScan_set_progress (str, VarFileScanDB.total_percent);
 		g_free (str);
 		str = NULL;
-		// g_free (Ptr);
-		// Ptr = NULL;
 	}
 	
 	if (VarFileScanDB.bool_update == TRUE) {
 		VarFileScanDB.bool_update = FALSE;
-		file_pixbuf_update_glist_file ();
+		file_pixbuf_update_glist ();
 		return (TRUE);
 	}
 	
 	if (VarFileScanDB.bool_thread_end == TRUE) {
-		WinNormReplay_close ();
+		if (FALSE == VarFileScanDB.BoolWindScanUsed) WindScan_close ();
 		gtk_timeout_remove (VarFileScanDB.handler_timeout);
-		conv_set_struct_not_used ();
 	}
 	
 	return (TRUE);
 }
-
-static gint FileScanDB_timeout_waiting (gpointer data)
-{
-	if (conv_struct_is_used () == FALSE) {
-		
-		gtk_timeout_remove (VarFileScanDB.handler_timeout_waiting);
-
-		if (file_set_scan () > 0) {
-		
-			g_snprintf (conv.valuenice ,    4, "%d", options_get_val_nice ());
-			
-			VarFileScanDB.bool_thread_end = FALSE;
-			VarFileScanDB.bool_etat = FALSE;
-			VarFileScanDB.NbrElementsInList = 1;
-			VarFileScanDB.ElementActif = 0;
-			VarFileScanDB.bool_compteur = FALSE;
-			VarFileScanDB.pass_conv = -1;
-			VarFileScanDB.bool_update = FALSE;
-			VarFileScanDB.MessUser = NULL;
-			
-			/* Tous les fichiers wav, mp3 et ogg sont a scanner */
-			/*if (BoolAllScan == TRUE) VarFileScanDB.NbrElementsInList = file_set_scan ();*/
-			VarFileScanDB.NbrElementsInList = file_set_scan ();
-			
-			conv_reset_struct ();
-			WinNormReplay_Create ("Scan DB");
-			WinNormReplay_reset_progressBar ();
-			secu_thread_add ();
-			VarFileScanDB.handler_timeout = gtk_timeout_add (100, FileScanDB_timeout, 0);
-			pthread_create (&VarFileScanDB.nmr_tid, NULL ,(void *)FileScanDB_thread, (void *)NULL);
-		}
-	}
-	return (TRUE);
-}
-
+// 
+// 
 void FileScanDB_action (gboolean BoolAllScan)
 {
-	VarFileScanDB.handler_timeout_waiting = gtk_timeout_add (100, FileScanDB_timeout_waiting, 0);
+	PRINT_FUNC_LF();
+	
+	// SI DES FICHIERS wav, mp3 et ogg PRET POUR LE SCAN
+	if ((VarFileScanDB.NbrElementsInList =  file_get_scan ()) > 0) {
+		VarFileScanDB.bool_thread_end = FALSE;
+		VarFileScanDB.bool_etat = FALSE;
+		VarFileScanDB.ElementActif = 0;
+		VarFileScanDB.bool_compteur = FALSE;
+		VarFileScanDB.pass_conv = -1;
+		VarFileScanDB.bool_update = FALSE;
+		VarFileScanDB.MessUser = NULL;
+		
+		VarFileScanDB.BoolWindScanUsed = WindScan_open ("Scan dBFS", WINDSCAN_PULSE);
+		VarFileScanDB.handler_timeout = gtk_timeout_add (50, FileScanDB_timeout, 0);
+		pthread_create (&VarFileScanDB.nmr_tid, NULL ,(void *)FileScanDB_thread, (void *)NULL);
+	}
 }
 
 
