@@ -35,26 +35,25 @@
 #  include <config.h>
 #endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <pthread.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "utils.h"
-#include "config_user.h"
-#include "dragNdrop.h"
-#include "info_song.h"
+#include "win_scan.h"
 #include "file.h"
-#include "options.h"
-#include "fileselect.h"
-#include "popup.h"
-#include "level.h"
-#include "win_norm_replay.h"
-#include "win_control.h"
 
 
 /*
@@ -81,7 +80,7 @@ typedef struct {
 	
 	gboolean         bool_set_end_of_user;
 	
-	gchar            PathNameTrash [ 256 ];
+	gchar            PathNameTrash [ 1024 ];
 	
 } VAR_FILE_TRASH;
 
@@ -98,32 +97,6 @@ Kubuntu et Xubuntu
 	$HOME/.local/share/Trash/files
 
 */
-gboolean filetrash_test_desktop_is_kde (void)
-{
-	FILE       *fp;
-#define MAX_CARS_KDE 255
-	gchar       buf   [ MAX_CARS_KDE +1 ];
-	gboolean    BoolRet = FALSE;
-	gint	 Dummy;
-	
-	/*
-	KDE_FULL_SESSION
-	*/
-	Dummy = system ("env | grep \"KDE_FULL_SESSION\" > /tmp/tst_kde_full_session.txt");
-	if ((fp = fopen ("/tmp/tst_kde_full_session.txt", "r")) != NULL) {
-		while (fgets (buf, MAX_CARS_KDE, fp) != NULL) {
-			if (strcmp (buf, "KDE_FULL_SESSION") == 0) {
-				if (strcmp (buf, "true") == 0 || strcmp (buf, "TRUE") == 0) {
-					BoolRet = TRUE;
-					break;
-				}
-			}
-		}
-		fclose (fp);
-	}
-	infosong_delete_file ("/tmp/tst_kde_full_session.txt");
-	return (BoolRet);	
-}
 
 
 
@@ -144,12 +117,42 @@ void filetrash_test (gchar *Name)
  
 
 
+// 
+// 
+gboolean filetrash_test_desktop_is_kde (void)
+{
+	FILE		*fp;
+#define MAX_CARS_KDE 255
+	gchar		buf   [ MAX_CARS_KDE +1 ];
+	gboolean	BoolRet = FALSE;
+	gint		Dummy;
+	
+	/*
+	KDE_FULL_SESSION
+	*/
+	Dummy = system ("env | grep \"KDE_FULL_SESSION\" > /tmp/tst_kde_full_session.txt");
+	if ((fp = fopen ("/tmp/tst_kde_full_session.txt", "r")) != NULL) {
+		while (fgets (buf, MAX_CARS_KDE, fp) != NULL) {
+			if (strcmp (buf, "KDE_FULL_SESSION") == 0) {
+				if (strcmp (buf, "true") == 0 || strcmp (buf, "TRUE") == 0) {
+					BoolRet = TRUE;
+					break;
+				}
+			}
+		}
+		fclose (fp);
+	}
+	g_unlink ("/tmp/tst_kde_full_session.txt");
+	return (BoolRet);	
+}
+// 
+// 
 gboolean filetrash_move_to_trash (gchar *Name)
 {
-	gchar     *NameDest = NULL;
-	gchar     *Ptr = NULL;
-	gchar     *LineCommand = NULL;
-	gint	 Dummy;
+	gchar	*NameDest = NULL;
+	gchar	 *Ptr = NULL;
+	gchar	*LineCommand = NULL;
+	gint	Dummy;
 	
 	/*PRINT_FUNC_LF();*/
 	
@@ -171,7 +174,8 @@ gboolean filetrash_move_to_trash (gchar *Name)
 	
 	return (TRUE);
 }
-
+// 
+// 
 gchar *filetrash_get_trash (void)
 {
 	if (var_filetrash.Bool_kde_full_session == TRUE)
@@ -180,7 +184,8 @@ gchar *filetrash_get_trash (void)
 
 	return ((gchar *)var_filetrash.PathNameTrash);
 }
-
+// 
+// 
 void filetrash_test_trash_is_ok (void)
 {
 	gboolean      BoolExistTrashOLD;
@@ -198,7 +203,7 @@ void filetrash_test_trash_is_ok (void)
 	g_print ("KDE SESSION : %s\n", var_filetrash.Bool_kde_full_session ? "TRUE" : "FALSE");
 
 	Path = g_strdup_printf ("%s/.Trash", getenv ("HOME"));
-	BoolExistTrashOLD = infosong_file_is_dir (Path);
+	BoolExistTrashOLD = libutils_test_dir_exist (Path);
 	if (BoolExistTrashOLD == TRUE)
 		g_print ("EXIST ......: %s\n", Path);
 	else	g_print ("NOT EXIST ..: %s\n", Path);
@@ -206,7 +211,7 @@ void filetrash_test_trash_is_ok (void)
 	Path = NULL;
 	
 	Path = g_strdup_printf ("%s/.local/share/Trash/files", getenv ("HOME"));
-	BoolExistTrashNEW = infosong_file_is_dir (Path);
+	BoolExistTrashNEW = libutils_test_dir_exist (Path);
 	if (BoolExistTrashNEW == TRUE)
 		g_print ("EXIST ......: %s\n", Path);
 	else	g_print ("NOT EXIST ..: %s\n", Path);
@@ -239,34 +244,30 @@ void filetrash_test_trash_is_ok (void)
 		else {
 			
 		}
-	
 	}
 	
 	g_print ("---\nUSE ........: %s\n---\n\n", filetrash_get_trash ());
 }
-
+// 
+// 
 static void filetrash_thread (void *arg)
 {
 	GList     *list = NULL;
 	DETAIL    *detail = NULL;
-	FIC       *fic = NULL;
 
 	var_filetrash.bool_thread_end = FALSE;
 	var_filetrash.bool_pass_conv = TRUE;
 	list = g_list_first (entetefile);
 	while (list) {
-		if ((detail = (DETAIL *)list->data)) {
-			if ((fic = (FIC *)detail->fic)) {
-				if (fic->EtatTrash == FILE_TRASH_VERIF_OK) {
+		if (NULL != (detail = (DETAIL *)list->data)) {
+			if (detail->EtatTrash == FILE_TRASH_VERIF_OK) {
 
-					var_filetrash.ElementActif ++;
-					var_filetrash.BoolEtat = TRUE;
+				var_filetrash.ElementActif ++;
+				var_filetrash.BoolEtat = TRUE;
 
-					if (filetrash_move_to_trash (detail->namefile) == TRUE) {
-						detail->remove = STRUCT_FIC_REMOVE;
-					}
+				if (filetrash_move_to_trash (detail->namefile) == TRUE) {
+					detail->BoolRemove = TRUE;
 				}
-				
 			}
 		}
 		list = g_list_next (list);
@@ -276,12 +277,13 @@ static void filetrash_thread (void *arg)
 	
 	pthread_exit(0);
 }
-
+// 
+// 
 static gint filetrash_timeout (gpointer data)
 {
-	if (WinNormReplay_is_get_close () == TRUE) {
-		var_filetrash.bool_thread_end = TRUE;
-	}
+	// if (TRUE == WindScan_close_request (void)) {
+	// 	var_filetrash.bool_thread_end = TRUE;
+	// }
 	
 	if (var_filetrash.bool_pass_conv == TRUE) {
 
@@ -297,63 +299,67 @@ static gint filetrash_timeout (gpointer data)
 					var_filetrash.nbr_trash,
 					foo
 					);
-		WinNormReplay_set_compteur (str);
+		WindScan_set_label (str);
 		g_free (str);
 		str = NULL;
 	}
 	
 	if (var_filetrash.BoolEtat == TRUE) {
 		
-		var_filetrash.total_percent = (double)((double)var_filetrash.ElementActif / (double)var_filetrash.nbr_trash);
-		WinNormReplay_set_data_progressBar (var_filetrash.total_percent);
+		gchar	*Str = NULL;
 		
+		var_filetrash.total_percent = (double)((double)var_filetrash.ElementActif / (double)var_filetrash.nbr_trash);
+		Str = g_strdup_printf ("%d%%", (int)(var_filetrash.total_percent * 100));
+		WindScan_set_progress (Str, var_filetrash.total_percent);
+		g_free (Str);
+		Str = NULL;
 		var_filetrash.BoolEtat = FALSE;
 		return (TRUE);
 	}
 	
 	if (var_filetrash.bool_thread_end == TRUE) {
-		WinNormReplay_close ();
-		fileaction_set_end ();
+
+		WindScan_close ();
+		
+		fileaction_set_end (TYPE_TRASH);
 		gtk_timeout_remove (var_filetrash.handler_timeout);
-		fileanalyze_modify_glist_entetefile ();
+		on_file_button_del_file_clicked (NULL, NULL);
 	}
 	return (TRUE);
 }
-
+// 
+// 
 void filetrash_action (void)
 {
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	var_filetrash.bool_thread_end = FALSE;
 	var_filetrash.ElementActif     = 0;
 	var_filetrash.BoolEtat        = FALSE;
 	var_filetrash.bool_pass_conv   = FALSE;
 	
-	WinNormReplay_Create (_("Trash"));
-	WinNormReplay_reset_progressBar ();
+	WindScan_open (_("Trash"), WINDSCAN_PULSE);
+	WindScan_set_label (_("<b><i>Trash files ...</i></b>"));
 		
 	pthread_create (&var_filetrash.nmr_tid, NULL ,(void *)filetrash_thread, (void *)NULL);
 	var_filetrash.handler_timeout = gtk_timeout_add (100, filetrash_timeout, 0);
 }
-
+// 
+// 
 gboolean filetrash_ok (void)
 {
 	GList     *list = NULL;
 	DETAIL    *detail = NULL;
-	FIC       *fic = NULL;
 	gboolean   BoolTrash = FALSE;
 		
 	var_filetrash.nbr_trash = 0;
 	
 	list = g_list_first (entetefile);
 	while (list) {
-		if ((detail = (DETAIL *)list->data)) {
-			if ((fic = (FIC *)detail->fic)) {
-			
-				if (fic->EtatTrash != FILE_TRASH_NONE) {
-					BoolTrash = TRUE;
-					var_filetrash.nbr_trash ++;
-				}
+		if (NULL != (detail = (DETAIL *)list->data)) {
+			if (detail->EtatTrash != FILE_TRASH_NONE) {
+				BoolTrash = TRUE;
+				var_filetrash.nbr_trash ++;
 			}
 		}
 		list = g_list_next (list);
