@@ -31,28 +31,22 @@
  */
 
 
-#ifndef __fileselect_h__
-#define __fileselect_h__ 1
+#ifndef fileselect_h
+#define fileselect_h 1
 
 
 typedef enum {
 
-	_PATH_DESTINATION_CD_ = 0,
-	_PATH_DESTINATION_DVD_,
-	_PATH_DESTINATION_FILE_,
-	_PATH_DESTINATION_FILE_WAV_,
-	_PATH_DESTINATION_FILE_MP3OGG_,
-	_PATH_DESTINATION_SPLIT_,
-	_PATH_LOAD_FILE_,
-	_PATH_IMPORT_FILE_WAV_,
-	_PATH_IMPORT_FILE_MP3OGG_,
-	_PATH_IMPORT_FILE_SPLIT_,
+	_PATH_CHOICE_DESTINATION_ = 0,
+	_PATH_LOAD_SPLIT_FILE_,
+	_PATH_LOAD_ONE_FILE_,
+	_PATH_LOAD_FILE_ALL_,
+	_PATH_LOAD_FILE_WAV_,
+	_PATH_LOAD_FILE_MP3OGG_,
+	_PATH_LOAD_FILE_TAGS_,
 	_PATH_IMPORT_IMAGES_,
 	_PATH_STOCKE_IMAGES_POCHETTE_,
 	_PATH_DEST_FILE_POSTSCRIPT_,
-	_PATH_LOAD_DVD_FROM_DIRECTORY_,
-	_PATH_TEMP_,
-	_PATH_DEST_JOURNAL_,
 
 	_NB_PATH_                       /* Do Not Use This Var, It's reserved */
 
@@ -60,7 +54,7 @@ typedef enum {
 
 
 void     fileselect_remove_comment (void);
-void	 fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern);
+void	 fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Extern);
 void	 fileselect_clear_glist (void);
 GList	*fileselect_set_glist_from_str (gchar *p_str);
 GList   *fileselect_get_glist (void);
