@@ -1,11 +1,11 @@
  /*
  * file      : global.h
- * project   : xcfa
+ * project   : BaseBuild
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2010 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
+ * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,33 +39,69 @@
 #include <glib/gi18n.h>
 
 
+extern	GtkBuilder	*GtkXcfaProjet;
+extern	GtkWidget	*WindMain;
 
-void	segfault_handler_mess_error (gchar *p_mess);
+void main_puts_statusbar_global (gchar *mess_label_status);
 
-extern	GtkBuilder	*GtkBuilderXcfa;
+/* This is used to create the pixmaps used in the interface. */
+GtkWidget *create_pixmap (GtkWidget *widget, const gchar *filename);
 
 
-typedef struct {
-	GtkWidget	*AdrWin;
-	gboolean	 Bool;
-} WIND_MAIN;
 
-extern WIND_MAIN wind_main;
-
-extern gboolean BoolWindErrorActivate;
-
-#define XCFA_GET_OBJECT(OBJ) gtk_builder_get_object (GtkBuilderXcfa, OBJ)
+#define GLADE_GET_OBJECT(OBJ) gtk_builder_get_object (GtkXcfaProjet, OBJ)
 
+/*
+*---------------------------------------------------------------------------
+* NOTEBOOK
+*---------------------------------------------------------------------------
+*/
+// notebook_general
+#define NOTEBOOK_DVD_AUDIO	0
+#define NOTEBOOK_CD_AUDIO	1
+	// notebook_expander_cd
+	#define NOTEBOOK_CD_AUDIO_TAGS		0
+	#define NOTEBOOK_CD_AUDIO_TITRE_CD	1
+	#define NOTEBOOK_CD_AUDIO_CUE		2
+#define NOTEBOOK_FICHIERS	2
+	// notebook_in_file
+	#define NOTEBOOK_FICHIERS_CONVERSION	0
+	#define NOTEBOOK_FICHIERS_WAV		1
+	#define NOTEBOOK_FICHIERS_MP3OGG	2	
+	#define NOTEBOOK_FICHIERS_TAGS		3
+#define NOTEBOOK_SPLIT		3
+#define NOTEBOOK_POCHETTE	4
+	// 
+	#define NOTEBOOK_POCHETTE_IMAGE		0
+	#define NOTEBOOK_POCHETTE_TITRE		1
+	#define NOTEBOOK_POCHETTE_TEXTE		2
+#define NOTEBOOK_OPTIONS	5
+	// notebook_options
+	#define NOTEBOOK_OPTIONS_GENERAL	0
+	#define NOTEBOOK_OPTIONS_CD_AUDIO	1
+	#define NOTEBOOK_OPTIONS_LAME		2
+	#define NOTEBOOK_OPTIONS_OGGENC		3
+	#define NOTEBOOK_OPTIONS_FLAC		4
+	#define NOTEBOOK_OPTIONS_MAC		5
+	#define NOTEBOOK_OPTIONS_WAVPACK	6
+	#define NOTEBOOK_OPTIONS_MUSEPACK	7
+	#define NOTEBOOK_OPTIONS_FAAC		8
+	#define NOTEBOOK_OPTIONS_AACPLUSENC	9
+	#define NOTEBOOK_OPTIONS_EXPORT_TAGS	10
+#define NOTEBOOK_PRGEXTERNES	6
+	// notebook_app_externes
+	#define NOTEBOOK_OPTIONS_PRGEXTERNES	0
+	#define NOTEBOOK_OPTIONS_EXTRA		1
 
 /*
 *---------------------------------------------------------------------------
 * DEBUG
 *---------------------------------------------------------------------------
 */
+#define PRINT_FUNC_LF() g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__)
 #define PRINTINT(str,num) g_print ("%s = %d\n", str, num)
 #define PRINTBOOL(str,bool) g_print ("%s = %s\n", str, bool == TRUE ? "TRUE" : "FALSE")
-#define PRINT_FUNC_LF() g_print ("%s :: %s (line = %d) \n", __FILE__, __FUNCTION__, __LINE__)
-#define PRINT(str) g_print ("%s -:- %s(line = %d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)
+#define PRINT(str) g_print ("%s :: %s(line = %d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)
 
 /*
 *---------------------------------------------------------------------------
@@ -83,90 +119,16 @@ extern gboolean BoolWindErrorActivate;
   g_object_set_data (G_OBJECT (component), name, widget)
 #endif
 
-/*
- * Standard gettext macros.
- */
-/*
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  define Q_(String) g_strip_context ((String), gettext (String))
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define Q_(String) g_strip_context ((String), (String))
-#  define N_(String) (String)
-#endif
-*/
-
-/* Use this function to set the directory containing installed pixmaps. */
-void add_pixmap_directory (const gchar *directory);
-/* This is used to create the pixmaps used in the interface. */
-GtkWidget *create_pixmap (GtkWidget *widget, const gchar *filename);
 
 /*
 *---------------------------------------------------------------------------
-* TEMPS
+* ALSA_PLAY.C
+* SPLIT_SPECTRE.C
 *---------------------------------------------------------------------------
 */
-#define GETTIMESEC(H,M,S,C) (gdouble)((H * 60) * 60) + (gdouble)(M * 60) + (gdouble)S + (gdouble)(C / 100.0)
-#define GETTIMEPERCENT(SecondesTempsActuel,AllTime) ((gdouble)SecondesTempsActuel / (gdouble)AllTime) * 100.0
-
-/*
-*---------------------------------------------------------------------------
-* NOTEBOOK
-*---------------------------------------------------------------------------
-*/
-
-#define NOTEBOOK_DVD_AUDIO	0
-#define NOTEBOOK_CD_AUDIO	1
-	#define NOTEBOOK_CD_AUDIO_TAGS		0
-	#define NOTEBOOK_CD_AUDIO_TITRE_CD	1
-	#define NOTEBOOK_CD_AUDIO_CUE		2
-#define NOTEBOOK_FICHIERS	2
-	#define NOTEBOOK_FICHIERS_CONVERSION	0
-	#define NOTEBOOK_FICHIERS_WAV		1
-	#define NOTEBOOK_FICHIERS_MP3OGG	2
-	#define NOTEBOOK_FICHIERS_TAGS		3
-#define NOTEBOOK_SPLIT		3
-#define NOTEBOOK_POCHETTE	4
-	#define NOTEBOOK_POCHETTE_IMAGE		0
-	#define NOTEBOOK_POCHETTE_TITRE		1
-	#define NOTEBOOK_POCHETTE_TEXTE		2
-#define NOTEBOOK_OPTIONS	5
-	#define NOTEBOOK_OPTIONS_GENERAL	0
-	#define NOTEBOOK_OPTIONS_CD_AUDIO	1
-	#define NOTEBOOK_OPTIONS_LAME		2
-	#define NOTEBOOK_OPTIONS_OGGENC		3
-	#define NOTEBOOK_OPTIONS_FLAC		4
-	#define NOTEBOOK_OPTIONS_MAC		5
-	#define NOTEBOOK_OPTIONS_WAVPACK	6
-	#define NOTEBOOK_OPTIONS_MUSEPACK	7
-	#define NOTEBOOK_OPTIONS_FAAC		8
-	#define NOTEBOOK_OPTIONS_AACPLUSENC	9
-	#define NOTEBOOK_OPTIONS_EXPORT_TAGS	10
-#define NOTEBOOK_PRGEXTERNES	6
-	#define NOTEBOOK_OPTIONS_PRGEXTERNES	0
-	#define NOTEBOOK_OPTIONS_PRGNAVIGATOR	1
-	#define NOTEBOOK_OPTIONS_PRGPOSTSCRIPT	2
-	#define NOTEBOOK_OPTIONS_PRGAUDIO	3
-
-
-
-/* Taille des caracteres dans la Statusbarre
-*/
-#define SIZE_CAR_STATUSBAR 9
+#define BLOCK_SIZE	2352
 
+// gdkkeysyms.h
 /*
 GDK_NOTHING		a special code to indicate a null event.
 GDK_KEY_PRESS		a key has been pressed.
@@ -209,11 +171,14 @@ typedef struct {
 	gboolean	BoolGDK_Right;		/* TRUE is PRESS else is RELEASE			*/
 	
 	gboolean	BoolGDK_Control_A;	/* TRUE is PRESS else is RELEASE			*/
+/*
+#define GDK_space 0x020
+*/
+	gboolean	BoolGDK_space;
 } KEYS;
 
 extern KEYS keys;
 
-
 typedef struct {
 	gchar      Machine [ 100 ];
 	gint       NbCpu;
@@ -225,8 +190,6 @@ typedef struct {
 extern HOST_CONF HostConf;
 
 
-
-
 /*
 *---------------------------------------------------------------------------
 * Dossier temporaire
@@ -234,9 +197,8 @@ extern HOST_CONF HostConf;
 */
 
 #define PATH_TMP_XCFA_CD_NORMALISE_PEAK_ALBUM "xcfa_peak_album"
-#define PATH_TMP_XCFA_SPLIT "xcfa_split"
 
-#define PATH_TMP_XCFA_SHNSPLIT "xcfa_shnsplit"
+#define PATH_TMP_XCFA_WAVSPLIT "xcfa_wavsplit"
 
 #define PATH_TMP_XCFA_AUDIOCD "xcfa_cdaudio"
 
