@@ -32,11 +32,17 @@
 
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <pthread.h>
 #include <sys/wait.h>
 #include <sys/types.h>
@@ -45,15 +51,14 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <stdlib.h>
 #include <string.h>
+ 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
 #include "global.h"
-#include "info_song.h"
-#include "win_play.h"
-#include "split.h"
-#include "options.h"
-#include "dvd_audio.h"
+#include "configuser.h"
 #include "mplayer.h"
 
 
@@ -68,6 +73,8 @@ VAR_MPLAYER VarMplayer;
 
 
 
+
+
 /*
 *---------------------------------------------------------------------------
 * EXTERNAL REF
@@ -75,11 +82,11 @@ VAR_MPLAYER VarMplayer;
 */
 extern int kill(pid_t pid, int sig);
 
-/*
-*---------------------------------------------------------------------------
-* SIGNAL ET EXECUTE EXTERNAL
-*---------------------------------------------------------------------------
-*/
+
+
+
+// SIGNAL ET EXECUTE EXTERNAL
+// 
 void mplayer_sigchld (gint signum)
 {
 	gint status;
@@ -93,7 +100,9 @@ void mplayer_sigchld (gint signum)
                 signal (SIGCHLD, mplayer_sigchld);
         }
 }
-int mplayer_call_exec (MPLAYER_ARGS *args, pid_t *p, gint p_output)
+// 
+// 
+int mplayer_call_exec (gchar **args, pid_t *p, gint p_output)
 {
 	gchar **ptr = (gchar **)args;
 
@@ -117,42 +126,67 @@ int mplayer_call_exec (MPLAYER_ARGS *args, pid_t *p, gint p_output)
 	return (VarMplayer.Tube [ 0 ]);
 }
 
-/*
-*---------------------------------------------------------------------------
-* FIFO CREATE and REMOVE
-*---------------------------------------------------------------------------
-*/
+// FIFO CREATE and REMOVE
+// 
 void mplayer_remove_list_args (void)
 {
 	gint	 PosArg = 0;
 
-	if (VarMplayer.PlayerArgs != NULL) {
-		for (PosArg = 0; VarMplayer.PlayerArgs[ PosArg ].str != NULL; PosArg ++) {
-			g_free (VarMplayer.PlayerArgs[ PosArg ].str);
-			VarMplayer.PlayerArgs[ PosArg ].str = NULL;
-		}
-		g_free (VarMplayer.PlayerArgs);
-		VarMplayer.PlayerArgs = NULL;
+	for (PosArg = 0; NULL != VarMplayer.PlayerArgs[ PosArg ]; PosArg ++) {
+		g_free (VarMplayer.PlayerArgs[ PosArg ]);
+		VarMplayer.PlayerArgs[ PosArg ] = NULL;
 	}
 }
+// 
+// 
+/*
+ man -k mkfifo 
+mkfifo (1)           - Créer des tubes nommés (FIFO)
+mkfifo (3)           - Créer un fichier spécial FIFO
+mkfifoat (3)         - Créer une FIFO (un tube nommé) relatif à un descripteur de fichier d'un répertoire
+
+NOM
+       mkfifo - Créer un fichier spécial FIFO
+
+SYNOPSIS
+       #include <sys/types.h>
+       #include <sys/stat.h>
+
+       int mkfifo(const char *pathname, mode_t mode);
+
+DESCRIPTION
+       La  fonction mkfifo() crée un fichier spécial FIFO (tube nommé)  à l’emplacement pathname. mode indique les permissions d’accès. Ces permissions sont modifiées par la
+       valeur d’umask du processus : les permissions d’accès effectivement adoptées sont (mode & ~umask).
+
+       L’ouverture d’un FIFO en lecture est généralement  bloquante,  jusqu’à  ce qu’un autre processus ouvre le même FIFO en écriture, et inversement.
+*/
 void mplayer_create_fifo (void)
+{
+	 if (0 == mkfifo(XCFA_TMP_FIFO, 0644)) {
+	 	gint	status;
+		gint	descripteur;
+	 	
+	 	descripteur = open (XCFA_TMP_FIFO, O_RDWR);
+	 	status = fcntl(descripteur, F_GETFL);
+	 	status = fcntl(descripteur, F_SETFL, status | O_NONBLOCK);
+	 	close (descripteur);
+	 }
+}
+/*
+void OLD_mplayer_create_fifo (void)
 {
 	gchar *args[ 10 ];
 	gint   pos = 0;
 	gint   status;
-	pid_t  NumFork;		
+	pid_t  NumFork;
 
-	if (infosong_access_mode (AM_FILE_EXIST, XCFA_TMP_FIFO, NULL) == TRUE) return;
+	if (TRUE == libutils_access_mode (XCFA_TMP_FIFO)) return;
 
 	args [ pos++ ] = "mkfifo";
 	args [ pos++ ] = XCFA_TMP_FIFO;
 	args [ pos++ ] = NULL;
 	args [ pos++ ] = NULL;
-	/*
-	for (pos = 0; args[ pos ] != NULL; pos++)
-		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
-	g_print ("\n");
-	*/
+
 	if ((NumFork = fork ()) == 0) {
 		execvp (args[0], args);
 		exit (2);
@@ -160,25 +194,30 @@ void mplayer_create_fifo (void)
 
 	waitpid (NumFork, &status, WUNTRACED);
 }
+*/
+// 
+// 
 void mplayer_remove_fifo (void)
+{
+	if (FALSE == libutils_access_mode (XCFA_TMP_FIFO)) return;
+	g_unlink (XCFA_TMP_FIFO);
+}
+/*
+void OLD_mplayer_remove_fifo (void)
 {
 	gchar *args[ 10 ];
 	gint   pos = 0;
 	gint   status;
 	pid_t  NumFork;		
 
-	if (infosong_access_mode (AM_FILE_EXIST, XCFA_TMP_FIFO, NULL) == FALSE) return;
+	if (FALSE == libutils_access_mode (XCFA_TMP_FIFO)) return;
 
 	args [ pos++ ] = "rm";
 	args [ pos++ ] = "-rf";
 	args [ pos++ ] = XCFA_TMP_FIFO;
 	args [ pos++ ] = NULL;
 	args [ pos++ ] = NULL;
-	/*
-	for (pos = 0; args[ pos ] != NULL; pos++)
-		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
-	g_print ("\n");
-	*/
+
 	if ((NumFork = fork ()) == 0) {
 		execvp (args[0], args);
 		exit (2);
@@ -188,18 +227,16 @@ void mplayer_remove_fifo (void)
 	
 	mplayer_remove_list_args ();
 }
-
-/*
-*---------------------------------------------------------------------------
-* FIFO COMMAND
-*---------------------------------------------------------------------------
 */
+// FIFO COMMAND
+// 
 void mplayer_set_fifo (gchar *str)
 {
 	if (VarMplayer.BoolErreurMplayer == TRUE) return;
 	if (VarMplayer.BoolThreadActivate == FALSE) return;
+	
+	if (TRUE == libutils_access_mode (XCFA_TMP_FIFO)) {
 
-	if (infosong_access_mode (AM_FILE_EXIST, XCFA_TMP_FIFO, NULL) == TRUE) {
 		FILE *fp = NULL;
 		if ((fp = fopen (XCFA_TMP_FIFO, "w")) != NULL) {
 			fprintf (fp, "%s\n", str);
@@ -207,30 +244,43 @@ void mplayer_set_fifo (gchar *str)
 		}
 	}
 }
+// 
+// 
 void mplayer_fifo_quit (void)
 {
 	mplayer_set_fifo ("quit");
-	VarMplayer.ListPlayFrom   = LIST_MPLAYER_FROM_NONE;
-	VarMplayer.BoolPushButton = PUSH_BUTTON_MPLAYER_STOP;
-	g_usleep (500000);
+	// VarMplayer.TypeButtonPush = PUSH_BUTTON_MPLAYER_STOP;
+	// g_usleep (500000);
+	VarMplayer.BoolIsPause = FALSE;
 }
+// 
+// 
 void mplayer_fifo_pause (void)
 {
-	VarMplayer.BoolPushButton = PUSH_BUTTON_MPLAYER_PAUSE;
+	// VarMplayer.TypeButtonPush = PUSH_BUTTON_MPLAYER_PAUSE;
+	VarMplayer.BoolIsPause = TRUE;
 	mplayer_set_fifo ("pause");
 }
+// 
+// 
 void mplayer_fifo_get_percent_pos (void)
 {
 	mplayer_set_fifo ("get_percent_pos");
 }
+// 
+// 
 void mplayer_fifo_get_time_pos (void)
 {
 	mplayer_set_fifo ("get_time_pos");
 }
+// 
+// 
 void mplayer_fifo_get_time_length (void)
 {
 	mplayer_set_fifo ("get_time_length");
 }
+// 
+// 
 void mplayer_fifo_seek (gdouble PercentValue)
 {
 	gchar *Str = NULL;
@@ -238,13 +288,17 @@ void mplayer_fifo_seek (gdouble PercentValue)
 	
 	if (PercentValue < 0.0) PercentValue = 0.0;
 	if (PercentValue > 100.0) PercentValue = 100.0;
-	
+	// VarMplayer.TypeButtonPush = PUSH_BUTTON_MPLAYER_PLAY;
+	VarMplayer.BoolIsPause = FALSE;
+
 	sec = (gint) ((VarMplayer.DOUBLE_TempsTotal * PercentValue) / 100.0);
 	Str = g_strdup_printf ("seek %d 2", sec);
 	mplayer_set_fifo (Str);
 	g_free (Str);
 	Str = NULL;
 }
+// 
+// 
 void mplayer_fifo_seek_with_hundr (gdouble PercentValue)
 {
 	gchar  *Mess = NULL;
@@ -254,6 +308,8 @@ void mplayer_fifo_seek_with_hundr (gdouble PercentValue)
 	
 	if (PercentValue < 0.0) PercentValue = 0.0;
 	if (PercentValue > 100.0) PercentValue = 100.0;
+	// VarMplayer.TypeButtonPush = PUSH_BUTTON_MPLAYER_PLAY;
+	VarMplayer.BoolIsPause = FALSE;
 	
 	sec = (gint) ((VarMplayer.DOUBLE_TempsTotal * PercentValue) / 100.0);
 	dsec  = (VarMplayer.DOUBLE_TempsTotal * PercentValue) / 100.0;
@@ -264,22 +320,9 @@ void mplayer_fifo_seek_with_hundr (gdouble PercentValue)
 	g_free (Mess);
 	Mess = NULL;
 }
-gboolean mplayer_is_activate (void)
-{
-	return (VarMplayer.BoolThreadActivate);
-}
-
-gboolean mplayer_is_activate_from_split (void)
-{
-	return (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT ? TRUE : FALSE);
-}
-
-/*
-*---------------------------------------------------------------------------
-* THREAD
-*---------------------------------------------------------------------------
-*/
-static void mplayer_do_thread (void *arg)
+// THREAD
+// 
+static void mplayer_thread (void *arg)
 {
 #define MAX_BUF_MPLAYER 1024
 	gint		 pos = 0;
@@ -291,18 +334,21 @@ static void mplayer_do_thread (void *arg)
 	guint		 Hundr;
 	gdouble		 SecondesTempsActuel = 0.0;
 	gboolean         BoolEndRead = FALSE;
+	// gboolean         BoolPass = FALSE;
 	
 	PRINT("DEBUT THREAD");
 	VarMplayer.BoolThreadActivate = TRUE;
 
-	fd = mplayer_call_exec (VarMplayer.PlayerArgs, &VarMplayer.CodeFork, STDOUT_FILENO);
-
+	fd = mplayer_call_exec (VarMplayer.PlayerArgs, &VarMplayer.CodeFork, STDOUT_FILENO);  // STDERR_FILENO
+	// 
+	// mplayer -input cmdlist
+	// 
 	do {
 		if (fd < 0) {
 			VarMplayer.BoolErreurMplayer = TRUE;
 			break;
 		}
-		
+
 		pos = -1;
 		do {			
 			pos++;
@@ -313,6 +359,8 @@ static void mplayer_do_thread (void *arg)
 			}
 			size = read (fd, &buf[pos], 1);
 			
+			// g_print ("size = %d\n",size);
+			
 			if (strstr(buf,"Audio: no sound")) {
 				VarMplayer.BoolErreurMplayer = TRUE;
 				g_print("\tAudio: no sound\n");
@@ -323,12 +371,51 @@ static void mplayer_do_thread (void *arg)
 				g_print("\tCannot sync MAD frame\n");
 				break;
 			}
-		} while (VarMplayer.BoolThreadActivate == TRUE && (buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
+			if (strstr(buf,"Not a valid DCA frame")) {
+				VarMplayer.BoolErreurMplayer = TRUE;
+				g_print("\tNot a valid DCA frame\n");
+				break;
+			}
 
+		} while (VarMplayer.BoolThreadActivate == TRUE && (buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
+		buf [ pos +2 ] = '\0';
+		buf [ pos +3 ] = '\0';
+		
+		if (LIST_MPLAYER_FROM_SPLIT == VarMplayer.ListPlayFrom) {
+			// PRINT("LIST_MPLAYER_FROM_SPLIT");
+		
+			// TEST DE FIN DE LECTURE
+			// g_print("BUF =%s", buf);
+			Ptr = buf;
+			if (*Ptr == '\n') {
+				Ptr ++;
+				if (*Ptr == ':') {
+					BoolEndRead = TRUE;
+					VarMplayer.PercentTempsActuel =  99.855072;
+					break;
+				}
+			}
+		}
+		else if (LIST_MPLAYER_FROM_CD == VarMplayer.ListPlayFrom) {
+			// PRINT("LIST_MPLAYER_FROM_CD");
+		}
+		else if (LIST_MPLAYER_FROM_DVD == VarMplayer.ListPlayFrom) {
+			// PRINT("LIST_MPLAYER_FROM_DVD");
+		}
+		
+		
 		if (VarMplayer.BoolErreurMplayer == TRUE) {
 			break;
 		}
 		
+		if (NULL != VarMplayer.Func_request_stop) {
+			// SI DEMANDE DE STOP  EST VALIDE
+			if (TRUE == (*VarMplayer.Func_request_stop)()) {
+				BoolEndRead = TRUE;
+				break;
+			}
+		}
+		
 		if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_CD) {
 			if (strstr(buf,"A:") == NULL && VarMplayer.PercentTempsActuel > 0. && *buf == '\n') {
 			}
@@ -340,8 +427,8 @@ static void mplayer_do_thread (void *arg)
 
 		// ANS_PERCENT_POSITION=8.0 (04:36.0)  0.8%
 		//
-		if ((Ptr = strstr(buf,"ANS_PERCENT_POSITION=")) != NULL) {
-			if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_DVD) {
+		if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_DVD) {
+			if ((Ptr = strstr(buf,"ANS_PERCENT_POSITION=")) != NULL) {
 				while (*Ptr != '=') Ptr++;
 				if (*Ptr == '=') Ptr++;
 				if (atoi(Ptr) >= 99) {
@@ -364,20 +451,13 @@ static void mplayer_do_thread (void *arg)
 			SecondesTempsActuel = (gdouble)Sec + ((gdouble)Hundr / 10.0);
 			VarMplayer.PercentTempsActuel = (SecondesTempsActuel / VarMplayer.DOUBLE_TempsTotal) * 100.0;
 						
-			if (VarMplayer.BeginPercentTempsActuel == -1.) {
-				VarMplayer.BeginPercentTempsActuel = VarMplayer.PercentTempsActuel;
-			}
-			
-			if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_FILE) {
-				if (VarMplayer.PercentTempsActuel >=  100.0) {
-					VarMplayer.PercentTempsActuel = 0.0;
-					BoolEndRead = TRUE;
-					break;
-				}
-			}
-			else if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT) {
-				if (VarMplayer.PercentTempsActuel >= VarMplayer.DOUBLE_TempsTotalSection || VarMplayer.PercentTempsActuel >=  99.855072) {
-					VarMplayer.PercentTempsActuel = 100.0;
+			if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT) {
+				// g_print("SecondesTempsActuel                = %f\n", SecondesTempsActuel);
+				// g_print("VarMplayer.PercentTempsActuel       = %f\n", VarMplayer.PercentTempsActuel);
+				// g_print("VarMplayer.DOUBLE_TempsTotalSection  = %f\n", VarMplayer.DOUBLE_TempsTotalSection);
+				// g_print("VarMplayer.DOUBLE_TempsTotal          = %f\n", VarMplayer.DOUBLE_TempsTotal);
+				if (SecondesTempsActuel >= VarMplayer.DOUBLE_TempsTotalSection /*|| VarMplayer.PercentTempsActuel >=  99.855072*/) { 
+					VarMplayer.PercentTempsActuel =  99.855072;
 					BoolEndRead = TRUE;
 					break;
 				}
@@ -388,6 +468,7 @@ static void mplayer_do_thread (void *arg)
 					break;
 				}
 			}
+			// BoolPass = TRUE;
 		}
 		
 		// ANS_LENGTH=85.00of 85.0 (01:25.0)  2.7% 
@@ -400,7 +481,6 @@ static void mplayer_do_thread (void *arg)
 			if (*Ptr == '.') Ptr++;
 			Hundr = atoi (Ptr);
 			VarMplayer.DOUBLE_TempsTotal = (gdouble)Sec;
-			VarMplayer.GUINT_TempsTotal = (guint)VarMplayer.DOUBLE_TempsTotal;
 		}
 		
 		if (buf[pos] != '\n') {
@@ -412,16 +492,17 @@ static void mplayer_do_thread (void *arg)
 
 	close(fd);
 	
-	if (BoolEndRead == TRUE) {
+	if (TRUE == BoolEndRead /*&& VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT*/) {
 		mplayer_set_fifo ("quit");
 	}
-	VarMplayer.PercentTempsActuel = 100.0;
 	BoolEndRead = TRUE;
 	
+	VarMplayer.Button = -1;
+	VarMplayer.BoolIsPause = FALSE;
+	
 	VarMplayer.BoolThreadActivate = FALSE;
 	PRINT("FIN THREAD");
 
-	VarMplayer.Button = -1;
 	
 	if (VarMplayer.BoolErreurMplayer == TRUE) {
 		g_print("\n");
@@ -436,265 +517,196 @@ static void mplayer_do_thread (void *arg)
 
 	pthread_exit (0);
 }
-
-/*
-*---------------------------------------------------------------------------
-* TIMEOUT
-*---------------------------------------------------------------------------
-*/
-static gint mplayer_do_timeout (gpointer data)
+// 
+// TIMEOUT
+// 
+static gint mplayer_timeout (gpointer data)
 {
 	static gint cpt = -1;
 
-	if (VarMplayer.Button == GDK_BUTTON_PRESS) return (TRUE);
-	if (VarMplayer.BoolPushButton == PUSH_BUTTON_MPLAYER_PAUSE) return (TRUE);
-	if (VarMplayer.Button != -1) return (TRUE);
-	
-	if (cpt ++ == 0) mplayer_fifo_get_percent_pos ();
-	if (cpt >= 10) cpt = -1;
+	if (VarMplayer.BoolThreadActivate == TRUE) {
+		
+		if (TRUE == VarMplayer.BoolIsPause) return (TRUE);
+		if (VarMplayer.Button != -1) return (TRUE);
+		
+		if (cpt ++ == 0) mplayer_fifo_get_percent_pos ();
+		if (cpt >= 10) cpt = -1;
 
-	switch (VarMplayer.ListPlayFrom) {
-	case LIST_MPLAYER_FROM_NONE :
-		break;
-	
-	case  LIST_MPLAYER_FROM_DVD :
-		mplayer_fifo_get_time_pos ();
-		WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-		break;
+		switch (VarMplayer.ListPlayFrom) {
+		case LIST_MPLAYER_FROM_NONE :
+		case LIST_MPLAYER_FROM_FILE :
+			break;
 		
-	case  LIST_MPLAYER_FROM_CD :
-		if (VarMplayer.DOUBLE_TempsTotal == 0.0) mplayer_fifo_get_time_length ();
-		else 					mplayer_fifo_get_time_pos ();
-		WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-		break;
-		
-	case  LIST_MPLAYER_FROM_FILE :
-		if (VarMplayer.DOUBLE_TempsTotal == 0.0) mplayer_fifo_get_time_length ();
-		else 					mplayer_fifo_get_time_pos ();
-		WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-		break;
-		
-	case  LIST_MPLAYER_FROM_SPLIT :
-		if (VarMplayer.DOUBLE_TempsTotal == 0.0) mplayer_fifo_get_time_length ();
-		else 					mplayer_fifo_get_time_pos ();
-		
-		if (VarMplayer.DOUBLE_TempsTotal > 0. && VarMplayer.PercentTempsActuel > 0.) {
-			split_with_mplayer (VarMplayer.PercentTempsActuel - VarMplayer.BeginPercentTempsActuel);
+		case  LIST_MPLAYER_FROM_DVD :
+			mplayer_fifo_get_time_pos ();
+			break;
+			
+		case  LIST_MPLAYER_FROM_CD :
+			if (VarMplayer.DOUBLE_TempsTotal == 0.0)
+				mplayer_fifo_get_time_length ();
+			else	mplayer_fifo_get_time_pos ();
+			if (NULL != VarMplayer.FuncSetValueTime && VarMplayer.PercentTempsActuel > 0.0) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
+			break;
+			
+		case  LIST_MPLAYER_FROM_SPLIT :
+			if (VarMplayer.DOUBLE_TempsTotal == 0.0)
+				mplayer_fifo_get_time_length ();
+			else	mplayer_fifo_get_time_pos ();
+			if (NULL != VarMplayer.FuncSetValueTime && VarMplayer.PercentTempsActuel > 0.0) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
+			break;
 		}
-		break;
 	}
-	
-	if (VarMplayer.BoolThreadActivate == FALSE) {
+	else if (VarMplayer.BoolThreadActivate == FALSE) {
 		
-		VarMplayer.BeginPercentTempsActuel = -1.;
-		VarMplayer.DOUBLE_TempsTotal = 0.;
-		
-		mplayer_set_value_time (VarMplayer.PercentTempsActuel);
-
 		gtk_timeout_remove (VarMplayer.HandlerTimeout);
-		VarMplayer.BoolTimeoutActivate = FALSE;
-		PRINT("FIN TIMEOUT");
 
 		/* Widget de l'onglet dvd, cd ou fichiers sur ATTENTE */
-		switch (VarMplayer.OLDListPlayFrom) {
+		switch (VarMplayer.ListPlayFrom) {
 		case LIST_MPLAYER_FROM_NONE :
+		case LIST_MPLAYER_FROM_FILE :
 			break;
 		case LIST_MPLAYER_FROM_DVD :
 			VarMplayer.PercentTempsActuel = 0.0;
-			WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-			dvdaudio_set_etat_music_pixbuf (NULL, FALSE);
-			WinPlay_after_end ();
+			if (VarMplayer.FuncSetValueTime) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
+			if (VarMplayer.FuncWinClose) (*VarMplayer.FuncWinClose) ();
+			if (VarMplayer.FuncIconeStop) (*VarMplayer.FuncIconeStop) ();
 			break;
 		case LIST_MPLAYER_FROM_CD :
 			VarMplayer.PercentTempsActuel = 0.0;
-			WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-			cdaudio_set_etat_music_pixbuf_with_detail (NULL, CD_ETAT_PLAY_ATTENTE);
-			WinPlay_after_end ();
-			break;
-		case LIST_MPLAYER_FROM_FILE :
-			VarMplayer.PercentTempsActuel = 0.0;
-			WinPlay_set_value_time (VarMplayer.PercentTempsActuel);
-			file_set_etat_music_pixbuf_with_detail (NULL, FILE_ETAT_PLAY_ATTENTE);
-			WinPlay_after_end ();
+			if (VarMplayer.FuncSetValueTime) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
+			if (VarMplayer.FuncIconeStop) (*VarMplayer.FuncIconeStop) ();
 			break;
 		case LIST_MPLAYER_FROM_SPLIT :
-			VarMplayer.PercentTempsActuel = 0.0;
-			split_with_mplayer (VarMplayer.PercentTempsActuel);
-			file_set_etat_music_pixbuf_with_detail (NULL, FILE_ETAT_PLAY_ATTENTE);
-			gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonPlay));
-			gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonStop));
-			gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonStop), FALSE);
-			gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonPlay), TRUE);
+			// VarMplayer.PercentTempsActuel = 0.0;
+			if (VarMplayer.FuncSetValueTime) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
+			if (VarMplayer.FuncIconeStop) (*VarMplayer.FuncIconeStop) ();
 			break;
 		}
 		
-		VarMplayer.OLDListPlayFrom = VarMplayer.ListPlayFrom;
+		VarMplayer.ListPlayFrom   = LIST_MPLAYER_FROM_NONE;
+		
+		mplayer_remove_fifo ();
+		
+		VarMplayer.BoolTimeoutActivate = FALSE;
+		PRINT("FIN TIMEOUT");
 	}
 	return (TRUE);
 }
+// MPLAYER INIT
+// 
+void mplayer_init (
+	LIST_MPLAYER_FROM p_ListPlayFrom,
+	gdouble p_TempsTotalSection,
+	guint p_TempsTotalSurface,
+	void *p_FuncWinClose,
+	void *p_FuncSetValueTime, 
+	void *p_FuncIconeStop,
+	void *p_Func_request_stop
+	)
+{
 
-/*
-*---------------------------------------------------------------------------
-* EXTERNAL CALL
-*---------------------------------------------------------------------------
-*/
-void mplayer_set_list (LIST_MPLAYER_FROM ListPlayFrom, gdouble p_TempsTotalSection, guint p_TempsTotalSurface, GList *p_list)
+	VarMplayer.PercentTempsActuel = -1.0;
+	VarMplayer.DOUBLE_TempsTotal = p_TempsTotalSurface;		// ***
+	VarMplayer.DOUBLE_TempsTotalSection = p_TempsTotalSection;	// ***
+	VarMplayer.BoolIsPause = FALSE;
+	VarMplayer.ListPlayFrom = p_ListPlayFrom;			// ***
+
+	VarMplayer.BoolThreadActivate = FALSE;
+	VarMplayer.NmrTid = 0;
+	VarMplayer.BoolTimeoutActivate = FALSE;
+	VarMplayer.HandlerTimeout = 0;
+	VarMplayer.SignalNumchildren = 0;
+	VarMplayer.CodeFork = 0;
+	VarMplayer.BoolErreurMplayer = FALSE;
+	
+	VarMplayer.Button = -1;						// ***
+	VarMplayer.FuncWinClose = p_FuncWinClose;			// ***
+	VarMplayer.FuncSetValueTime = p_FuncSetValueTime;		// ***
+	VarMplayer.FuncIconeStop = p_FuncIconeStop;			// ***
+	VarMplayer.Func_request_stop = p_Func_request_stop;		// ***
+}
+// EXTERNAL CALL
+// 
+void mplayer_set_list (GList *p_list)
 {
-#define MAX_ELEMENTS_ARGS  100
 	gint	 PosArg = 0;
 	GList	*list = NULL;
 	gchar	*Ptr = NULL;
 	
 	// PRINT_FUNC_LF();
-	
-	// INIT VAR
-	VarMplayer.DOUBLE_TempsTotalSection = p_TempsTotalSection;
-	VarMplayer.BeginPercentTempsActuel = -1.0;
-
+		
 	// DETRUIT MPLAYER VIA LE FIFO
 	mplayer_fifo_quit ();
-	VarMplayer.BoolPushButton = PUSH_BUTTON_MPLAYER_PLAY;
 	
 	// CREATE CONTROLE FILE MPLAYER VIA FIFO
 	mplayer_create_fifo ();
-	
-	// WAITING TO DESTROY
-	while (VarMplayer.BoolThreadActivate == TRUE) {
-		if ( VarMplayer . BoolThreadActivate == FALSE ) break;
-	}
-	
-	// STOCKE LE TYPE D APPEL
-	VarMplayer.OLDListPlayFrom =
-	VarMplayer.ListPlayFrom = ListPlayFrom;
+		
 
 	// DESTRUIT L ANCIENNE LIST D ARGUMENTS
 	mplayer_remove_list_args ();
 
-	VarMplayer.PlayerArgs = (MPLAYER_ARGS *)g_malloc0(sizeof(MPLAYER_ARGS) * MAX_ELEMENTS_ARGS);
 	PosArg = 0;
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("nice");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-n");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup_printf ("%d", options_get_val_nice ());
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("mplayer");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-nojoystick");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-nolirc");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-nortc");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-noautosub");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-nomouseinput");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-slave");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-idle");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-cache");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("8192");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("nice");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-n");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup_printf ("%d", Config.Nice);
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("mplayer");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-nojoystick");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-nolirc");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-nortc");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-noautosub");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-nomouseinput");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-slave");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-idle");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-cache");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("8192");
 	list = g_list_first (p_list);
 	while (list) {
-		if ((Ptr = (gchar *)list->data)) {
-			switch (ListPlayFrom) {
-			case LIST_MPLAYER_FROM_NONE :
-				break;
-			case LIST_MPLAYER_FROM_DVD :
-			case LIST_MPLAYER_FROM_CD :
-			case LIST_MPLAYER_FROM_FILE :
-			case LIST_MPLAYER_FROM_SPLIT :
-				VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup_printf ("%s", Ptr);
-				break;
-			}
+		if (NULL != (Ptr = (gchar *)list->data)) {
+			VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup (Ptr);
 		}
 		list = g_list_next (list);
 	}
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup ("-input");
-	VarMplayer.PlayerArgs[ PosArg++ ].str = g_strdup_printf ("file=%s", XCFA_TMP_FIFO);
-	VarMplayer.PlayerArgs[ PosArg++ ].str = NULL;
-	VarMplayer.PlayerArgs[ PosArg++ ].str = NULL;
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup ("-input");
+	VarMplayer.PlayerArgs[ PosArg++ ] = g_strdup_printf ("file=%s", XCFA_TMP_FIFO);
+	VarMplayer.PlayerArgs[ PosArg++ ] = NULL;
 	
-	// LISTE SUR STDOUT DES ARGUMENTS
+	// LISTER LES ARGUMENTS SUR STDOUT
 	g_print("\n");
 	g_print("!-----------------------------------------------------------!\n");
-	g_print("! MPLAYER  Alloc memory: %d / %d\n", PosArg -2, MAX_ELEMENTS_ARGS);
+	g_print("! READ WITH MPLAYER  \n");
 	g_print("!-----------------------------------------------------------!\n");
-	for (PosArg = 0; VarMplayer.PlayerArgs[ PosArg ].str != NULL; PosArg ++) {
-		g_print ("VarMplayer.PlayerArgs[ %02d ] = %s\n", PosArg, VarMplayer.PlayerArgs[ PosArg ].str);
+	g_print("! ");
+	// PRINT COMMAND LINE
+	for (PosArg = 0; VarMplayer.PlayerArgs[ PosArg ] != NULL; PosArg ++) {
+		g_print ("%s ", VarMplayer.PlayerArgs[ PosArg ]);
 	}
-	g_print("!-----------------------------------------------------------!\n! ");
-	for (PosArg = 0; VarMplayer.PlayerArgs[ PosArg ].str != NULL; PosArg ++) {
-		g_print ("%s ", VarMplayer.PlayerArgs[ PosArg ].str);
+	// PRINT COMMAND LINE IN STRUCT
+	g_print("\n!-----------------------------------------------------------!\n");
+	for (PosArg = 0; VarMplayer.PlayerArgs[ PosArg ] != NULL; PosArg ++) {
+		g_print ("VarMplayer.PlayerArgs[ %02d ] = %s\n", PosArg, VarMplayer.PlayerArgs[ PosArg ]);
 	}
-	g_print("\n");
 	g_print("!-----------------------------------------------------------!\n\n");
 
 	if (VarMplayer.PercentTempsActuel < 0.0) VarMplayer.PercentTempsActuel = 0.0;
-	VarMplayer.BoolErreurMplayer = FALSE;
-	VarMplayer.Button = -1;
-	VarMplayer.BoolPushButton = PUSH_BUTTON_MPLAYER_PLAY;
-
+	
 	// ACTIVATE THREAD
-	if (VarMplayer.BoolThreadActivate == FALSE) {
+	if (FALSE == VarMplayer.BoolThreadActivate) {
 		VarMplayer.BoolThreadActivate = TRUE;
-		pthread_create (&VarMplayer.NmrTid, NULL ,(void *)mplayer_do_thread, (void *)NULL);
+		pthread_create (&VarMplayer.NmrTid, NULL ,(void *)mplayer_thread, (void *)NULL);
 	}
 	
 	// ACTIVATE TIMEOUT
-	if (VarMplayer.BoolTimeoutActivate == FALSE) {
+	if (FALSE == VarMplayer.BoolTimeoutActivate) {
 		VarMplayer.BoolTimeoutActivate = TRUE;
 		PRINT("DEBUT TIMEOUT");
-		VarMplayer.HandlerTimeout = gtk_timeout_add (100, mplayer_do_timeout, 0);
+		VarMplayer.HandlerTimeout = gtk_timeout_add (100, mplayer_timeout, 0);
 	}
-
-#undef MAX_ELEMENTS_ARGS
 }
 
 
-
-void mplayer_set_value_time (gdouble value)
+gboolean mplayer_is_used (void)
 {
-	// gchar   *Mess = NULL;
-	gint     sec   = 0;
-
-	if (value < 0.0)   value = 0.0;
-	if (value > 100.0) value = 100.0;
-	
-	sec = (gint) ((VarMplayer.DOUBLE_TempsTotal * value) / 100.0);
-	
-	if (sec < 0) sec = 0;
-	
-	// Mess = g_strdup_printf ("<b> %02d:%02d:%02d </b>", (sec/60)/60, (sec/60)%60, sec%60);
-/*g_print("%s\n", Mess);*/
-	
-	
-	if (VarLecture.AdrAdjustAllFile) {
-		gtk_adjustment_set_value (GTK_ADJUSTMENT (VarLecture.AdrAdjustAllFile), value);
-	}
-	
-	// g_free (Mess);
-	// Mess = NULL;
-
-}
-gboolean mplayer_change_value_time (GtkRange *range, GtkScrollType scroll, gdouble value, gpointer user_data)
-{
-	if (VarMplayer.Button == GDK_BUTTON_RELEASE) {
-		mplayer_fifo_seek_with_hundr (value);
-		VarMplayer.PercentTempsActuel = value;
-		VarMplayer.Button = -1;
-	}
-	mplayer_set_value_time (value);
-	return FALSE;
-}
-gboolean mplayer_event_music (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
-{
-	if (event->type == GDK_BUTTON_PRESS) {
-		VarMplayer.Button = GDK_BUTTON_PRESS;
-	}
-	if (event->type == GDK_BUTTON_RELEASE) {
-		VarMplayer.Button = GDK_BUTTON_RELEASE;
-	}
-	
-	return (FALSE);
-}
-
-/* PLAYER ONGLET DVD
-*/
-void mplayer_button_stop_music_clicked (GtkButton *button)
-{
-	mplayer_fifo_quit ();
+	return (VarMplayer.BoolTimeoutActivate);
 }
 
 
@@ -704,4 +716,3 @@ void mplayer_button_stop_music_clicked (GtkButton *button)
 
 
 
-
