@@ -31,12 +31,11 @@
  */
 
 
-#ifndef __normalise_h__
-#define __normalise_h__ 1
+#ifndef normalise_h
+#define normalise_h 1
 
-gboolean   normalise_individuel (void);
-gboolean   normalise_collectif (void);
-void       normalise_file (void);
+gboolean   normalise_is_individuel (void);
+void       normalise_action (void);
 
 #endif
 
