@@ -31,19 +31,29 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
 #include <pthread.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "utils.h"
+#include "configuser.h"
+#include "prg_init.h"
+#include "win_info.h"
 #include "notify_send.h"
 
 
@@ -57,6 +67,9 @@ typedef struct {
 VAR_NOTIFYSEND NotifySend;
 
 
+
+// 
+// 
 void NotifySend_call (void)
 {
 	pid_t  pid;
@@ -70,14 +83,16 @@ void NotifySend_call (void)
 		_exit (0);
 	}
 }
-
+// 
+// 
 static void NotifySend_thread (void *arg)
 {
 	NotifySend_call ();
 	pthread_exit(0);
 }
-
-void NotifySend_msg (gchar *Title, gchar *Str)
+// 
+// 
+void NotifySend_remove (void)
 {
 	if (NotifySend.Title != NULL) {
 		g_free (NotifySend.Title);
@@ -87,9 +102,18 @@ void NotifySend_msg (gchar *Title, gchar *Str)
 		g_free (NotifySend.Str);
 		NotifySend.Str = NULL;
 	}
+}
+// 
+// 
+void NotifySend_msg (gchar *Title, gchar *Str)
+{
+	NotifySend_remove ();
 	
-	if (utils_scan_by_which ("notify-send", NULL) == FALSE) {
-		PRINT("(Package libnotify-bin): notify-send NOT EXIST");
+	if (FALSE == PrgInit.bool_notify_send) {
+		wininfo_create (
+			_("Package NOT FOUND !"),
+			_("(Package libnotify-bin): notify-send NOT EXIST"),
+		  	"");
 		return;
 	}
 	
