@@ -31,10 +31,11 @@
  */
 
 
-#ifndef __notify_send_h__
-#define __notify_send_h__ 1
+#ifndef notify_send_h
+#define notify_send_h 1
 
 void NotifySend_msg (gchar *Title, gchar *Str);
+void NotifySend_remove (void);
 
 #endif
 
