@@ -31,44 +31,50 @@
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
 
 
-/*  Christian Marillat
- *  mono   [ 12 .. 44 ] kbit
- *  stéréo [ 16 .. 64 ] kbit
- *
- *  Matteo Croce
- *  MONO   [ 10 12 14 18 20 24 32 40 ]
- *  STEREO [          18    24 32 40 48 ]
- *
-*/
-void optionsaacplusenc_combobox_accplusenc_mono_realize (GtkWidget *widget)
+
+static 	gint Tab_bitrate_mono [] = { 10, 12, 14, 18, 20, 24, 32, 40 };
+static 	gint Tab_bitrate_stereo [] = { 18, 24, 32, 40, 48 };
+// 
+// 
+gint optionsaacplusenc_get_bitrate_mono (void)
 {
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	return (Tab_bitrate_mono [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_mono) ]);
+}
+// 
+// 
+gint optionsaacplusenc_get_bitrate_stereo (void)
+{
+	return (Tab_bitrate_stereo [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_stereo) ]);
+}
+// 
+// 
+void on_combobox_accplusenc_mono_realize (GtkWidget *widget, gpointer user_data)
+{
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "10");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "12");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "14");
@@ -77,32 +83,47 @@ void optionsaacplusenc_combobox_accplusenc_mono_realize (GtkWidget *widget)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "40");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.aacplusenc_choice_mono);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ChoiceMonoAacplusenc);
 	var_options.Adr_Widget_aacplusenc_mono = GTK_COMBO_BOX (widget);
 }
-
-void optionsaacplusenc_combobox_accplusenc_stereo_realize (GtkWidget *widget)
+// 
+// 
+void on_combobox_accplusenc_mono_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	if (NULL != var_options.Adr_Widget_aacplusenc_mono) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_mono))) >= 0)
+			Config.ChoiceMonoAacplusenc = ind;
+	}
+}
+// 
+// 
+void on_combobox_accplusenc_stereo_realize (GtkWidget *widget, gpointer user_data)
+{
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "18");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "40");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "48");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.aacplusenc_choice_stereo);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ChoiceStereoAacplusenc);
 	var_options.Adr_Widget_aacplusenc_stereo = GTK_COMBO_BOX (widget);
 }
-	
-gint optionsaacplusenc_get_bitrate_mono (void)
+// 
+// 
+void on_combobox_accplusenc_stereo_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	gint	Tab [] = { 10, 12, 14, 18, 20, 24, 32, 40 };
-	return (Tab [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_mono) ]);
-}
-
-gint optionsaacplusenc_get_bitrate_stereo (void)
-{
-	gint	Tab [] = { 18, 24, 32, 40, 48 };
-	return (Tab [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_stereo) ]);
+	if (NULL != var_options.Adr_Widget_aacplusenc_stereo) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_stereo))) >= 0)
+			Config.ChoiceStereoAacplusenc = ind;
+	}
 }
 
 
+
+
+
+
+
+
