@@ -31,46 +31,125 @@
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-void OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ (void)
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
+
+
+static 	gchar *str_faac_conteneur[] = {
+	"",
+	"-w"
+	};
+static 	gchar *str_faac_abr[] = {
+	"-b 56",
+	"-b 64",
+	"-b 80",
+	"-b 96",
+	"-b 128",
+	"-b 152"
+	};
+static 	gchar *str_faac_vbr[] = {
+	"-q 10",
+	"-q 30",
+	"-q 50",
+	"-q 70",
+	"-q 80",
+	"-q 90",
+	"-q 100",
+	"-q 120",
+	"-q 150",
+	"-q 200",
+	"-q 250",
+	"-q 300",
+	"-q 400",
+	"-q 500"
+	};
+gchar *OptionsFaac_get_faac_conteneur (void)
 {
+	if (NULL == var_options.Adr_Widget_faac_conteneur) return ( (gchar *)str_faac_conteneur[ 0 ]);
+	return ( (gchar *)str_faac_conteneur[ gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_conteneur)) ]);	
+}
+gchar *OptionsFaac_get_faac_set_choice_vbr_abr (void)
+{
+	if (0 == gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_choice_vbr_abr))) {
+		gint	ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
+		if (ind < 0) ind = 0;
+		return ( (gchar *)str_faac_vbr[ ind ]);
+	}
+	return ( (gchar *)str_faac_abr[ gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr)) ]);
+}
+
+
+
+void on_combobox_faac_conteneur_realize (GtkWidget *widget, gpointer user_data)
+{
+	libcombo_alloc (GTK_COMBO_BOX (widget));
+
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Transport Stream (ADTS) - Extension .aac"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("MPEG-4 File Format (MP4) - Extension .m4a"));
+	
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ConteneurFacc);
+	var_options.Adr_Widget_faac_conteneur = GTK_COMBO_BOX (widget);
+
+	// on_combobox_faac_set_choice_vbr_abr_changed (NULL,NULL);
+}
+void on_combobox_faac_conteneur_changed (GtkComboBox *combobox, gpointer user_data)
+{
+	if (NULL != var_options.Adr_Widget_faac_conteneur) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_conteneur))) >= 0)
+			Config.ConteneurFacc = ind;
+		
+		OptionsInternal_set_datas_interne (COLOR_FAAC_CONTENEUR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
+	}
+}
+
+
+
+void on_combobox_faac_choice_vbr_abr_realize (GtkWidget *widget, gpointer user_data)
+{
+	libcombo_alloc (GTK_COMBO_BOX (widget));
+	var_options.Adr_Widget_faac_choice_vbr_abr = GTK_COMBO_BOX (widget);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.AbrVbrFacc);
+}
+void on_combobox_faac_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer user_data)
+{	
+	if (NULL != var_options.Adr_Widget_faac_choice_vbr_abr) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_choice_vbr_abr))) >= 0)
+			Config.AbrVbrFacc = ind;
+	}
 	if (var_options.Adr_Widget_faac_choice_vbr_abr == NULL) return;
 	if (var_options.Adr_Widget_faac_set_choice_vbr_abr == NULL) return;
 	
-	if (var_options.bool_changed == FALSE) return;
-	var_options.bool_changed = FALSE;
-	
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
-	utils_alloc_combo (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
+	libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
 	
 	switch (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr)) {
 	
-	/* ABR
-	 * 56, 64, 80, 96, 128, 152
-    	*/
+	/* VBR
+	 * 10, 30, 50, 70, 80, 90, 100, 120, 150, 200, 250, 300, 400, 500
+    	 */
 	case 0 :
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "10");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "30");
@@ -87,12 +166,12 @@ void OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ (void)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "400");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "500");
 		
-		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config_User.faac_set_choice_vbr);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config.VbrFaccIndice);
 		break;
 	
-	/* VCR
-	*  10, 30, 50, 70, 80, 90, 100, 120, 150, 200, 250, 300, 400, 500
-	*/
+	/* ABR
+	 * 56, 64, 80, 96, 128, 152
+	 */
 	case 1 :
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "56");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "64");
@@ -101,152 +180,35 @@ void OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ (void)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "128");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "152");
 		
-		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config_User.faac_set_choice_abr);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config.AbrFaccIndice);
 		break;
 	}
-	var_options.bool_changed = TRUE;
-	
-}
-
-void OptionsFaac_combobox_faac_conteneur_realize (GtkWidget *widget)
-{
-	/*PRINT_FUNC_LF();*/
-	
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
-
-	/*
-	Titre de l'option = Conteneur
-	Choix = Transport Stream (ADTS) - Extension .aac /OU/ MPEG-4 File Format (MP4) - Extension .m4a 
-	*/
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Transport Stream (ADTS) - Extension .aac"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("MPEG-4 File Format (MP4) - Extension .m4a"));
-	
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.faac_conteneur);
-	var_options.Adr_Widget_faac_conteneur = GTK_COMBO_BOX (widget);
-	var_options.bool_changed = TRUE;
-	OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ ();
-}
-void OptionsFaac_combobox_faac_conteneur_changed (void)
-{
-	/*PRINT_FUNC_LF();*/
-	options_set_datas_interne (COLOR_FAAC_CONTENEUR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
+	OptionsInternal_set_datas_interne (COLOR_FAAC_SET_CHOICE_VBR_ABR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
 }
 
 
-void OptionsFaac_combobox_faac_choice_vbr_abr_realize (GtkWidget *widget)
+
+void on_combobox_faac_set_choice_vbr_abr_realize (GtkWidget *widget, gpointer user_data)
 {
-	/*PRINT_FUNC_LF();*/
-	
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
-     	/*
-	Titre de l'option = VBR / ABR
-	Choix = VBR /OU/ ABR
-	*/
-
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
-	
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.faac_choice_vbr_abr);
-	var_options.bool_changed = TRUE;
-	var_options.Adr_Widget_faac_choice_vbr_abr = GTK_COMBO_BOX (widget);
-}
-void OptionsFaac_combobox_faac_choice_vbr_abr_changed (void)
-{
-	/*PRINT_FUNC_LF();*/
-	
-	OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ ();
-	options_set_datas_interne (COLOR_FAAC_SET_CHOICE_VBR_ABR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
-}
-
-
-void OptionsFaac_combobox_faac_set_choice_vbr_abr_realize (GtkWidget *widget)
-{
-	/*PRINT_FUNC_LF();*/
-	
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
-
+	// libcombo_alloc (GTK_COMBO_BOX (widget));
 	var_options.Adr_Widget_faac_set_choice_vbr_abr = GTK_COMBO_BOX (widget);
-	var_options.bool_changed = TRUE;
-	OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ ();
+	on_combobox_faac_choice_vbr_abr_changed (NULL,NULL);
 }
-void OptionsFaac_combobox_faac_set_choice_vbr_abr_changed (void)
+void on_combobox_faac_set_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	if (var_options.bool_changed == FALSE) return;
-	if (var_options.Adr_Widget_faac_choice_vbr_abr == NULL) return;
-	if (var_options.Adr_Widget_faac_set_choice_vbr_abr == NULL) return;
-	
-	switch (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr)) {
-	case 0 :
-		Config_User.faac_set_choice_vbr = gtk_combo_box_get_active (var_options.Adr_Widget_faac_set_choice_vbr_abr);
-		break;
-	case 1 :
-		Config_User.faac_set_choice_abr = gtk_combo_box_get_active (var_options.Adr_Widget_faac_set_choice_vbr_abr);
-		break;
+	if (NULL != var_options.Adr_Widget_faac_set_choice_vbr_abr) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr))) >= 0) {
+			switch (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr)) {
+			case 0 :
+				Config.VbrFaccIndice = ind;
+				break;
+			case 1 :
+				Config.AbrFaccIndice = ind;
+				break;
+			}
+		}
+		OptionsInternal_set_datas_interne (COLOR_FAAC_SET_CHOICE_VBR_ABR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
 	}
-	
-	options_set_datas_interne (COLOR_FAAC_SET_CHOICE_VBR_ABR, var_options.Adr_label_faac_m4a, FAAC_WAV_TO_M4A);
 }
 
-gchar *OptionsFaac_get_faac_conteneur (void)
-{
-	gchar *str_faac_conteneur[] = {
-	"",
-	"-w"
-	};
-
-	if (!var_options.Adr_Widget_faac_conteneur) return ( (gchar *)str_faac_conteneur[ 0 ]);
-	return ( (gchar *)str_faac_conteneur[ gtk_combo_box_get_active (var_options.Adr_Widget_faac_conteneur) ]);	
-}
-gboolean OptionsFaac_bool_get_faac_conteneur (void)
-{
-	return ( *OptionsFaac_get_faac_conteneur () == '-' ? TRUE : FALSE);
-}
-
-
-gchar *OptionsFaac_get_faac_set_choice_vbr_abr (void)
-{
-	/* ABR
-	 * 56, 64, 80, 96, 128, 152
-    	*/
-	gchar *str_faac_abr[] = {
-	"-b 56",
-	"-b 64",
-	"-b 80",
-	"-b 96",
-	"-b 128",
-	"-b 152"
-	};
-	/* VCR
-	*  10, 30, 50, 70, 80, 90, 100, 120, 150, 200, 250, 300, 400, 500
-	*/
-	gchar *str_faac_vbr[] = {
-	"-q 10",
-	"-q 30",
-	"-q 50",
-	"-q 70",
-	"-q 80",
-	"-q 90",
-	"-q 100",
-	"-q 120",
-	"-q 150",
-	"-q 200",
-	"-q 250",
-	"-q 300",
-	"-q 400",
-	"-q 500"
-	};
-	
-	if (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr) == 0) {
-		return ( (gchar *)str_faac_vbr[ gtk_combo_box_get_active (var_options.Adr_Widget_faac_set_choice_vbr_abr) ]);
-	}
-	return ( (gchar *)str_faac_abr[ gtk_combo_box_get_active (var_options.Adr_Widget_faac_set_choice_vbr_abr) ]);
-}
-
-
-
-
-
