@@ -31,35 +31,49 @@
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-void optionsFlac_combobox_flac_compression_realize (GtkWidget *widget)
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
+
+
+
+
+
+
+static gchar *CompLevel[] = {"-0","-1","-2","-3","-4","-5","-6","-7","-8"};
+
+gchar *optionsFlac_get_compression_level_flac (void)
+{
+	// return ((gchar *)CompLevel [ gtk_combo_box_get_active ( GTK_COMBO_BOX (var_options.Adr_Widget_flac_compression)) ]);
+	return ((gchar *)CompLevel [ Config.CompressionLevelFlac ]);
+}
+
+
+
+void on_options_combobox_flac_compression_realize (GtkWidget *widget, gpointer user_data)
 {
  	var_options.Adr_Widget_flac_compression =  GTK_COMBO_BOX (widget);
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("0  (Rapide)"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "1");
@@ -71,18 +85,27 @@ void optionsFlac_combobox_flac_compression_realize (GtkWidget *widget)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "7");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("8  (Lent)"));
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.compression_level_flac);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.CompressionLevelFlac);
 }
-
-gchar *optionsFlac_get_compression_level_flac (void)
+void on_combobox_flac_compression_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	static gchar *CompLevel[] = {"-0","-1","-2","-3","-4","-5","-6","-7","-8"};
-
-	return ((gchar *)CompLevel [ gtk_combo_box_get_active ( var_options.Adr_Widget_flac_compression) ]);
+	if (NULL != var_options.Adr_Widget_flac_compression) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_flac_compression))) >= 0)
+			Config.CompressionLevelFlac = ind;
+		OptionsInternal_set_datas_interne (COLOR_FLAC_TAUX_COMPRESSION, var_options.Adr_label_flac_flac, FLAC_WAV_TO_FLAC);
+	}
 }
 
 
-void optionsFlac_combobox_flac_compression_changed (void)
-{
-	options_set_datas_interne (COLOR_FLAC_TAUX_COMPRESSION, var_options.Adr_label_flac_flac, FLAC_WAV_TO_FLAC);
-}
+
+
+
+
+
+
+
+
+
+
+
