@@ -31,35 +31,44 @@
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-void optionsApe_combobox_ape_compression_realize (GtkWidget *widget)
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
+
+
+
+static gchar *CompLevel[] = {"-c1000","-c2000","-c3000","-c4000","-c5000",};
+gchar *optionsApe_get_compression_level_ape (void)
+{
+	return ((gchar *)CompLevel [ gtk_combo_box_get_active ( GTK_COMBO_BOX (var_options.Adr_Widget_ape_compression)) ]);
+}
+
+
+
+void on_combobox_ape_compression_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_options.Adr_Widget_ape_compression =  GTK_COMBO_BOX (widget);
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (fast):          '-c1000'");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (normal):     '-c2000'");
@@ -67,18 +76,18 @@ void optionsApe_combobox_ape_compression_realize (GtkWidget *widget)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (extra high): '-c4000'");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (insane):       '-c5000'");
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.compression_level_ape);
-
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.CompressionLevelApeMac);
 }
-
-gchar *optionsApe_get_compression_level_ape (void)
+void on_combobox_ape_compression_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	static gchar *CompLevel[] = {"-c1000","-c2000","-c3000","-c4000","-c5000",};
+	if (NULL != var_options.Adr_Widget_ape_compression) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_ape_compression))) >= 0)
+			Config.CompressionLevelApeMac = ind;
 
-	return ((gchar *)CompLevel [ gtk_combo_box_get_active ( var_options.Adr_Widget_ape_compression) ]);
+		OptionsInternal_set_datas_interne (COLOR_MAC_QUALITE, var_options.Adr_label_mac_ape, MAC_WAV_TO_APE);
+	}
 }
 
-void optionsApe_combobox_ape_compression_changed (void)
-{
-	options_set_datas_interne (COLOR_MAC_QUALITE, var_options.Adr_label_mac_ape, MAC_WAV_TO_APE);
-}
+
+
