@@ -31,36 +31,52 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
 #include <gtk/gtk.h>
-
 #include <string.h>
-
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-void optionsMusepack_combobox_mppenc_realize (GtkWidget *widget)
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
+
+
+
+static 	gchar *str_val_preset[] = {
+		"--telephone",
+		"--thumb",
+		"--radio",
+		"--standard",
+		"--xtreme",
+		"--insane",
+		"--braindead"
+	};
+gchar *optionsMusepack_get_quality_mppenc (void)
+{
+	return ( (gchar *)str_val_preset[ gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Mppenc)) ]);
+}
+
+
+
+void on_combobox_mppenc_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_options.Adr_Widget_Mppenc = GTK_COMBO_BOX (widget);
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("telephone: lowest quality              :   32 ..  48 kbit/s"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("thumb      : low quality/internet     :   58 ..  86 kbit/s"));
@@ -70,23 +86,27 @@ void optionsMusepack_combobox_mppenc_realize (GtkWidget *widget)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("insane      : extreme high quality   : 232 .. 268 kbit/s"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("braindead : extreme high quality   : 232 .. 278 kbit/s"));
 	
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.quality_mppenc);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.QualityMppenc);
 }
-gchar *optionsMusepack_get_quality_mppenc (void)
+void on_combobox_mppenc_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	gchar *str_val_preset[] = {
-		"--telephone",
-		"--thumb",
-		"--radio",
-		"--standard",
-		"--xtreme",
-		"--insane",
-		"--braindead"
-	};
-	return ( (gchar *)str_val_preset[ gtk_combo_box_get_active (var_options.Adr_Widget_Mppenc) ]);
+	if (NULL != var_options.Adr_Widget_Mppenc) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Mppenc))) >= 0)
+			Config.QualityMppenc = ind;
+		
+		OptionsInternal_set_datas_interne (COLOR_MUSEPACK_QUALITE, var_options.Adr_label_musepack_mpc, MPPENC_WAV_TO_MPC);
+	}
 }
 
-void optionsMusepack_combobox_mppenc_changed (void)
-{
-	options_set_datas_interne (COLOR_MUSEPACK_QUALITE, var_options.Adr_label_musepack_mpc, MPPENC_WAV_TO_MPC);
-}
+
+
+
+
+
+
+
+
+
+
+
