@@ -27,42 +27,37 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * 
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
-#include "global.h"
-#include "config_user.h"
-#include "cd_audio.h"
-#include "utils.h"
-#include "options.h"
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gstdio.h>
-#include "info_song.h"
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
-/*
-*---------------------------------------------------------------------------
-* CODE
-*---------------------------------------------------------------------------
-*/
-/* Recupere et renvoie la chaine de parametres
-*  --
-*  entree : -
-*  retour :
-*/
-gchar *optionsOggenc_get_val_bitrate_oggenc (void)
-{
-	gchar *val[] = {
+#include "global.h"
+#include "configuser.h"
+#include "options.h"
+
+
+
+
+static 	gchar *val_bitrate_ogg[] = {
 	"--bitrate=45",
 	"--bitrate=64",
 	"--bitrate=80",
@@ -87,21 +82,62 @@ gchar *optionsOggenc_get_val_bitrate_oggenc (void)
 	"--quality=9",
 	"--quality=10"
 	};
-
-	return (val[ gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) ]);
-}
-/* Construction du combobox 'Oggenc'
-*  --
-*  entree :
-*      GtkWidget *widget : Adresse du combobox
-*  retour : -
+// 
+// 
+/*
+	Config.BitrateOggenc
+	Config.ManagedOggenc
+	Config.DownmixOggenc
 */
-void optionsOggenc_make_combobox_oggenc (GtkWidget *widget)
+gchar *optionsOggenc_get_param (DETAIL *detail)
+{
+	gchar StrOggenc[ 1000 ];
+	
+	if (NULL == detail)
+		strcpy (StrOggenc, val_bitrate_ogg [ Config.BitrateOggenc ]);
+	else	strcpy (StrOggenc, val_bitrate_ogg [ detail->TypeMp3Ogg.type ]);
+	
+	if (Config.BitrateOggenc < 11 && Config.ManagedOggenc == 0) {
+		if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+		strcat (StrOggenc, "--managed");
+	}
+	if (Config.BitrateOggenc < 9 && Config.DownmixOggenc == 0) {
+		if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+		strcat (StrOggenc, "--downmix");
+	}
+	
+	return ((gchar *)strdup (StrOggenc));
+}
+// 
+// 
+gchar *optionsOggenc_get_val_bitrate_oggenc (void)
+{
+	return (val_bitrate_ogg [ gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_bitrate)) ]);
+}
+// 
+// 
+gboolean optionsOggenc_get_bool_managed_oggenc (void)
+{
+	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_managed"))) == TRUE) {
+		if (gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_managed)) == 0) return (TRUE);
+	}
+	return (FALSE);
+}
+// 
+// 
+gboolean optionsOggenc_get_bool_downmix_oggenc (void)
+{
+	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_downmix"))) == TRUE) {
+		if (gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_downmix)) == 0) return (TRUE);
+	}
+	return (FALSE);
+}
+// 
+// 
+void on_combobox_oggenc_bitrate_realize (GtkWidget *widget, gpointer user_data)
 {
-	/* PRINT_FUNC_LF(); */
 	var_options.Adr_Widget_Oggenc_bitrate = GTK_COMBO_BOX (widget);
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 45  kbit/s");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 64  kbit/s");
@@ -128,82 +164,76 @@ void optionsOggenc_make_combobox_oggenc (GtkWidget *widget)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  9"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  10  (Meilleure qualite)"));
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.RateMp3OggOptions.Bitrate_Oggenc);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.BitrateOggenc);
 }
-
-void optionsOggenc_combobox_oggenc_bitrate_changed (void)
+// 
+// 
+void on_combobox_oggenc_bitrate_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	/* PRINT_FUNC_LF(); */
+	if (NULL != var_options.Adr_Widget_Oggenc_bitrate) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_bitrate))) >= 0)
+			Config.BitrateOggenc = ind;
+		
+		gtk_widget_set_sensitive (
+			GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_managed")),
+			gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 11 ? TRUE : FALSE);
 
-	if (var_options.Adr_Widget_Oggenc_bitrate == NULL) return;
-
-	/* Managed ne peut etre selectionne que avec le parametre '--bitrate='
-	*/
-	gtk_widget_set_sensitive (
-		GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_oggenc_managed")),
-		gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 11 ? TRUE : FALSE);
-
-	gtk_widget_set_sensitive (
-		GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_oggenc_downmix")),
-		gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 9 ? TRUE : FALSE);
-
-	if (var_options.Adr_label_oggenc_ogg == NULL) return;
-	options_set_datas_interne (COLOR_OGGENC_DEBIT, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
-}
-
-/* Si OUI retourne TRUE sinon FALSE
-*/
-gboolean optionsOggenc_get_bool_managed_oggenc (void)
-{
-	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_oggenc_managed"))) == TRUE) {
-		if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_managed) == 0) return (TRUE);
+		gtk_widget_set_sensitive (
+			GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_downmix")),
+			gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 9 ? TRUE : FALSE);
+		
+		OptionsInternal_set_datas_interne (COLOR_OGGENC_DEBIT, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
 	}
-	return (FALSE);
 }
-void optionsOggenc_combobox_oggenc_managed_realize (GtkWidget *widget)
+// 
+// 
+void on_combobox_oggenc_managed_realize (GtkWidget *widget, gpointer user_data)
 {
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Oui"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.RateMp3OggOptions.Managed_Oggenc);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ManagedOggenc);
 
 	var_options.Adr_Widget_Oggenc_managed = GTK_COMBO_BOX (widget);
 }
-void optionsOggenc_combobox_oggenc_managed_changed (void)
+void on_combobox_oggenc_managed_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	options_set_datas_interne (COLOR_OGGENC_MANAGED, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
-}
-
-/* Si OUI retourne TRUE sinon FALSE
-*/
-gboolean optionsOggenc_get_bool_downmix_oggenc (void)
-{
-	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_oggenc_downmix"))) == TRUE) {
-		if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_downmix) == 0) return (TRUE);
+	if (NULL != var_options.Adr_Widget_Oggenc_managed) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_managed))) >= 0)
+			Config.ManagedOggenc = ind;
+		OptionsInternal_set_datas_interne (COLOR_OGGENC_MANAGED, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
 	}
-	/*
-	if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_downmix) == 0) return (TRUE);
-	*/
-	return (FALSE);
 }
-void optionsOggenc_combobox_oggenc_downmix_realize (GtkWidget *widget)
+// 
+// 
+void on_combobox_oggenc_downmix_realize (GtkWidget *widget, gpointer user_data)
 {
-	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
-	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Mono force"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Stereo"));
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.RateMp3OggOptions.Downmix_Oggenc);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.DownmixOggenc);
 
 	var_options.Adr_Widget_Oggenc_downmix = GTK_COMBO_BOX (widget);
 }
-void optionsOggenc_combobox_oggenc_downmix_changed (void)
+void on_combobox_oggenc_downmix_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	options_set_datas_interne (COLOR_OGGENC_DOWNMIX, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
+	if (NULL != var_options.Adr_Widget_Oggenc_downmix) {
+		gint ind;
+		if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_downmix))) >= 0)
+			Config.DownmixOggenc = ind;
+		OptionsInternal_set_datas_interne (COLOR_OGGENC_DOWNMIX, var_options.Adr_label_oggenc_ogg, OGGENC_WAV_TO_OGG);
+	}
 }
 
 
+
+
+
+
+
