@@ -30,20 +30,31 @@
  * 
  */
 
+
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
 #include <pthread.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "utils.h"
+#include "extra.h"
+#include "win_info.h"
 #include "play_file.h"
 
 
@@ -62,7 +73,7 @@ void PlayFile_call (void)
 	pid_t  pid;
 
 	if ((pid = fork ()) == 0) {
-		if (PlayFile.Param != NULL && *PlayFile.Param != '\0') {
+		if (NULL != PlayFile.Param && '\0' != *PlayFile.Param) {
 			execlp (PlayFile.Playeur,
 				PlayFile.Playeur,
 				PlayFile.Param,
@@ -86,26 +97,32 @@ static void PlayFile_thread (void *arg)
 	pthread_exit(0);
 }
 
-void PlayFile_play (gchar *Playeur, gchar *Param, gchar *PathNameFile)
+void PlayFile_play (gchar *PathNameFile)
 {
 	PRINT_FUNC_LF();
-	g_print ("\t%s %s %s\n", Playeur, Param, PathNameFile);
+	g_print ("\t%s\n", PathNameFile);
 	
+	if (FALSE == extra_get_lecteur_audio_is_ok ()) {
+		PRINT("VEUILLEZ SAISIR UN LECTEUR AUDIO");
+		wininfo_create (
+			_("PAS de lecteur audio present"),
+			_("Veuillez installez un lecteur audio."),
+			  "");
+		return;
+	}
 	
 	if (PlayFile.Playeur != NULL) {
-		g_free (PlayFile.Playeur);
-		PlayFile.Playeur = NULL;
+		g_free (PlayFile.Playeur);	PlayFile.Playeur = NULL;
 	}
 	if (PlayFile.Param != NULL) {
-		g_free (PlayFile.Param);
-		PlayFile.Param = NULL;
+		g_free (PlayFile.Param);	PlayFile.Param = NULL;
 	}
 	if (PlayFile.PathNameFile != NULL) {
-		g_free (PlayFile.PathNameFile);
-		PlayFile.PathNameFile = NULL;
+		g_free (PlayFile.PathNameFile);	PlayFile.PathNameFile = NULL;
 	}
-	PlayFile.Playeur      = g_strdup (Playeur);
-	PlayFile.Param        = g_strdup (Param);
+	
+	PlayFile.Playeur      = g_strdup (extra_get_name_lecteur_audio ());
+	PlayFile.Param        = g_strdup (extra_get_param_name_lecteur_audio ());
 	PlayFile.PathNameFile = g_strdup (PathNameFile);
 	pthread_create (&PlayFile.nmr_tid, NULL ,(void *)PlayFile_thread, (void *)NULL);
 }
