@@ -31,11 +31,11 @@
  */
 
 
-#ifndef __play_file_h__
-#define __play_file_h__ 1
+#ifndef play_file_h
+#define play_file_h 1
 
 
-void PlayFile_play (gchar *Playeur, gchar *Param, gchar *PathNameFile);
+void PlayFile_play (gchar *PathNameFile);
 
 
 #endif
