@@ -31,7 +31,21 @@
  */
  
  
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
 #include <gtk/gtk.h>
+
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "poche.h"
  
  
@@ -57,7 +71,7 @@ gchar *code_entete_ps [] =
 
 /* Production xcfa
  * xcfa - GTK+ implementation of the GNU shell command
- * 2003,2004,2005,2006,2007 Claude Bulin
+ * 2003 - 2010  Claude Bulin
  */
 gchar *code_xcfa_ps [] =
 {
@@ -92,18 +106,59 @@ gchar *code_xcfa_ps [] =
 "/l4 { tabcover 9 get } def		%",
 " ",
 "/title (TITRE DU CD) def		% -- PARAM_TITLE",
-"/fonttitle /Times-Bold def		% la police du titre",
+
+"/Times-Bold findfont			% prise en compte des accents",
+"dup length dict begin			%",
+"{ 1 index /FID ne			%",
+"  {def}					%",
+"  {pop pop}				%",
+"  ifelse				%",
+"} forall				%",
+" ",
+"/Encoding ISOLatin1Encoding def		%",
+"currentdict				%",
+"end					%",
+"/Times-Bold-ISOLatin1 exch definefont pop	%",
+"/fonttitle /Times-Bold-ISOLatin1 def		% la police du titre",
 "/sizefonttitle 16 def			% la taille du titre",
+
 "/bool_title_cover true def		% -- PARAM_BOOL_TITLE_COVER",
 "/bool_title_back true def		% -- PARAM_BOOL_TITLE_BACK",
 " ",
 "/foottext (indication de pied de page) def	% -- PARAM_FOOTTEXT",
 "/bool_foottext_cover true def		% -- PARAM_BOOL_FOOTTEXT_COVER",
 "/bool_foottext_back true def		% -- PARAM_BOOL_FOOTTEXT_BACK",
-"/fontfoottext /Helvetica def		%",
+
+"/Times findfont				% prise en compte des accents",
+"dup length dict begin			%",
+"{ 1 index /FID ne			%",
+"  {def}					%",
+"  {pop pop}				%",
+"  ifelse				%",
+"} forall				%",
+" ",
+"/Encoding ISOLatin1Encoding def		%",
+"currentdict				%",
+"end					%",
+"/Times-ISOLatin1 exch definefont pop	%",
+"/fontfoottext /Times-ISOLatin1 def	%",
 "/sizefontfoottext 7 def			%",
 " ",
-"/fonttextdata /Times-Roman def		% la police pour 'cover' / 'back'",
+
+"/Times-Roman findfont			% prise en compte des accents",
+"dup length dict begin			%",
+"{ 1 index /FID ne			%",
+"  {def}					%",
+"  {pop pop}				%",
+"  ifelse				%",
+"} forall				%",
+" ",
+"/Encoding ISOLatin1Encoding def		%",
+"currentdict				%",
+"end					%",
+"/Times-Roman-ISOLatin1 exch definefont pop	%",
+"/fonttextdata /Times-Roman-ISOLatin1 def	% la police pour 'cover' / 'back'",
+
 "/sizefonttextdata 10 def		% la taille",
 "/bool_textdata_cover true def		% -- PARAM_BOOL_TEXTDATA_COVER",
 "/bool_textdata_back true def		% -- PARAM_BOOL_TEXTDATA_BACK",
