@@ -30,17 +30,26 @@
  * 
  */
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
 #include <string.h>
 #include <stdlib.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "config_user.h"
+#include "configuser.h"
 #include "poche.h"
 
 
@@ -126,6 +135,10 @@ void gdk_gc_set_function (GdkGC *gc, GdkFunction function);
 */
 
 
+
+
+// 
+// 
 void pochedraw_draw_grille_img (void)
 {
 	GdkColor      gdk_color;
@@ -133,9 +146,9 @@ void pochedraw_draw_grille_img (void)
 	GdkGC        *gc;
 	gint          cptab = 0;
 
-	if (!poche.Adr_image_preview) return;
+	if (NULL == poche.Adr_image_preview) return;
 
-	colormap = gdk_window_get_colormap (poche.Adr_image_preview->window);
+	colormap = gdk_drawable_get_colormap (poche.Adr_image_preview->window);
 	FOND_BLANC
 	gc = gdk_gc_new (poche.Adr_image_preview->window);
 	CRAYON_BLEU
@@ -165,7 +178,8 @@ void pochedraw_draw_grille_img (void)
 	}
 	gdk_gc_destroy (gc);
 }
-
+// 
+// 
 gboolean pochedraw_get_grille_img (void)
 {
 #define W 612.0
@@ -179,9 +193,7 @@ gboolean pochedraw_get_grille_img (void)
 	gint          point = 0;
 	gint          cptab = 0;
 
-	if (!poche.Adr_image_preview) return (FALSE);
-
-	/*gdk_window_clear (poche.Adr_image_preview->window);*/
+	if (NULL == poche.Adr_image_preview) return (FALSE);
 
 	largeur = (percent * 612.0) / 100.0;
 	hauteur = (percent * 792.0) / 100.0;
@@ -206,7 +218,6 @@ gboolean pochedraw_get_grille_img (void)
 	poche.tab [ cptab ].x2 = y1;
 	poche.tab [ cptab ].y2 = y2;
 	cptab ++;
-	/*gdk_draw_line (poche.Adr_image_preview->window, poche.Adr_image_preview->style->black_gc, x1-7, x2, y1+7, y2);*/
 
 	/* recto bas */
 	x2 = (percent * (gdouble)(792.0-(PTR1))) / 100.0;
@@ -309,7 +320,8 @@ gboolean pochedraw_get_grille_img (void)
 	
 	return (TRUE);
 }
-
+// 
+// 
 void pochedraw_draw_grille_base (void)
 {
 #define W 612.0
@@ -326,21 +338,11 @@ void pochedraw_draw_grille_base (void)
 	gint          point = 0;
 	gint          cptab = 0;
 
-	if (!poche.Adr_image_preview) return;
+	if (NULL == poche.Adr_image_preview) return;
 
-	if (Config_User.Bool_Config_Ok == FALSE) return;
-	if (Config_User.notebook_general != NOTEBOOK_POCHETTE) return;
+	if (FALSE == Config.BoolConfigOk) return;
+	if (Config.NotebookGeneral != NOTEBOOK_POCHETTE) return;
 	
-	/*PRINT_FUNC_LF();*/
-
-	/*gdk_window_clear (poche.Adr_image_preview->window);*/
-	/*gdk_window_clear_area (poche.Adr_image_preview->window,
-				poche.Adr_image_preview->allocation.x,
-				poche.Adr_image_preview->allocation.y,
-				poche.Adr_image_preview->allocation.width,
-				poche.Adr_image_preview->allocation.height
-				);*/
-
 	largeur = (percent * 612.0) / 100.0;
 	hauteur = (percent * 792.0) / 100.0;
 	gtk_widget_set_size_request (poche.Adr_image_preview, largeur +2, hauteur +2);
@@ -350,7 +352,7 @@ void pochedraw_draw_grille_base (void)
 	diff_largeur = x = (w/2)-(largeur/2);
 	diff_hauteur = y = (h/2)-(hauteur/2);
 
-	colormap = gdk_window_get_colormap (poche.Adr_image_preview->window);
+	colormap = gdk_drawable_get_colormap (poche.Adr_image_preview->window);
 	FOND_BLANC
 	gc = gdk_gc_new (poche.Adr_image_preview->window);
 	CRAYON_NOIR
@@ -530,35 +532,11 @@ gdk_draw_line (poche.Adr_image_preview->window, gc, x1, x2-7, y1, y2+7);
 
 	gdk_gc_destroy (gc);
 }
-
-
+// 
+// 
 void pochedraw_redraw_image (void)
 {
-	/*GdkRectangle update_rect;*/
-	
 	if (poche.Adr_image_preview == NULL) return;
-	/*
-	g_print ("poche.Adr_image_preview->allocation.x      = %d\n", poche.Adr_image_preview->allocation.x);
-	g_print ("poche.Adr_image_preview->allocation.y      = %d\n", poche.Adr_image_preview->allocation.y);
-	g_print ("poche.Adr_image_preview->allocation.width  = %d\n", poche.Adr_image_preview->allocation.width);
-	g_print ("poche.Adr_image_preview->allocation.height = %d\n", poche.Adr_image_preview->allocation.height);
-
-	update_rect.x      = poche.Adr_image_preview->allocation.x;
-	update_rect.y      = poche.Adr_image_preview->allocation.y;
-	update_rect.width  = poche.Adr_image_preview->allocation.width;
-	update_rect.height = poche.Adr_image_preview->allocation.height;
-
-	gdk_draw_rectangle (
-			poche.Adr_image_preview->window,
-  			poche.Adr_image_preview->style->white_gc,
-   			FALSE,
-			update_rect.x,
-			update_rect.y,
-			update_rect.width,
-			update_rect.height
-			);
-	gtk_widget_draw (poche.Adr_image_preview, &update_rect);
-	*/
 	gtk_widget_queue_draw_area (
 				poche.Adr_image_preview,
 				poche.Adr_image_preview->allocation.x,
