@@ -23,15 +23,17 @@
  * 
  */
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
-#include "global.h"
-#include "poche.h"
-
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -39,6 +41,14 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
+#include "global.h"
+#include "poche.h"
+
+
 
 /*
 *---------------------------------------------------------------------------
