@@ -30,16 +30,22 @@
  * 
  */
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gprintf.h>
+#include <glib/gstdio.h>
 #include <string.h>
 #include <stdlib.h>
-
 #include <unistd.h>
 #include <dirent.h>
 #include <sys/stat.h>
@@ -47,11 +53,15 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "info_song.h"
-#include "config_user.h"
+#include "configuser.h"
 #include "win_info.h"
 #include "prg_init.h"
+#include "conv.h"
 #include "poche.h"
 
 
@@ -97,20 +107,16 @@ typedef struct {
 } PS;
 
 
-/*
-*---------------------------------------------------------------------------
-* STRUCTURE
-*---------------------------------------------------------------------------
-*/
-
+// 
+// 
 PS *pochegen_remove_struct_ps (PS *p_ps)
 {
 	GList      *List = NULL;
 	FIELDS_PS  *fps = NULL;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
-	if (p_ps) {
+	if (NULL != p_ps) {
 		g_free (p_ps->str_package);
 		p_ps->str_package = NULL;		/* PARAM_PACKAGE 		*/
 		g_free (p_ps->str_version);
@@ -122,11 +128,12 @@ PS *pochegen_remove_struct_ps (PS *p_ps)
 
 		List = g_list_first (p_ps->glist_fields);
 		while (List) {
-			if ((fps = (FIELDS_PS *)List->data)) {
-				g_free (fps->author);
-				g_free (fps->title);
-				g_free (fps->time);
-				List->data = NULL;
+			if (NULL != (fps = (FIELDS_PS *)List->data)) {
+				g_free (fps->author);	fps->author = NULL;
+				g_free (fps->title);	fps->title = NULL;
+				g_free (fps->time);	fps->time = NULL;
+				g_free (fps);
+				fps = List->data = NULL;
 			}
 			List = g_list_next (List);
 		}
@@ -138,12 +145,13 @@ PS *pochegen_remove_struct_ps (PS *p_ps)
 	}
 	return (NULL);
 }
-
+// 
+// 
 PS *pochegen_allocate_struct_ps (void)
 {
 	PS *new = (PS *)g_malloc0 (sizeof (PS));
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	if (new) {
 		new->str_package = NULL;		/* PARAM_PACKAGE 		*/
@@ -164,10 +172,10 @@ PS *pochegen_allocate_struct_ps (void)
 	}
 	return ((PS *)new);
 }
-
-/* Lecture du buffer textview ligne par ligne pour le stocker dans des
-*  structures 'TEXTDATA' qui seront chainees dans un GList
-*/
+// 
+// Lecture du buffer textview ligne par ligne pour le stocker dans des
+// structures 'TEXTDATA' qui seront chainees dans un GList
+// 
 GList *pochegen_get_glist_from_textview (void)
 {
 	GList         *List = NULL;
@@ -186,7 +194,7 @@ GList *pochegen_get_glist_from_textview (void)
 	gchar         *PtrDummy = NULL;
 	
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	/* Suppression des lignes vides en fin de texte */
 	for (Cpt = Total_Line; Cpt > 1; Cpt --) {
@@ -195,7 +203,8 @@ GList *pochegen_get_glist_from_textview (void)
 		gtk_text_buffer_get_end_iter (Buf, &End);
 		
 		PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
-		Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+		// Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+		Ptr_buf = g_strdup(PtrDummy);
 		g_free (PtrDummy);
 		PtrDummy = NULL;
 		// Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
@@ -204,30 +213,32 @@ GList *pochegen_get_glist_from_textview (void)
 			gtk_text_buffer_delete (Buf, &Start, &End);
 		else	break;
 	}
-
+	g_free (Ptr_buf);
+	Ptr_buf = NULL;
 	/* Get start-end buffer text with coord. in utf8 */
 	Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 	gtk_text_buffer_get_bounds (Buf, &Start, &End);
 	
 	PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
-	Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+	// Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+	Ptr_buf = g_strdup(PtrDummy);
 	g_free (PtrDummy);
 	PtrDummy = NULL;
 	// Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
-
 	/* Decompose le buffer en lignes de texte */
 	Larrbuf = g_strsplit(Ptr_buf, "\n", 0);
+	g_free (Ptr_buf);
+	Ptr_buf = NULL;
 
 	for (i=0; Larrbuf[i]; i++) {
 		/* delette end cars line */
 		if ((Ptr = strrchr (Larrbuf[i], 13))) *Ptr = '\0';
 		if ((Ptr = strrchr (Larrbuf[i], 10))) *Ptr = '\0';
-
 		/* total car '-' in Larrbuf[i] pour 'separator' */
 		for (separator = 0, Ptr = Larrbuf[i]; ; ) {
 			/* Ptr = strchr (Ptr, '-'); */
 			Ptr = strstr (Ptr, " - ");
-			if (!Ptr) break;
+			if (NULL == Ptr) break;
 			Ptr++;
 			Ptr++;
 			Ptr++;
@@ -303,12 +314,12 @@ GList *pochegen_get_glist_from_textview (void)
 	NList = g_list_last (List);
 	while (NList) {
 		ps = (FIELDS_PS *)NList->data;
-		if (ps && *ps->author == '\0' && *ps->title == '\0') {
-			g_free (ps->author); ps->author = NULL;
-			g_free (ps->title); ps->title = NULL;
-			g_free (ps->time); ps->time = NULL;
-			g_free (ps); ps = NULL;
-			NList->data = NULL;
+		if (NULL != ps && *ps->author == '\0' && *ps->title == '\0') {
+			if (ps->author) { g_free (ps->author); ps->author = NULL; }
+			if (ps->title)  { g_free (ps->title);  ps->title = NULL;  }
+			if (ps->time)   { g_free (ps->time);   ps->time = NULL;   }
+			g_free (ps);
+			ps = NList->data = NULL;
 		}
 		else {
 			break;
@@ -319,7 +330,8 @@ GList *pochegen_get_glist_from_textview (void)
 
 	return (List);
 }
-
+// 
+// 
 PS *pochegen_get_struct_ps (void)
 {
 	PS   *new = NULL;
@@ -330,7 +342,7 @@ PS *pochegen_get_struct_ps (void)
 		return (NULL);
 	}
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	new->str_package = g_strdup (PACKAGE);
 	new->str_version = g_strdup (VERSION);
@@ -369,7 +381,6 @@ PS *pochegen_get_struct_ps (void)
 		new->bool_title_back = FALSE;
 	}
 	*/
-	
 	/* Pied de page sur recto / verso */
 	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (poche.Adr_combobox_entry_foottext))) {
 	case 0 :
@@ -470,18 +481,15 @@ PS *pochegen_get_struct_ps (void)
 
 	return ((PS *)new);
 }
-
-/*
-*---------------------------------------------------------------------------
-* GEN CODE IMAGEMAGICK
-*---------------------------------------------------------------------------
-*/
+// 
+// GEN CODE IMAGEMAGICK
+// 
 void pochegen_code_convert_ps (void)
 {
 	FILE  *fp_preview = NULL;
 	guint  line = 0;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	fp_preview = fopen (poche.file_preview_ps, "a");
 	while (*code_convert_ps [ line ]) {
@@ -491,23 +499,247 @@ void pochegen_code_convert_ps (void)
 	fclose (fp_preview);
 }
 
+
+/*
+http://groups.google.com/group/fr.comp.lang.postscript/browse_thread/thread/02c45a9323555bce/6ea3bd76a5363612
+In article
+<20b53f10-2209-494e-96ef-2b934820a...@26g2000hsk.googlegroups.com>,
+ Ahmed Ayadi <ayadi.ahmed.e...@gmail.com> wrote:
+
+> Je suis nouveau avec le language Postscript. J'aime bien imprimé des
+> documents postscript avec des lettres avec accent comme 'é', 'à' et
+> 'ç'.
+
+Bonsoir.
+En supposant l'usage de caractères sur 8 bits, il faut procéder au
+recodage de la fonte.
+
+Une fonte (Type 1, Type 3, TrueType, OpenType etc...) contient une
+association entre un code numérique (code de caractère) et un dessin
+vectoriel (glyphe) qui représente en général (au moins dans les langues
+alphabétiques) une lettre, un chiffre, un signe de ponctuation etc...
+Cette association est l'encodage. (encoding)
+Cette association n'est pas fixée et peut être modifié via une
+programmation Postscript adéquate. Cette programmation se nomme
+'recodage' (re-encoding).
+En Postscript les fontes ne sont pas tenues d'avoir un encodage
+particulier,  et donc pour avoir des résultats reproductible avec
+n'importe quelle fonte, le recodage est indispensable.
+
+Pour une fonte T1 (ou Type 42, expression Postscript d'une TrueType),
+l'encodage est donnée par le vecteur dont la clef est /Encoding dans le
+dictionnaire de la fonte. Il faut modifier ce vecteur pour recoder la
+fonte. Ce vecteur comporte 256 valeurs (indicées par le code de
+caractère sur 8 bits, de 0 à 255). Chaque valeur de ce vecteur est un
+nom de glyphe, identifiant le dessin qui sera effectué.
+
+Donc pour recoder une fonte, on fait une copie du dictinnaire de fonte
+où l'on assigne des valeurs différente aux éléments du vecteur
+/Encoding. Les interpréteurs PS prédéfinissent des vecteurs usuels, ce
+qui évite de devoir réinventer la roue. Un de ces vecteurs est
+/ISOLatin1Encoding (voir Red Book annexe E)
+
+Muni de ces explications, l'exemple du Red Book section 5.9.1 se
+comprend mieux (sachant que pour des raisons d'unicité, il n'est pas
+permis de cloner l'identificateur de fonte contenu sous clef /FID du
+dictionnaire de fonte):
+
+/Helvetica findfont
+dup length dict begin
+{ 1 index /FID ne
+  {def}
+  {pop pop}
+  ifelse
+} forall
+
+/Encoding ISOLatin1Encoding def
+currentdict
+end
+/Helvetica-ISOLatin1 exch definefont pop
+
+/Helvetica-ISOLatin1 findfont 30 scalefont setfont
+20 120 moveto (c cedille ç \347 ) show
+20 90 moveto  (e grave è \350 ) show
+20 60 moveto  (a grave à \340 ) show
+showpage
+
+François Robert
+*/
+
+
+/*
+http://www.utf8-chartable.de/
+	Table de caracteres
+*/
+
+/*
+page 615 depuis:
+	Manuel de reference du langage Postscript Edition: Addison-Wesley
+*/
+typedef struct {
+	gint	car1, car2;
+	gint	CarPostscript;
+} TABLE_PS;
+
+#define TOTAL_TABLE_PS 95
+
+TABLE_PS TablePS [ TOTAL_TABLE_PS ] = {
+
+ { 0xc2, 0xa1, 241 },	// 	¡	 INVERTED EXCLAMATION MARK
+ { 0xc2, 0xa2, 242 },	// 	¢	 CENT SIGN
+ { 0xc2, 0xa3, 243 },	// 	£	 POUND SIGN
+ { 0xc2, 0xa4, 244 },	// 	¤	 CURRENCY SIGN
+ { 0xc2, 0xa5, 245 },	// 	¥	 YEN SIGN
+ { 0xc2, 0xa6, 246 },	// 	¦	 BROKEN BAR
+ { 0xc2, 0xa7, 247 },	// 	§	 SECTION SIGN
+ { 0xc2, 0xa8, 250 },	//	¨	 DIAERESIS
+ { 0xc2, 0xa9, 251 },	//	©	 COPYRIGHT SIGN
+ { 0xc2, 0xaa, 252 },	//	ª	 FEMININE ORDINAL INDICATOR
+ { 0xc2, 0xab, 253 },	//	«	 LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+ { 0xc2, 0xac, 254 },	//	¬	 NOT SIGN
+ { 0xc2, 0xad, 255 },	//		 SOFT HYPHEN
+ { 0xc2, 0xae, 256 },	//	®	 REGISTERED SIGN
+ { 0xc2, 0xaf, 257 },	//	¯	 MACRON
+ { 0xc2, 0xb0, 260 },	//	°	 DEGREE SIGN
+ { 0xc2, 0xb1, 261 },	//	±	 PLUS-MINUS SIGN
+ { 0xc2, 0xb2, 262 },	//	²	 SUPERSCRIPT TWO
+ { 0xc2, 0xb3, 263 },	//	³	 SUPERSCRIPT THREE
+ { 0xc2, 0xb4, 264 },	//	´	 ACUTE ACCENT
+ { 0xc2, 0xb5, 265 },	//	µ	 MICRO SIGN
+ { 0xc2, 0xb6, 266 },	//	¶	 PILCROW SIGN
+ { 0xc2, 0xb7, 267 },	//	·	 MIDDLE DOT
+ { 0xc2, 0xb8, 270 },	//	¸	 CEDILLA
+ { 0xc2, 0xb9, 271 },	//	¹	 SUPERSCRIPT ONE
+ { 0xc2, 0xba, 272 },	//	º	 MASCULINE ORDINAL INDICATOR
+ { 0xc2, 0xbb, 273 },	//	»	 RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+ { 0xc2, 0xbc, 274 },	//	¼	 VULGAR FRACTION ONE QUARTER
+ { 0xc2, 0xbd, 275 },	//	½	 VULGAR FRACTION ONE HALF
+ { 0xc2, 0xbe, 276 },	//	¾	 VULGAR FRACTION THREE QUARTERS
+ { 0xc2, 0xbf, 277 },	//	¿	 INVERTED QUESTION MARK
+ { 0xc3, 0x80, 300 },	//	À	 LATIN CAPITAL LETTER A WITH GRAVE
+ { 0xc3, 0x81, 301 },	//	Á	 LATIN CAPITAL LETTER A WITH ACUTE
+ { 0xc3, 0x82, 302 },	//	Â	 LATIN CAPITAL LETTER A WITH CIRCUMFLEX
+ { 0xc3, 0x83, 303 },	//	Ã	 LATIN CAPITAL LETTER A WITH TILDE
+ { 0xc3, 0x84, 304 },	//	Ä	 LATIN CAPITAL LETTER A WITH DIAERESIS
+ { 0xc3, 0x85, 305 },	//	Å	 LATIN CAPITAL LETTER A WITH RING ABOVE
+ { 0xc3, 0x86, 306 },	//	Æ	 LATIN CAPITAL LETTER AE
+ { 0xc3, 0x87, 307 },	//	Ç	 LATIN CAPITAL LETTER C WITH CEDILLA
+ { 0xc3, 0x88, 310 },	//	È	 LATIN CAPITAL LETTER E WITH GRAVE
+ { 0xc3, 0x89, 311 },	//	É	 LATIN CAPITAL LETTER E WITH ACUTE
+ { 0xc3, 0x8a, 312 },	//	Ê	 LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+ { 0xc3, 0x8b, 313 },	//	Ë	 LATIN CAPITAL LETTER E WITH DIAERESIS
+ { 0xc3, 0x8c, 314 },	//	Ì	 LATIN CAPITAL LETTER I WITH GRAVE
+ { 0xc3, 0x8d, 315 },	//	Í	 LATIN CAPITAL LETTER I WITH ACUTE
+ { 0xc3, 0x8e, 316 },	//	Î	 LATIN CAPITAL LETTER I WITH CIRCUMFLEX
+ { 0xc3, 0x8f, 317 },	//	Ï	 LATIN CAPITAL LETTER I WITH DIAERESIS
+ { 0xc3, 0x90, 320 },	//	Ð	 LATIN CAPITAL LETTER ETH
+ { 0xc3, 0x91, 321 },	//	Ñ	 LATIN CAPITAL LETTER N WITH TILDE
+ { 0xc3, 0x92, 322 },	//	Ò	 LATIN CAPITAL LETTER O WITH GRAVE
+ { 0xc3, 0x93, 323 },	//	Ó	 LATIN CAPITAL LETTER O WITH ACUTE
+ { 0xc3, 0x94, 324 },	//	Ô	 LATIN CAPITAL LETTER O WITH CIRCUMFLEX
+ { 0xc3, 0x95, 325 },	//	Õ	 LATIN CAPITAL LETTER O WITH TILDE
+ { 0xc3, 0x96, 326 },	//	Ö	 LATIN CAPITAL LETTER O WITH DIAERESIS
+ { 0xc3, 0x97, 327 },	// 	×	 MULTIPLICATION SIGN
+ { 0xc3, 0x98, 330 },	//	Ø	 LATIN CAPITAL LETTER O WITH STROKE
+ { 0xc3, 0x99, 331 },	//	Ù	 LATIN CAPITAL LETTER U WITH GRAVE
+ { 0xc3, 0x9a, 332 },	//	Ú	 LATIN CAPITAL LETTER U WITH ACUTE
+ { 0xc3, 0x9b, 333 },	//	Û	 LATIN CAPITAL LETTER U WITH CIRCUMFLEX
+ { 0xc3, 0x9c, 334 },	//	Ü	 LATIN CAPITAL LETTER U WITH DIAERESIS
+ { 0xc3, 0x9d, 335 },	//	Ý	 LATIN CAPITAL LETTER Y WITH ACUTE
+ { 0xc3, 0x9e, 336 },	//	Þ	 LATIN CAPITAL LETTER THORN
+ { 0xc3, 0x9f, 337 },	//	ß	 LATIN SMALL LETTER SHARP S
+ { 0xc3, 0xa0, 340 },	//	à	 LATIN SMALL LETTER A WITH GRAVE
+ { 0xc3, 0xa1, 341 },	//	á	 LATIN SMALL LETTER A WITH ACUTE
+ { 0xc3, 0xa2, 342 },	//	â	 LATIN SMALL LETTER A WITH CIRCUMFLEX
+ { 0xc3, 0xa3, 343 },	//	ã	 LATIN SMALL LETTER A WITH TILDE
+ { 0xc3, 0xa4, 344 },	//	ä	 LATIN SMALL LETTER A WITH DIAERESIS
+ { 0xc3, 0xa5, 345 },	//	å	 LATIN SMALL LETTER A WITH RING ABOVE
+ { 0xc3, 0xa6, 346 },	//	æ	 LATIN SMALL LETTER AE
+ { 0xc3, 0xa7, 347 },	//	ç	 LATIN SMALL LETTER C WITH CEDILLA
+ { 0xc3, 0xa8, 350 },	//	è	 LATIN SMALL LETTER E WITH GRAVE
+ { 0xc3, 0xa9, 351 },	//	é	 LATIN SMALL LETTER E WITH ACUTE
+ { 0xc3, 0xaa, 352 },	//	ê	 LATIN SMALL LETTER E WITH CIRCUMFLEX
+ { 0xc3, 0xab, 353 },	//	ë	 LATIN SMALL LETTER E WITH DIAERESIS
+ { 0xc3, 0xac, 354 },	//	ì	 LATIN SMALL LETTER I WITH GRAVE
+ { 0xc3, 0xad, 355 },	//	í	 LATIN SMALL LETTER I WITH ACUTE
+ { 0xc3, 0xae, 356 },	//	î	 LATIN SMALL LETTER I WITH CIRCUMFLEX
+ { 0xc3, 0xaf, 357 },	//	ï	 LATIN SMALL LETTER I WITH DIAERESIS
+ { 0xc3, 0xb0, 360 },	//	ð	 LATIN SMALL LETTER ETH
+ { 0xc3, 0xb1, 361 },	//	ñ	 LATIN SMALL LETTER N WITH TILDE
+ { 0xc3, 0xb2, 362 },	//	ò	 LATIN SMALL LETTER O WITH GRAVE
+ { 0xc3, 0xb3, 363 },	//	ó	 LATIN SMALL LETTER O WITH ACUTE
+ { 0xc3, 0xb4, 364 },	//	ô	 LATIN SMALL LETTER O WITH CIRCUMFLEX
+ { 0xc3, 0xb5, 365 },	//	õ	 LATIN SMALL LETTER O WITH TILDE
+ { 0xc3, 0xb6, 366 },	//	ö	 LATIN SMALL LETTER O WITH DIAERESIS
+ { 0xc3, 0xb7, 367 },	//	÷	 DIVISION SIGN
+ { 0xc3, 0xb8, 370 },	//	ø	 LATIN SMALL LETTER O WITH STROKE
+ { 0xc3, 0xb9, 371 },	//	ù	 LATIN SMALL LETTER U WITH GRAVE
+ { 0xc3, 0xba, 372 },	//	ú	 LATIN SMALL LETTER U WITH ACUTE
+ { 0xc3, 0xbb, 373 },	//	û	 LATIN SMALL LETTER U WITH CIRCUMFLEX
+ { 0xc3, 0xbc, 374 },	//	ü	 LATIN SMALL LETTER U WITH DIAERESIS
+ { 0xc3, 0xbd, 375 },	//	ý	 LATIN SMALL LETTER Y WITH ACUTE
+ { 0xc3, 0xbe, 376 },	//	þ	 LATIN SMALL LETTER THORN
+ { 0xc3, 0xbf, 377 }	//	ÿ	 LATIN SMALL LETTER Y WITH DIAERESIS
+
+};
+
+// 
+// 
+gint pochegen_get_car_table_ps (gint car1, gint car2)
+{
+	gint	cpt;
+	
+	for (cpt = 0; cpt < TOTAL_TABLE_PS; cpt ++) {
+		if (car1 == TablePS [ cpt ] . car1 && car2 == TablePS [ cpt ] . car2) break;
+	}
+	if (cpt >= TOTAL_TABLE_PS) {
+		return (40);	// ESPACE
+	}
+	
+	return ( TablePS [ cpt ] . CarPostscript );
+}
+// 
+// 
+void pochegen_fprintf (FILE *fp, gchar *buf)
+{
+	gchar	*Ptr = buf;
+	gint	car1, car2;
+	
+	fprintf (fp, "(");
+	while (*Ptr) {
+		if (*Ptr < 0) {
+			car1 = *Ptr;
+			car1 &= 0xff;
+			car2 = *(Ptr +1);
+			car2 &= 0xff;
+			fprintf (fp, "\\%03d", pochegen_get_car_table_ps (car1, car2));
+			Ptr ++;
+		}
+		else {
+			fprintf (fp, "%c", *Ptr);
+		}
+		Ptr ++;
+	}
+	fprintf (fp, ")");
+}
 /*
 *---------------------------------------------------------------------------
 * GEN CODE XCFA
 *---------------------------------------------------------------------------
 */
 
-/* Generation du fichier PostScript
-*/
+// 
+// Generation du fichier PostScript
+// 
 void pochegen_code_xcfa_ps (void)
 {
-	FILE       *fp_preview = NULL;
-	gint        line = 0;
-	PS         *new = NULL;
-	GList      *List = NULL;
-	FIELDS_PS  *ps = NULL;
+	FILE		*fp_preview = NULL;
+	gint		line = 0;
+	PS		*new = NULL;
+	GList		*List = NULL;
+	FIELDS_PS	*ps = NULL;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	if ((new = pochegen_get_struct_ps ()) == NULL) {
 		g_print ("ERREUR D'ALLOCATION MEMOIRE\n");
@@ -519,7 +751,6 @@ void pochegen_code_xcfa_ps (void)
 	line = 0;
 
 	while (*code_xcfa_ps [ line ]) {
-
 		/* PARAM_PACKAGE	*/
 		if (strstr (code_xcfa_ps [ line ], "PARAM_PACKAGE")) {
 			fprintf (fp_preview, "/PACKAGE (%s) def\n", new->str_package);
@@ -530,7 +761,12 @@ void pochegen_code_xcfa_ps (void)
 		}
 		/* PARAM_TITLE	*/
 		else if (strstr (code_xcfa_ps [ line ], "PARAM_TITLE")) {
-			fprintf (fp_preview, "/title (%s) def\n", new->str_title);
+			
+			// fprintf (fp_preview, "/title (%s) def\n", new->str_title);
+			
+			fprintf (fp_preview, "/title ");
+			pochegen_fprintf (fp_preview, new->str_title);
+			fprintf (fp_preview, " def\n");
 		}
 		/* PARAM_BOOL_TITLE_COVER	*/
 		else if (strstr (code_xcfa_ps [ line ], "PARAM_BOOL_TITLE_COVER")) {
@@ -542,7 +778,12 @@ void pochegen_code_xcfa_ps (void)
 		}
 		/* PARAM_FOOTTEXT	*/
 		else if (strstr (code_xcfa_ps [ line ], "PARAM_FOOTTEXT")) {
-			fprintf (fp_preview, "/foottext (%s) def\n", new->str_foottext);
+		
+			// fprintf (fp_preview, "/foottext (%s) def\n", new->str_foottext);
+			
+			fprintf (fp_preview, "/foottext ");
+			pochegen_fprintf (fp_preview, new->str_foottext);
+			fprintf (fp_preview, " def\n");
 		}
 		/* PARAM_BOOL_FOOTTEXT_COVER	*/
 		else if (strstr (code_xcfa_ps [ line ], "PARAM_BOOL_FOOTTEXT_COVER")) {
@@ -584,14 +825,21 @@ void pochegen_code_xcfa_ps (void)
 			*/
 			List = g_list_first (new->glist_fields);
 			if (List) {
+			
 				fprintf (fp_preview, "/textdata [\n");
 				while (List) {
 					if ((ps = (FIELDS_PS *)List->data)) {
-						fprintf (fp_preview, "(%s)",  ps->author);
-						fprintf (fp_preview, " (%s)", ps->title);
+						
+						// fprintf (fp_preview, "(%s)",  ps->author);
+						pochegen_fprintf (fp_preview, ps->author);
+												
+						// fprintf (fp_preview, " (%s)", ps->title);
+						pochegen_fprintf (fp_preview, ps->title);
+						
 						if (*ps->author || *ps->title)
 							fprintf (fp_preview, " (%s)", ps->time);
 						else	fprintf (fp_preview, " ()");
+						
 						fprintf (fp_preview, "\n");
 					}
 					List = g_list_next (List);
@@ -614,14 +862,9 @@ void pochegen_code_xcfa_ps (void)
 
 	new = pochegen_remove_struct_ps (new);
 }
-
-/*
-*---------------------------------------------------------------------------
-* GENERATION DU CODE POSTSCRIPT RECTO / VERSO
-*---------------------------------------------------------------------------
-*/
-
-
+// 
+// GENERATION DU CODE POSTSCRIPT RECTO / VERSO
+// 
 GLIST_POCHETTE *pochegen_get_elem_actif (gboolean bool_recto)
 {
 	GLIST_POCHETTE *ptr = NULL;
@@ -632,7 +875,8 @@ GLIST_POCHETTE *pochegen_get_elem_actif (gboolean bool_recto)
 
 	return ((GLIST_POCHETTE *)ptr);
 }
-
+// 
+// 
 gboolean pochegen_creation_postscript_recto (void)
 {
 	GLIST_POCHETTE *gl = NULL;
@@ -643,11 +887,11 @@ gboolean pochegen_creation_postscript_recto (void)
 	gchar  buf   [ MAX_CARS +1 ];
 	gchar		*Dummy;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	if ((gl = pochegen_get_elem_actif (TRUE))) {
 
-		if (infosong_file_is_reg (poche.file_recto_ps) == TRUE) {
+		if (libutils_test_file_exist (poche.file_recto_ps) == TRUE) {
 			/*g_print ("PAS DE GENERATION RECTO\n");*/
 			return (TRUE);
 		}
@@ -657,7 +901,7 @@ gboolean pochegen_creation_postscript_recto (void)
 		pocheexec_convert_to_postscript (gl->name_img, file_recto_tmp);
 	}
 	else {
-		infosong_delete_file (poche.file_recto_ps);
+		g_unlink (poche.file_recto_ps);
 		return (FALSE);
 	}
 
@@ -692,14 +936,15 @@ gboolean pochegen_creation_postscript_recto (void)
 	fclose (fp_recto);
 	fclose (fp_recto_tmp);
 
-	infosong_delete_file (file_recto_tmp);
+	g_unlink (file_recto_tmp);
 
 	g_free (file_recto_tmp);
 	file_recto_tmp = NULL;
 
 	return (TRUE);
 }
-
+// 
+// 
 gboolean pochegen_creation_postscript_verso (void)
 {
 	GLIST_POCHETTE *gl = NULL;
@@ -710,11 +955,11 @@ gboolean pochegen_creation_postscript_verso (void)
 	gchar  buf   [ MAX_CARS +1 ];
 	gchar		*Dummy;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	if ((gl = pochegen_get_elem_actif (FALSE))) {
 
-		if (infosong_file_is_reg (poche.file_verso_ps) == TRUE) {
+		if (libutils_test_file_exist (poche.file_verso_ps) == TRUE) {
 			/*g_print ("PAS DE GENERATION VERSO\n");*/
 			return (TRUE);
 		}
@@ -724,7 +969,7 @@ gboolean pochegen_creation_postscript_verso (void)
 		pocheexec_convert_to_postscript (gl->name_img, file_verso_tmp);
 	}
 	else {
-		infosong_delete_file (poche.file_verso_ps);
+		g_unlink (poche.file_verso_ps);
 		return (FALSE);
 	}
 
@@ -759,14 +1004,15 @@ gboolean pochegen_creation_postscript_verso (void)
 	fclose (fp_verso);
 	fclose (fp_verso_tmp);
 
-	infosong_delete_file (file_verso_tmp);
+	g_unlink (file_verso_tmp);
 
 	g_free (file_verso_tmp);
 	file_verso_tmp = NULL;
 
 	return (TRUE);
 }
-
+// 
+// 
 gchar *pochegen_get_coordonees_recto (void)
 {
 	gchar *str = NULL;
@@ -781,7 +1027,8 @@ gchar *pochegen_get_coordonees_recto (void)
 	str = NULL;
 	return (&poche.coord_recto[0]);
 }
-
+// 
+// 
 gchar *pochegen_get_coordonees_verso (gint choice)
 {
 	gchar *str = NULL;
@@ -796,13 +1043,14 @@ gchar *pochegen_get_coordonees_verso (gint choice)
 	str = NULL;
 	return (&poche.coord_verso[0]);
 }
-
+// 
+// 
 void pochegen_code_entete_ps (void)
 {
 	FILE  *fp_preview = NULL;
 	guint  line = 0;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	fp_preview = fopen (poche.file_preview_ps, "w");
 	while (*code_entete_ps [ line ]) {
@@ -811,13 +1059,9 @@ void pochegen_code_entete_ps (void)
 	}
 	fclose (fp_preview);
 }
-
-/*
-*---------------------------------------------------------------------------
-* GENERATION DU CODE POSTSCRIPT
-*---------------------------------------------------------------------------
-*/
-
+// 
+// GENERATION DU CODE POSTSCRIPT
+// 
 void pochegen_gen_code_postscript (void)
 {
 	FILE     *fp_recto = NULL;
@@ -827,8 +1071,12 @@ void pochegen_gen_code_postscript (void)
 	gchar     buf   [ MAX_CARS +1 ];
 	gboolean  bool_file_recto = FALSE;
 	gboolean  bool_file_verso = FALSE;
+	static gboolean enter_pochegen_gen_code_postscript = FALSE;
+	
+	if (TRUE == enter_pochegen_gen_code_postscript) return;
+	enter_pochegen_gen_code_postscript = TRUE;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	pochegen_code_entete_ps ();
 	bool_file_recto = pochegen_creation_postscript_recto ();
@@ -865,6 +1113,8 @@ void pochegen_gen_code_postscript (void)
 	}
 
 	pochegen_code_xcfa_ps ();
+	
+	enter_pochegen_gen_code_postscript = FALSE;
 }
 
 /*
@@ -873,8 +1123,9 @@ void pochegen_gen_code_postscript (void)
 *---------------------------------------------------------------------------
 */
 
-/* Dimensionne l'image et affichage dans le preview
-*/
+// 
+// Dimensionne l'image et affichage dans le preview
+// 
 void pochegen_affiche_image (void)
 {
 	gdouble  percent = pocheevnt_get_percent_zoom ();
@@ -884,7 +1135,7 @@ void pochegen_affiche_image (void)
 	gchar   *LineCommand = NULL;
 	/*GError  *error = NULL;*/
 	
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	/* Calculs dimension */
 	largeur = (percent * 612.0) / 100.0;
@@ -908,49 +1159,50 @@ void pochegen_affiche_image (void)
 	
 	poche.bool_with_get_grille_img = TRUE;
 }
-
+// 
+// 
 void pochegen_file_postscript (void)
 {
 	gchar *newname = NULL;
 	gchar *PtrName = NULL;
 	
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	PtrName = strrchr (poche.file_preview_ps, '/');
 	PtrName ++;
-	newname = g_strdup_printf ("%s/%s", Config_User.Path_Dest_File_PostScript, PtrName);
-	infosong_copy_file (poche.file_preview_ps, newname);
+	newname = g_strdup_printf ("%s/%s", Config.PathDestFilePostScript, PtrName);
+	conv_copy_src_to_dest (poche.file_preview_ps, newname);
 	g_free (newname);
 	newname = NULL;
 }
-
+// 
+// 
 void pochegen_file_pdf (void)
 {
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	/* Test si ps2pdf est present */
 	if (PrgInit.bool_ps2pdf == FALSE) {
 		wininfo_create (
 			_("ps2pdf est absent"),
+			_("Production du fichier PDF impossible car Le programme"),
 			  "\n",
-			_("   Production du fichier PDF impossible car Le programme"),
-			  "         \n",
-			_("   'ps2pdf' est absent de votre configuration."),
+			_("'ps2pdf' est absent de votre configuration."),
 			  "\n\n",
-		 	_("   SOLUTION:"),
+		 	_("SOLUTION:"),
 		 	  "\n",
-			_("   Installez 'ps2pdf'."),
-			  "\n\n",
+			_("Installez 'ps2pdf'."),
 			  "");
 		return;
 	}
 	/* Fabrication du PDF */
-	pocheexec_make_pdf_file (poche.file_preview_ps, Config_User.Path_Dest_File_PostScript);
+	pocheexec_make_pdf_file (poche.file_preview_ps, Config.PathDestFilePostScript);
 }
-
+// 
+// 
 void pochegen_file_postscript_pdf (void)
 {
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 	
 	pochegen_file_postscript ();
 	pochegen_file_pdf ();
