@@ -30,29 +30,36 @@
  * 
  */
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gprintf.h>
-
+#include <glib/gstdio.h>
 #include <pthread.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "global.h"
-#include "info_song.h"
-#include "win_pulse.h"
-#include "win_info.h"
-#include "config_user.h"
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
 
+#include "global.h"
+#include "win_scan.h"
+#include "win_info.h"
+#include "get_info.h"
 #include "poche.h"
-#include "secu.h"
-#include "get.h"
+
 
 /*
 *---------------------------------------------------------------------------
@@ -94,14 +101,14 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 	gint	  Dummy;
 
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	/* Si le nom existe deja, en chercher un nouveau */
 	/*
 	if ( (ptr_name = strrchr (filename, '/')) == NULL) return (NULL);
 	ptr_name ++;
 	name_file = g_strdup_printf ("%s/%s", poche.Path_pochette, ptr_name);
-	if (infosong_file_is_reg (name_file) == TRUE) {
+	if (libutils_test_file_exist (name_file) == TRUE) {
 		g_print ("EXISTE DEJA: %s\n", name_file);
 		g_free(name_file);
 		name_file = NULL;
@@ -109,7 +116,7 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 		num = 1;
 		while (TRUE) {
 			name_file = g_strdup_printf ("%s/%03d.jpg", poche.Path_pochette, num);
-			if (infosong_file_is_reg (name_file) == FALSE) {
+			if (libutils_test_file_exist (name_file) == FALSE) {
 				g_print ("NOUVEAU NOM: %s\n", name_file);
 				break;
 			}
@@ -122,7 +129,7 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 	num = 1;
 	while (TRUE) {
 		name_file = g_strdup_printf ("%s/%03d.jpg", poche.Path_pochette, num);
-		if (infosong_file_is_reg (name_file) == FALSE) {
+		if (libutils_test_file_exist (name_file) == FALSE) {
 			/*g_print ("NOUVEAU NOM: %s\n", name_file);*/
 			break;
 		}
@@ -137,12 +144,12 @@ g_print("LINECOMMAND=\n%s\n", LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 
-	if (infosong_file_is_reg (name_file) == FALSE) {
+	if (libutils_test_file_exist (name_file) == FALSE) {
 		g_free(name_file);
 		name_file = NULL;
 	}
-	if (infosong_file_is (FILE_IS_IMG, name_file) != FILE_IS_IMG) {
-		infosong_delete_file (name_file);
+	if (GetInfo_file_is (name_file) != FILE_IS_IMG) {
+		g_unlink (name_file);
 		g_free (name_file);
 		name_file = NULL;
 	}
@@ -168,11 +175,11 @@ void pocheweb_analyze_file_html (void)
 	gint     TypeCode = 0;
 	size_t	 Dummy;
 	
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	nameindexhtml = g_strdup_printf ("%s/index.html", poche.Path_pochette);
 
-	lenfile = infosong_get_size_file (nameindexhtml);
+	lenfile = libutils_get_size_file (nameindexhtml);
 	if (lenfile <= 100) {
 		g_print ("ERREUR TAILLE DE %s = %d\n", nameindexhtml, (gint)lenfile);
 		g_free (nameindexhtml);
@@ -206,7 +213,7 @@ void pocheweb_analyze_file_html (void)
 		buffer = NULL;
 		g_free (result);
 		result = NULL;
-		infosong_delete_file (nameindexhtml);
+		g_unlink (nameindexhtml);
 		g_free (nameindexhtml);
 		nameindexhtml = NULL;
 		
@@ -248,7 +255,7 @@ void pocheweb_analyze_file_html (void)
 					pochedir_make_glist (ptr_name);
 				}
 
-				if (winpulse_event_set_close ()) {
+				if (WindScan_close_request ()) {
 					g_print ("DEMANDE D'ANNULATION DEPUIS: ");
 					PRINT_FUNC_LF();
 					break;
@@ -263,7 +270,7 @@ void pocheweb_analyze_file_html (void)
 	buffer = NULL;
 	g_free (result);
 	result = NULL;
-	infosong_delete_file (nameindexhtml);
+	g_unlink (nameindexhtml);
 	g_free (nameindexhtml);
 	nameindexhtml = NULL;
 }
@@ -281,7 +288,7 @@ gboolean pocheweb_recup_file_html (gchar *cd_name)
 	gchar     *LineCommand = NULL;
 	gint	  Dummy;
 
-	/*PRINT_FUNC_LF();*/
+	PRINT_FUNC_LF();
 
 	/* Construction du path	*/
 	Ptr = PtrNew = g_strdup_printf ("http://images.google.com/images?q=%s", cd_name);
@@ -316,7 +323,7 @@ g_print("LineCommand=%s\n", LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 
-	bool_ret = (infosong_file_is_reg (nameindexhtml) && infosong_get_size_file (nameindexhtml) > 0);
+	bool_ret = (libutils_test_file_exist (nameindexhtml) && libutils_get_size_file (nameindexhtml) > 0);
 
 	g_free (name);
 	name = NULL;
@@ -328,7 +335,7 @@ static void pocheweb_thread (void *arg)
 {
 	gchar *ptr_cdname = NULL;
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	ptr_cdname = pocheevnt_get_comboboxentry_cdaudio ();
 	
@@ -340,7 +347,6 @@ static void pocheweb_thread (void *arg)
 	pocheweb_event.EndTimeout = TRUE;
 	pocheweb_event.EndThread = TRUE;
 
-	secu_thread_sub ();
 	pthread_exit(0);
 }
 
@@ -352,27 +358,30 @@ gboolean pocheweb_bool_file_add (void)
 static gint pocheweb_timeout (gpointer data)
 {
 	if (pocheweb_event.name) {
-		winpulse_set_labelfile (pocheweb_event.name);
+		gchar	*Str = g_strdup_printf ("<b><i>%s</i></b>", pocheweb_event.name);
+		WindScan_set_label (Str);
 		g_free (pocheweb_event.name);
 		pocheweb_event.name = NULL;
+		g_free (Str);
+		Str = NULL;
 	}
 	else if (pocheweb_event.EndThread == TRUE) {
 		pocheevnt_table_add_images ();
 		pocheevnt_set_flag_buttons_recto ();
 		pocheevnt_set_flag_buttons_verso ();
 		gtk_timeout_remove (pocheweb_event.timeout);
-		winpulse_close ();
-		// PRINT("winpulse_close ();");
+		
+		WindScan_close ();
+
 		if (pocheweb_bool_file_add () == FALSE) {
 			wininfo_create (
 				_("Aucun fichier trouve !"),
-				_("    Pour resoudre ce probleme:"),
+				_("Pour resoudre ce probleme:"),
 				  "\n",
-				  "    -----------------------------------\n",
-				_("    Modifiez la chaine de recherche et"),
-				  "            \n",
-				_("    recommencez."),
-		 	  	  "     \n\n",
+				  "-----------------------------------\n",
+				_("Modifiez la chaine de recherche et"),
+				  "\n",
+				_("recommencez."),
 			  	  "");
 		}
 	}
@@ -381,23 +390,16 @@ static gint pocheweb_timeout (gpointer data)
 
 void  pocheweb_get (void)
 {
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	pocheweb_tt_glist = g_list_length (poche.glist);
-	
-	winpulse_create ();
-	// PRINT("winpulse_create ();");
-	winpulse_set_init_pulse ();
-	winpulse_set_title (_("Chargement des images"));
-	winpulse_set_labeltitle (_("Chargement des images"));
+	WindScan_open ("Recherche des fichiers images", WINDSCAN_PULSE);
+	WindScan_set_label ("<b><i>Recherche des fichiers images ...</i></b>");
 	pocheweb_event.name = g_strdup (_("[Recherche des fichiers images]"));
-	winpulse_set_labelfile (pocheweb_event.name);
-
 	pocheweb_event.name = NULL;
 	pocheweb_event.EndThread = FALSE;
 	pocheweb_event.EndTimeout = FALSE;
 	pocheweb_event.timeout = gtk_timeout_add (10, pocheweb_timeout, 0);
-	secu_thread_add ();
 	pthread_create (&pocheweb_event.nmr_tid, NULL ,(void *)pocheweb_thread, (void *)NULL);
 }
 
