@@ -31,25 +31,27 @@
  */
  
  
-#ifndef __popup_h__
-#define __popup_h__ 1
+#ifndef popup_h
+#define popup_h 1
 
+#include "file.h"
+#include "cd_audio.h"
 
-void popup_for_pocheevent (gboolean bool_recto);
+void	popup_normalise_dvd (void);
 
-void popup_cd (AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
-void popup_normalise_cd (void);
-void popup_normalise_dvd (void);
-void popup_file (DETAIL *detail, TYPE_FILE_IS TypeFileIs);
-/*void popup_file_Normalisation (DETAIL *detail, gboolean BoolAllIsNormalised, gboolean BoolIsSelected);*/
-void popup_file_ReplayGain (DETAIL *detail);
-void popup_make_popup_TST (void);
-void popup_trash (void);
-void popup_frequence (void);
-void popup_piste (void);
-void popup_quantification (void);
-void popup_for_player (void);
+void	popup_cd (AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
+void	popup_normalise_cd (void);
 
+void	popup_trash (void);
+void	popup_file (DETAIL *detail, TYPE_FILE_IS TypeFileIs);
+void	popup_file_ReplayGain (DETAIL *detail);
 
+void	popup_file_wav_frequence (DETAIL *detail);
+void	popup_file_wav_piste (DETAIL *detail);
+void	popup_file_wav_quantification (DETAIL *detail);
+
+void	popup_file_Split (void);
+
+void	popup_for_pocheevent (gboolean bool_recto);
 
 #endif
