@@ -30,22 +30,25 @@
  * 
  */
 
-
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
-
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "cd_audio.h"
-#include "file.h"
-#include "utils.h"
 #include "options.h"
-#include "poche.h"
-#include "win_info.h"
+#include "cd_audio.h"
 #include "prg_init.h"
 
 
@@ -83,6 +86,18 @@ PRGINIT PrgInit;
 
 TABLEAU_PRG_EXTERN TableauPrgExtern [ NMR_MAX_TABLEAU ] = {
 
+{"a52dec",							// PACKAGEDEBIAN_64
+"a52dec",							// PACKAGEDEBIAN_32
+"a52dec",							// NAME1
+"",								// NAME2
+"",								// NAME3
+&PrgInit.bool_a52dec,						// FOUND
+"",								// DEPOTDEBIAN_64
+"",								// DEPOTDEBIAN_32
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+NULL},								// DESCRIPTION
+
 {"aacplusenc",							// PACKAGEDEBIAN_64
 "aacplusenc",							// PACKAGEDEBIAN_32
 "aacplusenc",							// NAME1
@@ -218,7 +233,7 @@ NULL},								// DESCRIPTION
 // ADD
 {"monkeys-audio",						// PACKAGEDEBIAN_64
 "monkeys-audio",						// PACKAGEDEBIAN_32
-"mac",						// NAME1
+"mac",								// NAME1
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_ape,						// FOUND
@@ -488,24 +503,77 @@ NULL}								// DESCRIPTION
 
 
 // LES ELEMENTS DU TREEVIEW
-
+// 
+void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
+{
+	gchar *New_Str = NULL;
+	
+	var_options.Adr_label_type_paquege = widget;
+	
+	if (libutils_find_file ("apt-get") == TRUE || libutils_find_file ("aptitude") == TRUE) {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: deb</b> "));
+		}
+		var_options.Type_Package = _DEBIAN_;
+	}
+	else if (libutils_find_file ("slackpkg") == TRUE || libutils_find_file ("installpkg") == TRUE) {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: tgz</b> "));
+		}
+		var_options.Type_Package = _TGZ_;
+	}
+	else if (libutils_find_file ("pacman-g2") == TRUE) {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: fpm</b> "));
+		}
+		var_options.Type_Package = _FPM_;
+	}
+	else if (libutils_find_file ("rpm") == TRUE || libutils_find_file ("urpmi") == TRUE  || libutils_find_file ("zypper") == TRUE || libutils_find_file ("yum") == TRUE) {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: rpm</b> "));
+		}
+		var_options.Type_Package = _RPM_;
+	}
+	else {
+		if (widget != NULL) {
+			New_Str = g_strdup_printf (_(" <b>... les paquets: ?</b> "));
+		}
+		var_options.Type_Package = _PACKAGE_NOT_FOUND_;
+	}
+	
+	if (widget != NULL && New_Str != NULL) {
+		gtk_label_set_markup (GTK_LABEL (var_options.Adr_label_type_paquege), New_Str);
+		// gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_type_package_without_deb"))), New_Str);
+		g_free (New_Str);
+		New_Str = NULL;
+	}
+}
+// LES ELEMENTS DU TREEVIEW
+// 
 gchar *prginit_get_name (TYPE_PROGINIT TypeEnum)
 {
 	return ((gchar *)TableauPrgExtern [ TypeEnum ] . PtrName);
 }
+// 
+// 
 GdkPixbuf *prginit_get_pixbuf (TYPE_PROGINIT TypeEnum)
 {
 	return ((GdkPixbuf *)TableauPrgExtern [ TypeEnum ] . Pixbuf);
 }
+// 
+// 
 gchar *prginit_get_Description (TYPE_PROGINIT TypeEnum)
 {
 	return ((gchar *)TableauPrgExtern [ TypeEnum ] . Description);
 }
+// 
+// 
 gboolean prginit_elem_is_present (TYPE_PROGINIT TypeEnum)
 {
 	return ((gboolean)*TableauPrgExtern [ TypeEnum ] . BoolFound);
 }
-
+// 
+// 
 void prginit_affiche_glist (void)
 {
 	gchar		*Name;
@@ -514,8 +582,6 @@ void prginit_affiche_glist (void)
 	GtkTreeIter	 iter;
 	gint		 index;
 	
-	/* PRINT_FUNC_LF(); */
-	
 	// EFFACER LE CONTENU DU TREEVIEW
 	
 	gtk_list_store_clear (GTK_LIST_STORE (var_prgextern.Adr_List_Store));
@@ -546,8 +612,8 @@ void prginit_affiche_glist (void)
 		Name = NULL;
 	}
 }
-
-
+// 
+// 
 void prginit_print_info (void)
 {
 	gint	index;
@@ -561,7 +627,8 @@ void prginit_print_info (void)
 		g_print("!  %s   %s\n", (*TableauPrgExtern [ index ] . BoolFound == TRUE) ? "Yes      " : " NO  --> ", TableauPrgExtern [ index ] . PtrName);
 	g_print ("!------------------------------\n\n");
 }
-
+// 
+// 
 void prginit_scan (void)
 {
 	gint	index;
@@ -572,16 +639,15 @@ void prginit_scan (void)
 		
 		*TableauPrgExtern [ index ] . BoolFound = FALSE;
 		TableauPrgExtern [ index ] . PtrName    = NULL;
-		// TableauPrgExtern [ index ] . Pixbuf     = NULL;
 
 		// CHERCHE LE NOM APPROPRIE SUIVANT LA DISTRIBUTION UTILISEE
 		
-		*TableauPrgExtern [ index ] . BoolFound = utils_scan_by_which (TableauPrgExtern [ index ] . Name1, NULL);
+		*TableauPrgExtern [ index ] . BoolFound = libutils_find_file (TableauPrgExtern [ index ] . Name1);
 		TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name1;
 		
 		if (*TableauPrgExtern [ index ] . BoolFound == FALSE) {
 			if (*TableauPrgExtern [ index ] . Name2 != '\0') {
-				if ((*TableauPrgExtern [ index ] . BoolFound = utils_scan_by_which (TableauPrgExtern [ index ] . Name2, NULL)) == TRUE) {
+				if ((*TableauPrgExtern [ index ] . BoolFound = libutils_find_file (TableauPrgExtern [ index ] . Name2)) == TRUE) {
 					TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name2;
 				}
 			}
@@ -589,7 +655,7 @@ void prginit_scan (void)
 
 		if (*TableauPrgExtern [ index ] . BoolFound == FALSE) {
 			if (*TableauPrgExtern [ index ] . Name3 != '\0') {
-				if ((*TableauPrgExtern [ index ] . BoolFound = utils_scan_by_which (TableauPrgExtern [ index ] . Name3, NULL)) == TRUE) {
+				if ((*TableauPrgExtern [ index ] . BoolFound = libutils_find_file (TableauPrgExtern [ index ] . Name3)) == TRUE) {
 					TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name3;
 				}
 			}
@@ -614,12 +680,14 @@ void prginit_scan (void)
 	
 	prginit_affiche_glist ();
 }
-
+// 
+// 
 gboolean prginit_get_etat (void)
 {
 	prginit_scan ();
 	
 	var_prgextern.Bool_Goto_Page_Options =
+		PrgInit.bool_a52dec &
 		PrgInit.bool_cdparanoia &
 		PrgInit.bool_cdda2wav &
 		PrgInit.bool_flac &
@@ -651,47 +719,51 @@ gboolean prginit_get_etat (void)
 	return (var_prgextern.Bool_Goto_Page_Options);
 
 }
-
-
-/* Update du treeview
-*/
-void prginit_update_glist (void)
+// UPDATE DU TREEVIEW
+// 
+void on_button_scan_without_deb_clicked (GtkButton *button, gpointer user_data)
 {
-
 	if (var_prgextern.Adr_Tree_Model == NULL) return;
-
 	prginit_scan ();
-	
 	prginit_affiche_glist ();
-	cdaudio_affiche_glist_audio_cd ();
-	file_pixbuf_update_glist_file ();
-	file_set_flag_buttons_audio_file ();
-	cdaudio_set_flag_buttons_audio_cd ();
+	//
+	cdaudio_update_glist ();
+	cdaudio_affiche_glist_audio ();
+	cdaudio_set_flag_buttons ();
+	//
+	file_pixbuf_update_glist ();
+	file_affiche_glist ();
+	file_set_flag_buttons ();
 }
-
-
-/* Creation du scrolledwindow et des evenements associes
-*/
+// 
+// 
+gboolean prginit_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	return (TRUE);
+}
+// CREAATION DU SCROLLWINDOW ET DES EVENEMENTS ASSOCIES
+// 
 static void prginit_add_columns (GtkTreeView *treeview)
 {
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
-	// GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
+	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
 
-	/*PRINT_FUNC_LF();*/
-
-	/* SIGNAL 'changed'
-	*/
+	// SIGNAL 'key-press-event'
+	g_signal_connect(G_OBJECT(treeview),
+			"key-press-event",
+			(GCallback) prginit_key_press_event,
+			model);
+	
+	// SIGNAL 'changed'
 	var_prgextern.Adr_Line_Selected = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 	gtk_tree_selection_set_mode (var_prgextern.Adr_Line_Selected, GTK_SELECTION_BROWSE);
 
-	/* PRGEXT_NAME
-	*/
+	// PRGEXT_NAME
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.0, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
 						     renderer,
-						     /*"text", PRGEXT_NAME,*/
 						     "markup", PRGEXT_NAME,
 						     NULL);
 	// gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
@@ -700,8 +772,7 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
 	gtk_tree_view_append_column (treeview, column);
 
-	/* PRGEXT_STATUS
-	*/
+	// PRGEXT_STATUS
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	column = gtk_tree_view_column_new_with_attributes (
@@ -715,14 +786,12 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
 	gtk_tree_view_append_column (treeview, column);
 
-	/* PRGEXT_COMMENT
-	*/
+	// PRGEXT_COMMENT
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.0, NULL);
 	column = gtk_tree_view_column_new_with_attributes (
 							_("Action"),
 							renderer,
-							/*"text", PRGEXT_COMMENT,*/
 							"markup", PRGEXT_COMMENT,
 							NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
@@ -731,36 +800,8 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
 	gtk_tree_view_append_column (treeview, column);
 }
-
-GdkPixbuf *prginit_init_pixbufs_file (char *NameFilePixbuf)
-{
-	GdkPixbuf *NewPixbuf = NULL;
-	GError    *error = NULL;
-	gchar     *Pathname_Pixbuf = NULL;
-
-	/* PRINT_FUNC_LF(); */
-
-	Pathname_Pixbuf = utils_get_pathname (NameFilePixbuf);
-
-	/* load pixbuf
-	*/
-	NewPixbuf = gdk_pixbuf_new_from_file(Pathname_Pixbuf, &error);
- 	if (error) {
- 		GDK_PIXBUF_ERROR;
-		g_critical ("Could not load pixbuf: %s\n", error->message);
-		g_error_free (error);
-		g_free (Pathname_Pixbuf);
-		Pathname_Pixbuf = NULL;
-		return (NULL);
-	}
-
-	g_free (Pathname_Pixbuf);
-	Pathname_Pixbuf = NULL;
-
-	return (NewPixbuf);
-}
-
-
+// 
+// 
 void prginit_remove_comment (void)
 {
 	gint	index;
@@ -770,10 +811,11 @@ void prginit_remove_comment (void)
 		TableauPrgExtern[ index ].Description = NULL;
 	}
 }
-
-
+// 
+// 
 void prginit_init_comment (void)
 {
+	TableauPrgExtern[ NMR_a52dec ].Description 			= g_strdup (_(" [ liba52-0.7.4-dev ] decode ATSC A/52 audio streams"));
 	TableauPrgExtern[ NMR_aacplusenc ].Description 			= g_strdup (_(" [ aacplusenc ] AAC+ encoder"));
 	TableauPrgExtern[ NMR_cdparanoia ].Description 			= g_strdup (_(" [ cdparanoia ] Extracteur cd audio"));
 	TableauPrgExtern[ NMR_checkmp3 ].Description 			= g_strdup (_(" [ checkmp3 ] Cherche des renseignements sur les formats mp3"));
@@ -785,14 +827,9 @@ void prginit_init_comment (void)
 	TableauPrgExtern[ NMR_icedax ].Description 			= g_strdup (_(" [ icedax ] Extracteur cd audio"));
 	TableauPrgExtern[ NMR_lame ].Description 			= g_strdup (_(" [ lame ] Conversion wav : mp3"));
 	TableauPrgExtern[ NMR_lsdvd ].Description 			= g_strdup (_(" [ lsdvd ] Cherche les informations d'un dvd"));
-	
 	TableauPrgExtern[ NMR_mac ].Description 			= g_strdup (_(" [ monkeys-audio ] Monkey's Audio Console Front End : APE"));
-	
-	// TableauPrgExtern[ NMR_mpc123_mppdec ].Description 		= g_strdup (_(" MPC Decodeur"));
-	// TableauPrgExtern[ NMR_mppenc ].Description 			= g_strdup (_(" MPC Encodeur"));
 	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppdec"));
 	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppenc"));
-	
 	TableauPrgExtern[ NMR_mplayer ].Description 			= g_strdup (_(" [ mplayer ] Lecteur et extracteur"));
 	TableauPrgExtern[ NMR_mp3gain ].Description 			= g_strdup (_(" [ mp3gain ] Normaliseur de fichier mp3"));
 	TableauPrgExtern[ NMR_mpg321 ].Description 			= g_strdup (_(" [ mpg321 ] Conversion mp3 : wav"));
@@ -810,43 +847,34 @@ void prginit_init_comment (void)
 	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" [ wavpack ] WAVPACK  Hybrid Lossless Audio Compressor"));
 	TableauPrgExtern[ NMR_wXXcodecs	].Description 			= g_strdup (_(" [ wXXcodecs ] Codecs video non supportes par mplayer / <b><i>PAS indispensable</i></b>"));
 }
-
-/* Initialisation du scrolledwindow
-*/
-void prginit_make_scrolledwindow (GtkWidget *widget)
+// INITIALISATION DU SCROLLWINDOW
+// 
+void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointer user_data)
 {
 	GtkTreeModel *model;
 	GtkWidget    *treeview;
 	GtkListStore *store;
 
-	/* PRINT_FUNC_LF(); */
-
-	var_prgextern.Pixbuf_Ok        = prginit_init_pixbufs_file ("prg-ok.png");
-	var_prgextern.Pixbuf_Not_Ok    = prginit_init_pixbufs_file ("dbfs-no.png");
+	var_prgextern.Pixbuf_Ok        = libutils_init_pixbufs ("xcfa/prg-ok.png");
+	var_prgextern.Pixbuf_Not_Ok    = libutils_init_pixbufs ("xcfa/dbfs-no.png");
 
 	var_prgextern.Adr_scroll = widget;
 	var_prgextern.Adr_List_Store =
-	store = gtk_list_store_new (PRGEXT_TOTAL_COLUMN,	/* Nombre total de colonnes */
-				    G_TYPE_STRING,		/* Name */
-				    GDK_TYPE_PIXBUF,		/* Status */
-				    G_TYPE_STRING,		/* Commentaire */
+	store = gtk_list_store_new (PRGEXT_TOTAL_COLUMN,	// Nombre total de colonnes
+				    G_TYPE_STRING,		// Name
+				    GDK_TYPE_PIXBUF,		// Status
+				    G_TYPE_STRING,		// Commentaire
 				    G_TYPE_INT
 				    );
 	var_prgextern.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
-
 	treeview = gtk_tree_view_new_with_model (model);
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
-
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
-
-	/* add columns to the tree view */
 	prginit_add_columns (GTK_TREE_VIEW (treeview));
-
 	prginit_init_comment ();
 	prginit_scan ();
 	prginit_print_info ();
-
 	gtk_widget_show_all (widget);
 }
 
