@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __prg_init_h__
-#define __prg_init_h__ 1
+#ifndef prg_init_h
+#define prg_init_h 1
 
 typedef struct {
 	GtkListStore      *Adr_List_Store;
@@ -52,7 +52,8 @@ extern VAR_PRGEXTERN var_prgextern;
 
 
 typedef enum {
-	NMR_aacplusenc = 0,
+	NMR_a52dec = 0,
+	NMR_aacplusenc,
 	NMR_cdparanoia,
 	NMR_checkmp3,
 	NMR_imagemagick_convert,
@@ -112,6 +113,7 @@ extern TABLEAU_PRG_EXTERN TableauPrgExtern [  ];
 
 
 typedef struct {
+	gboolean	bool_a52dec;
 	gboolean	bool_notify_send;
 	gboolean	bool_ape;
 	gboolean	bool_mpc123_mppdec;
@@ -150,7 +152,7 @@ extern PRGINIT PrgInit;
 
 
 void       prginit_remove_comment (void);
-void       prginit_make_scrolledwindow (GtkWidget *widget);
+// void       prginit_make_scrolledwindow (GtkWidget *widget);
 gboolean   prginit_get_etat (void);
 void       prginit_update_glist (void);
 gchar     *prginit_get_name (TYPE_PROGINIT TypeEnum);
