@@ -31,14 +31,27 @@
  */
 
 
-#include <gtk/gtk.h>
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+#include <gtk/gtk.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "proc.h"
 
 
+
 /*
 *---------------------------------------------------------------------------
 * VARIABLES
@@ -110,7 +123,7 @@ GList *proc_get_proc_init_cdrominfo (void)
 
 	PRINT_FUNC_LF();
 
-	if (!g_file_get_contents("/proc/sys/dev/cdrom/info", &Lcontent, NULL, &Aerror)) {
+	if (FALSE == g_file_get_contents("/proc/sys/dev/cdrom/info", &Lcontent, NULL, &Aerror)) {
 		g_print ("\t---------------------------------------------------\n");
 		g_print ("\tLE FICHIER: </proc/sys/dev/cdrom/info> N'EXISTE PAS\n");
 		g_print ("\t---------------------------------------------------\n");
@@ -124,7 +137,7 @@ GList *proc_get_proc_init_cdrominfo (void)
 	Larrbuf[2] = g_strdup ("drive name:               hdd	hdc scd4	 sr0");
 	*/
 	for (i=0; Larrbuf[i]; i++) {
-		if (!strncmp(Larrbuf[i], DRIVE_NAME, strlen(DRIVE_NAME))) {
+		if (0 == strncmp(Larrbuf[i], DRIVE_NAME, strlen(DRIVE_NAME))) {
 
 			s_proc = g_strdup (Larrbuf[i]);
 			/*g_print ("Larrbuf[%02d] = %s\n", i, s_proc);*/
