@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __proc_h__
-#define ___proc_h__ 1
+#ifndef proc_h
+#define proc_h 1
 
 GList *proc_get_proc_init_cdrominfo (void);
 GList *proc_remove_glist_cdrominfo (GList *list);
