@@ -31,26 +31,13 @@
  */
 
 
-#ifndef __process_h__
-#define ___process_h__ 1
-
+#ifndef process_h
+#define _process_h 1
 
 #define XCFA_FILE_LOAD		"/tmp/xcfa_file_load.txt"
-#define XCFA_PROCESS		"/tmp/xcfa_process.txt"
-#define XCFA_PID		"/tmp/xcfa_pid.txt"
-
-
-typedef struct {
-	guint          handler_timeout;
-	gboolean       bool_read_access;
-	gboolean       bool_action_is_ready;
-} VAR_PROCESS;
-
-extern VAR_PROCESS var_process;
-
 
 void		process_goto_timeout (void);
-gboolean	process_bool_action_is_ready (void);
+gboolean	process_exist_file (void);
 
 #endif
 
