@@ -32,12 +32,16 @@
 
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
 #endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -46,13 +50,15 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
-#include "utils.h"
 #include "options.h"
-#include "win_control.h"
-#include "win_norm_replay.h"
-#include "logs.h"
+#include "win_scan.h"
+#include "notify_send.h"
 #include "replaygain.h"
 
 
@@ -72,7 +78,7 @@ ACTION SUR LA SOURCES		FileAction.bool_ReplaygainClear    = file_get_bool_Replay
 ACTION SUR LA SOURCES		FileAction.bool_normalize          = file_get_bool_normalize_file ();
 ACTION SUR LA SOURCES		FileAction.bool_NormalizeCollectif = file_get_bool_NormalizeCollectif_file ();
 CREATION DESTINATION		FileAction.bool_conversion         = file_get_bool_conversion_file ();
-ACTION SUR LA DESTINATION	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply_file ();
+ACTION SUR LA DESTINATION	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply ();
 */
 
 
@@ -145,65 +151,63 @@ void replaygain_set_list (RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 	GList            *ListProg = NULL;
 	GList            *ListEtat = NULL;
 	DETAIL           *detail = NULL;
-	FIC              *fic = NULL;
 	gchar            *Ptr = NULL;
 	ETAT_REPLAYGAIN  *PtrReplayGain = NULL;
 	gboolean          BoolList = FALSE;
+	gint		  pos;
 	
-	if (rpg.bool_thread_end == TRUE) return;
+	if (TRUE == rpg.bool_thread_end) return;
 	
-GDK_THREADS_ENTER();
 	rpg.MessUser = g_string_new (NULL);
+	
 	/* Entete global */
-	list = g_list_append (list, g_strdup ("nice"));
-	list = g_list_append (list, g_strdup ("-n"));
-	list = g_list_append (list, g_strdup (conv.valuenice));
+	pos = filelc_get_command_line_nice ();
 	
 	/* Entetes particuliers */
 	switch (rpg_type) {
 	case MP3GAIN :
-		list = g_list_append (list, g_strdup ("mp3gain"));
+		conv.ArgConv [ pos++ ] = g_strdup ("mp3gain");
 		g_string_append_printf (rpg.MessUser, "<i><b>MP3, mp3gain</b>");
 		switch (rpg_action) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			list = g_list_append (list, g_strdup ("-s"));
-			list = g_list_append (list, g_strdup ("d"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-s");
+			conv.ArgConv [ pos++ ] = g_strdup ("d");
 			g_string_append_printf (rpg.MessUser, ", <b>EFFACER</b></i>");
 			break;
 		case RPG_ALBUM :
-			list = g_list_append (list, g_strdup ("-a"));
-			list = g_list_append (list, g_strdup ("-p"));
-			list = g_list_append (list, g_strdup ("-c"));
-			list = g_list_append (list, g_strdup ("-f"));
-			list = g_list_append (list, g_strdup ("-T"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-a");
+			conv.ArgConv [ pos++ ] = g_strdup ("-p");
+			conv.ArgConv [ pos++ ] = g_strdup ("-c");
+			conv.ArgConv [ pos++ ] = g_strdup ("-f");
+			conv.ArgConv [ pos++ ] = g_strdup ("-T");
 			g_string_append_printf (rpg.MessUser, ", <b>ALBUM</b></i>");
 			break;
 		case RPG_PISTE :
-			list = g_list_append (list, g_strdup ("-r"));
-			list = g_list_append (list, g_strdup ("-p"));
-			list = g_list_append (list, g_strdup ("-c"));
-			list = g_list_append (list, g_strdup ("-f"));
-			list = g_list_append (list, g_strdup ("-T"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-r");
+			conv.ArgConv [ pos++ ] = g_strdup ("-p");
+			conv.ArgConv [ pos++ ] = g_strdup ("-c");
+			conv.ArgConv [ pos++ ] = g_strdup ("-f");
+			conv.ArgConv [ pos++ ] = g_strdup ("-T");
 			g_string_append_printf (rpg.MessUser, ", <b>PISTE</b></i>");
 			break;
 		}
 		break;
 	case METAFLAC :
-		list = g_list_append (list, g_strdup ("metaflac"));
+		conv.ArgConv [ pos++ ] = g_strdup ("metaflac");
 		g_string_append_printf (rpg.MessUser, "<i><b>FLAC, metaflac</b>");
 		switch (rpg_action) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			list = g_list_append (list, g_strdup ("--remove-replay-gain"));
+			conv.ArgConv [ pos++ ] = g_strdup ("--remove-replay-gain");
 			g_string_append_printf (rpg.MessUser, ", <b>EFFACER</b></i>");
 			break;
 		case RPG_ALBUM :
-			list = g_list_append (list, g_strdup ("--add-replay-gain"));
+			conv.ArgConv [ pos++ ] = g_strdup ("--add-replay-gain");
 			g_string_append_printf (rpg.MessUser, ", <b>ALBUM</b></i>");
 			break;
 		case RPG_PISTE :
@@ -212,18 +216,18 @@ GDK_THREADS_ENTER();
 		}
 		break;
 	case WVGAIN :
-		list = g_list_append (list, g_strdup ("wvgain"));
+		conv.ArgConv [ pos++ ] = g_strdup ("wvgain");
 		g_string_append_printf (rpg.MessUser, "<i><b>WAVPACK, wvgain</b>");
 		switch (rpg_action) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			list = g_list_append (list, g_strdup ("-c"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-c");
 			g_string_append_printf (rpg.MessUser, ", <b>EFFACER</b></i>");
 			break;
 		case RPG_ALBUM :
-			list = g_list_append (list, g_strdup ("-a"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-a");
 			g_string_append_printf (rpg.MessUser, ", <b>ALBUM</b></i>");
 			break;
 		case RPG_PISTE :
@@ -232,18 +236,18 @@ GDK_THREADS_ENTER();
 		}
 		break;
 	case VORBISGAIN :
-		list = g_list_append (list, g_strdup ("vorbisgain"));
+		conv.ArgConv [ pos++ ] = g_strdup ("vorbisgain");
 		g_string_append_printf (rpg.MessUser, "<i><b>OGG, vorbisgain</b>");
 		switch (rpg_action) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			list = g_list_append (list, g_strdup ("-c"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-c");
 			g_string_append_printf (rpg.MessUser, ", <b>EFFACER</b></i>");
 			break;
 		case RPG_ALBUM :
-			list = g_list_append (list, g_strdup ("-a"));
+			conv.ArgConv [ pos++ ] = g_strdup ("-a");
 			g_string_append_printf (rpg.MessUser, ", <b>ALBUM</b></i>");
 			break;
 		case RPG_PISTE :
@@ -258,49 +262,41 @@ GDK_THREADS_ENTER();
 	while (ListProg) {
 		if ((detail = (DETAIL *)ListProg->data)) {
 			
-			/* Test d'entree */
-			if (!detail->type_infosong_file_is == FILE_IS_OGG ||
-			    !detail->type_infosong_file_is == FILE_IS_MP3 ||
-			    !detail->type_infosong_file_is == FILE_IS_FLAC ||
-			    !detail->type_infosong_file_is == FILE_IS_WAVPACK) {
+			// TEST D ENTREE
+			if (detail->type_infosong_file_is != FILE_IS_OGG ||
+			    detail->type_infosong_file_is != FILE_IS_MP3 ||
+			    detail->type_infosong_file_is != FILE_IS_FLAC ||
+			    detail->type_infosong_file_is != FILE_IS_WAVPACK) {
 			    
 				ListProg = g_list_next (ListProg);
 				continue;
 			}
 			
-			if ((fic = (FIC *)detail->fic) && fic->Etat_ReplayGain == rpg_action) {
+			if (NULL != detail && detail->Etat_ReplayGain == rpg_action) {
 				/* VORBISGAIN */
 				if (detail->type_infosong_file_is == FILE_IS_OGG && rpg_type == VORBISGAIN) {
 					
-					/* fic->Etat_Normalise = NORM_SCAN_ACTIF; */
 					BoolList = TRUE;
 					
-					/*
-					if (type_replaygain == _CLEAR_REPLAYGAIN_)
-						ACTION SUR LA SOURCE
-					else if (type_replaygain ==  _APPLY_REPLAYGAIN_)
-						ACTION SUR LA DESTINATION
-					*/
-					list = g_list_append (list, g_strdup (detail->namefile));
+					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile);
 					
 					/* Get pointer Etat Flag */
-					ListEtat = g_list_append (ListEtat, &fic->Etat_ReplayGain);
+					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain);
 					
-					if (fic->EtatTrash == FILE_TRASH_OK) fic->EtatTrash = FILE_TRASH_VERIF_OK;
+					if (detail->EtatTrash == FILE_TRASH_OK) detail->EtatTrash = FILE_TRASH_VERIF_OK;
 					
 					rpg.ElementActif ++;
 				}
 				/* MP3GAIN */
 				else if (detail->type_infosong_file_is == FILE_IS_MP3 && rpg_type == MP3GAIN) {
 				
-					/* fic->Etat_Normalise = NORM_SCAN_ACTIF; */
 					BoolList = TRUE;
-					list = g_list_append (list, g_strdup (detail->namefile));
+					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile);
 					
 					/* Get pointer Etat Flag */
-					ListEtat = g_list_append (ListEtat, &fic->Etat_ReplayGain);
+					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain);
 					
-					if (fic->EtatTrash == FILE_TRASH_OK) fic->EtatTrash = FILE_TRASH_VERIF_OK;
+					if (detail->EtatTrash == FILE_TRASH_OK) detail->EtatTrash = FILE_TRASH_VERIF_OK;
 					
 					rpg.ElementActif ++;
 				}
@@ -308,24 +304,24 @@ GDK_THREADS_ENTER();
 				else if (detail->type_infosong_file_is == FILE_IS_FLAC && rpg_type == METAFLAC) {
 					/* PISTE -> NONE */
 					BoolList = TRUE;
-					list = g_list_append (list, g_strdup (detail->namefile));
+					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile);
 					
 					/* Get pointer Etat Flag */
-					ListEtat = g_list_append (ListEtat, &fic->Etat_ReplayGain);
+					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain);
 					
-					if (fic->EtatTrash == FILE_TRASH_OK) fic->EtatTrash = FILE_TRASH_VERIF_OK;
+					if (detail->EtatTrash == FILE_TRASH_OK) detail->EtatTrash = FILE_TRASH_VERIF_OK;
 					
 					rpg.ElementActif ++;
 				}
 				/* WVGAIN */
 				else if (detail->type_infosong_file_is == FILE_IS_WAVPACK && rpg_type == WVGAIN) {
 					BoolList = TRUE;
-					list = g_list_append (list, g_strdup (detail->namefile));
+					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile);
 					
 					/* Get pointer Etat Flag */
-					ListEtat = g_list_append (ListEtat, &fic->Etat_ReplayGain);
+					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain);
 					
-					if (fic->EtatTrash == FILE_TRASH_OK) fic->EtatTrash = FILE_TRASH_VERIF_OK;
+					if (detail->EtatTrash == FILE_TRASH_OK) detail->EtatTrash = FILE_TRASH_VERIF_OK;
 					
 					rpg.ElementActif ++;
 				}
@@ -333,26 +329,24 @@ GDK_THREADS_ENTER();
 		}
 		ListProg = g_list_next (ListProg);
 	}
-GDK_THREADS_LEAVE();
 	
 	/* Test application de ReplayGain */
-	if (BoolList == TRUE) {
+	if (TRUE == BoolList) {
 
 		/* Appel au ReplayGain */
 		rpg.bool_compteur = TRUE;
 		rpg.bool_etat = TRUE;
+		conv.ArgConv [ pos++ ] = NULL;
 		
-		conv.ArgConv = conv_alloc_arg (list);
-		conv_exec (FALSE, REPLAYGAIN, list, rpg.MessUser->str);
-		g_free (conv.ArgConv);
-		conv.ArgConv = NULL;
+		conv_to_convert (FALSE, REPLAYGAIN, rpg.MessUser->str);
+		filelc_get_command_line_remove ();
 		
 		rpg.bool_compteur = FALSE;
 
 		/* Set update */
 		ListProg = g_list_first (ListEtat);
 		while (ListProg) {
-			if ((PtrReplayGain = (ETAT_REPLAYGAIN *)ListProg->data)) {
+			if (NULL != (PtrReplayGain = (ETAT_REPLAYGAIN *)ListProg->data)) {
 				*PtrReplayGain = RPG_ATTENTE;
 			}
 			ListProg->data = NULL;
@@ -366,7 +360,7 @@ GDK_THREADS_LEAVE();
 	/* suppression des elements de la liste */
 	ListProg = g_list_first (list);
 	while (ListProg) {
-		if ((Ptr = (gchar *)ListProg->data)) {
+		if (NULL != (Ptr = (gchar *)ListProg->data)) {
 			g_free (Ptr);
 			Ptr = NULL;
 		}
@@ -384,61 +378,65 @@ GDK_THREADS_LEAVE();
 */
 static gint replaygain_timeout (gpointer data)
 {
-	if (WinNormReplay_is_get_close () == TRUE) {
-		conv_stop_conversion ();
-	}
+	// if (WinNormReplay_is_get_close () == TRUE) {
+	// 	conv_stop_conversion ();
+	// }
 	
-	if (conv.bool_percent_conv == TRUE) {
+	if (TRUE == conv.bool_percent_conv) {
 		rpg.total_percent = (double)rpg.ElementActif / (double)rpg.NbrElementsInList;
-		WinNormReplay_set_data_progressBar (rpg.total_percent);
+	// 	WinNormReplay_set_data_progressBar (rpg.total_percent);
 	}
 
-	if (rpg.bool_update == TRUE) {
+	if (TRUE == rpg.bool_update) {
 		rpg.bool_update = FALSE;
-		file_pixbuf_update_glist_file ();
-		file_set_flag_buttons_audio_file ();
+		file_pixbuf_update_glist ();
+		file_set_flag_buttons ();
 		return (TRUE);
 	}
 	
-	if (rpg.bool_etat == TRUE) {
+	if (TRUE == rpg.bool_etat) {
 		
-		/*WinNormReplay_set_etat (rpg.MessUser->str);*/
+	// 	WinNormReplay_set_etat (rpg.MessUser->str);
 		g_string_free (rpg.MessUser, TRUE);
 		rpg.MessUser = NULL;
 		
 		rpg.bool_etat = FALSE;
 	}
 	
-	if (rpg.bool_compteur == TRUE) {
+	if (TRUE == rpg.bool_compteur) {
 		
 		gchar *str = NULL;
     		gchar *spinner="|/-\\";
-		// gchar *Ptr = NULL;
 		gchar  foo [ 2 ];
 		
 		foo [ 0 ] = spinner[rpg.pass_conv++%4];
 		foo [ 1 ] = '\0';
-		// Ptr = utils_convert_string (foo, TRUE);
 		
 		str = g_strdup_printf (_("<b>En cours: %d sur %d   %s</b>"),
 					rpg.ElementActif,
 					rpg.NbrElementsInList,
 					foo
 					);
-		WinNormReplay_set_compteur (str);
+		// WinNormReplay_set_compteur (str);
 		g_free (str);
 		str = NULL;
-		// g_free (Ptr);
-		// Ptr = NULL;
 		
 		return (TRUE);
 	}
 	
-	if (rpg.bool_thread_end == TRUE) {
-		WinNormReplay_close ();
-		fileaction_set_end ();
+	if (TRUE == rpg.bool_thread_end) {
+		// WinNormReplay_close ();
+		if (FALSE == conv.bool_stop) {
+			NotifySend_msg (_("XCFA: ReplayGain fichiers"), _("Ok"));
+		} else {
+			NotifySend_msg (_("XCFA: ReplayGain fichiers"), _("Arret par l'utilisateur"));
+		}
+		if (rpg.type_replaygain == _CLEAR_REPLAYGAIN_) {
+			fileaction_set_end (TYPE_REPLAYGAINCLEAR);
+		} else if (rpg.type_replaygain ==  _APPLY_REPLAYGAIN_) {
+			fileaction_set_end (TYPE_REPLAYGAINAPPLY);
+		}
 		gtk_timeout_remove (rpg.handler_timeout);
-		conv_set_struct_not_used ();
 	}
 	
 	return (TRUE);
@@ -479,21 +477,19 @@ void replaygain_get_list_Clear (void)
 {
 	GList   *list = NULL;
 	DETAIL  *detail = NULL;
-	FIC     *fic = NULL;
 
 	/*PRINT_FUNC_LF();*/
 
 	list = g_list_first (entetefile);
 	while (list) {
-		if ((detail = (DETAIL *)list->data)) {
+		if (NULL != (detail = (DETAIL *)list->data)) {
 			if (detail->type_infosong_file_is == FILE_IS_OGG ||
 				detail->type_infosong_file_is == FILE_IS_MP3 ||
 				detail->type_infosong_file_is == FILE_IS_FLAC ||
 				detail->type_infosong_file_is == FILE_IS_WAVPACK) {
-				if ((fic = (FIC *)detail->fic)) {
-					if (fic->Etat_ReplayGain == RPG_EFFACER) {
-						rpg.NbrElementsInList ++;
-					}
+				
+				if (detail->Etat_ReplayGain == RPG_EFFACER) {
+					rpg.NbrElementsInList ++;
 				}
 			}
 		}
@@ -505,21 +501,18 @@ void replaygain_get_list_Apply (void)
 {
 	GList   *list = NULL;
 	DETAIL  *detail = NULL;
-	FIC     *fic = NULL;
 
 	/*PRINT_FUNC_LF();*/
 
 	list = g_list_first (entetefile);
 	while (list) {
-		if ((detail = (DETAIL *)list->data)) {
+		if (NULL != (detail = (DETAIL *)list->data)) {
 			if (detail->type_infosong_file_is == FILE_IS_OGG ||
 				detail->type_infosong_file_is == FILE_IS_MP3 ||
 				detail->type_infosong_file_is == FILE_IS_FLAC ||
 				detail->type_infosong_file_is == FILE_IS_WAVPACK) {
-				if ((fic = (FIC *)detail->fic)) {
-					if (fic->Etat_ReplayGain != RPG_EFFACER && fic->Etat_ReplayGain != RPG_ATTENTE) {
-						rpg.NbrElementsInList ++;
-					}
+				if (detail->Etat_ReplayGain != RPG_EFFACER && detail->Etat_ReplayGain != RPG_ATTENTE) {
+					rpg.NbrElementsInList ++;
 				}
 			}
 		}
@@ -534,10 +527,6 @@ void replaygain_get_list_Apply (void)
 */
 void replaygain_action (TYPE_REPLAYGAIN type_replaygain)
 {
-	logs_add_datas_session ("FROM FILE->REPLAYGAIN");
-	
-	g_snprintf (conv.valuenice ,    4, "%d", options_get_val_nice ());
-	
 	rpg.bool_thread_end = FALSE;
 	rpg.bool_etat = FALSE;
 	rpg.NbrElementsInList = 0;
@@ -550,10 +539,10 @@ void replaygain_action (TYPE_REPLAYGAIN type_replaygain)
 	if (type_replaygain == _CLEAR_REPLAYGAIN_)	 replaygain_get_list_Clear ();
 	else if (type_replaygain ==  _APPLY_REPLAYGAIN_) replaygain_get_list_Apply ();
 
-	conv_reset_struct ();
+	conv_reset_struct (WindScan_close_request);
 	
-	WinNormReplay_Create ("ReplayGain");
-	WinNormReplay_reset_progressBar ();
+	// WinNormReplay_Create ("ReplayGain");
+	// WinNormReplay_reset_progressBar ();
 	rpg.handler_timeout = gtk_timeout_add (100, replaygain_timeout, 0);
 	pthread_create (&rpg.nmr_tid, NULL ,(void *)replaygain_thread, (void *)NULL);
 }
