@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __replaygain_h__
-#define __replaygain_h__ 1
+#ifndef replaygain_h
+#define replaygain_h 1
 
 typedef enum {_CLEAR_REPLAYGAIN_ = 0, _APPLY_REPLAYGAIN_} TYPE_REPLAYGAIN;
 
