@@ -1,5 +1,5 @@
  /*
- * file    : tags_aac.c
+ * file      : tags_aac.c
  * project   : xcfa
  * with      : Gtk-2
  *
@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,8 +50,11 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "get.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
@@ -59,9 +69,8 @@
 INFO_AAC *tagsaac_remove_info (INFO_AAC *info)
 {
 	if (info) {
-		g_free (info->namefile);
-		g_free (info->time);
-		g_free (info->hertz);
+		if (NULL != info->time)		{ g_free (info->time);	info->time = NULL;	}
+		if (NULL != info->hertz)	{ g_free (info->hertz);	info->hertz = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
