@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,75 +50,17 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
 
 
 
-/*
-*---------------------------------------------------------------------------
-* FILE IS AIFF ?
-*---------------------------------------------------------------------------
-*/
-/*
-POS	ASCII	HEXA
-00	F		46
-01	O		4f
-02	R		52
-03	M		4d
-04	
-05	
-06	
-07	
-08	A		41
-09	I		49
-10	F		46
-11	F		46
-12	C		43
-13	O		4f
-14	M		4d
-15	M		4d
-*/
-gboolean tagsaiff_file_is_aiff (gchar *namefile)
-{
-	FILE        *fp = NULL;
-	size_t       lenread = 0;
-	gchar       *buf = NULL;
-	gboolean     bool_signature = FALSE;
-	
-	/*PRINT_FUNC_LF();*/
-
-	buf = (gchar *)g_malloc0 (sizeof(gchar) * 512);
-	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 500, fp);
-		fclose (fp);
-	
-		if (buf [  0 ] == 0x46 &&	// F
-		    buf [  1 ] == 0x4f &&	// O
-		    buf [  2 ] == 0x52 &&	// R
-		    buf [  3 ] == 0x4d &&	// M
-		    
-		    buf [  8 ] == 0x41 &&	// A
-		    buf [  9 ] == 0x49 &&	// I
-		    buf [ 10 ] == 0x46 &&	// F
-		    buf [ 11 ] == 0x46 &&	// F
-		    buf [ 12 ] == 0x43 &&	// C
-		    buf [ 13 ] == 0x4f &&	// O
-		    buf [ 14 ] == 0x4d &&	// M
-		    buf [ 15 ] == 0x4d)	{	// M
-		    
-			bool_signature = TRUE;
-		}
-	}
-
-	g_free (buf);
-	buf = NULL;
-	
-	return (bool_signature);
-}
 
 /*
 *---------------------------------------------------------------------------
@@ -121,8 +70,6 @@ gboolean tagsaiff_file_is_aiff (gchar *namefile)
 INFO_AIFF *tagsaiff_remove_info (INFO_AIFF *info)
 {
 	if (info) {
-		g_free (info->namefile);
-
 		info->tags = (TAGS *)tags_remove (info->tags);
 
 		g_free (info);
@@ -136,17 +83,15 @@ INFO_AIFF *tagsaiff_remove_info (INFO_AIFF *info)
 * GET HEADER
 *---------------------------------------------------------------------------
 */
-INFO_AIFF *tagsaiff_get_info (gchar *namefile)
+INFO_AIFF *tagsaiff_get_info (DETAIL *detail)
 {
 	INFO_AIFF     *ptrinfo = NULL;
 
 	ptrinfo = (INFO_AIFF *)g_malloc0 (sizeof (INFO_AIFF));
 	if (ptrinfo == NULL) return (NULL);
 
-	ptrinfo->namefile = g_strdup (namefile);
-
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-	tags_set (namefile, ptrinfo->tags);
+	tags_set (detail->namefile, ptrinfo->tags);
 
 	return ((INFO_AIFF *)ptrinfo);
 }
