@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,11 +50,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
+#include "get_info.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
 
 
 /*
@@ -83,42 +94,6 @@ struct APE_HEADER_OLD
 };
 *****************************************************************************************/
 
-/*
-*---------------------------------------------------------------------------
-* FILE IS APE ?
-*---------------------------------------------------------------------------
-*/
-
-gboolean tagsape_file_is_ape (gchar *namefile)
-{
-	FILE        *fp = NULL;
-	size_t       lenread = 0;
-	gchar       *buf = NULL;
-	gint         cpt;
-	gboolean     bool_signature = FALSE;
-	
-	/*PRINT_FUNC_LF();*/
-
-	buf = (gchar *)g_malloc0 (sizeof(gchar) * 2048);
-	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 2000, fp);
-		fclose (fp);
-	
-		for (cpt = 0; cpt < 2000; cpt ++) {
-			if (buf [ cpt + 0 ] == 0x4d &&	/* 'M' */
-			    buf [ cpt + 1 ] == 0x41 &&	/* 'A' */
-			    buf [ cpt + 2 ] == 0x43 &&	/* 'C' */
-			    buf [ cpt + 3 ] == 0x20) {	/* ' ' */
-			    bool_signature = TRUE;
-			    break;
-			}
-		}
-	}
-	g_free (buf);
-	buf = NULL;
-	
-	return (bool_signature);
-}
 
 
 /*
@@ -130,9 +105,8 @@ gboolean tagsape_file_is_ape (gchar *namefile)
 INFO_APE *tagsape_remove_info (INFO_APE *info)
 {
 	if (info) {
-		g_free (info->namefile);
-		g_free (info->time);
-		g_free (info->size);
+		if (NULL != info->time)		{ g_free (info->time); info->time = NULL;	}
+		if (NULL != info->size)		{ g_free (info->size);info->size = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -142,16 +116,14 @@ INFO_APE *tagsape_remove_info (INFO_APE *info)
 	return ((INFO_APE *)NULL);
 }
 
-INFO_APE *tagsape_get_info (gchar *namefile)
+INFO_APE *tagsape_get_info (DETAIL *detail)
 {
 	INFO_APE	*ptrinfo = NULL;
-	SHNTAG		*ShnTag = get_with_shntool (namefile);
+	SHNTAG		*ShnTag = GetInfo_shntool (detail->namefile);
 
 	ptrinfo = (INFO_APE *)g_malloc0 (sizeof (INFO_APE));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-
-	ptrinfo->namefile = g_strdup (namefile);
 	
 	ptrinfo->SecTime  = ShnTag->SecTime;
 	ptrinfo->time     = g_strdup (ShnTag->time);
@@ -162,7 +134,7 @@ INFO_APE *tagsape_get_info (gchar *namefile)
 	tags_set (namefile, ptrinfo->tags);
 	*/
 	
-	ShnTag = get_free_shntool (ShnTag);
+	ShnTag = GetInfo_free_shntool (ShnTag);
 	
 	return (ptrinfo);
 }
