@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,11 +50,14 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
 
 
 
@@ -69,8 +79,6 @@ $ file *
 INFO_DTS *tagsdts_remove_info (INFO_DTS *info)
 {
 	if (info) {
-		g_free (info->namefile);
-
 		info->tags = (TAGS *)tags_remove (info->tags);
 
 		g_free (info);
@@ -84,17 +92,15 @@ INFO_DTS *tagsdts_remove_info (INFO_DTS *info)
 * GET HEADER
 *---------------------------------------------------------------------------
 */
-INFO_DTS *tagsdts_get_info (gchar *namefile)
+INFO_DTS *tagsdts_get_info (DETAIL *detail)
 {
 	INFO_DTS     *ptrinfo = NULL;
 
 	ptrinfo = (INFO_DTS *)g_malloc0 (sizeof (INFO_DTS));
 	if (ptrinfo == NULL) return (NULL);
 
-	ptrinfo->namefile = g_strdup (namefile);
-
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-	tags_set (namefile, ptrinfo->tags);
+	tags_set (detail->namefile, ptrinfo->tags);
 
 	return ((INFO_DTS *)ptrinfo);
 }
