@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,8 +50,12 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "get.h"
+#include "get_info.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
@@ -58,9 +69,8 @@
 INFO_M4A *tagsm4a_remove_info (INFO_M4A *info)
 {
 	if (info) {
-		g_free (info->namefile);
-		g_free (info->time);
-		g_free (info->hertz);
+		if (NULL != info->time)		{ g_free (info->time); info->time = NULL;	}
+		if (NULL != info->hertz)	{ g_free (info->hertz);info->hertz = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -75,7 +85,7 @@ INFO_M4A *tagsm4a_remove_info (INFO_M4A *info)
 * GET INFO
 *---------------------------------------------------------------------------
 */
-INFO_M4A *tagsm4a_get_info (DETAIL *detail, gchar *namefile)
+INFO_M4A *tagsm4a_get_info (DETAIL *detail)
 {
 	gchar      **Larrbuf = NULL;
 	GString      *gstr = NULL;
@@ -83,7 +93,7 @@ INFO_M4A *tagsm4a_get_info (DETAIL *detail, gchar *namefile)
 	gchar        *ptr = NULL;
 	INFO_M4A     *ptrinfo = NULL;
 
-	gstr = get_with_faad (namefile);
+	gstr = GetInfo_faad (detail->namefile);
 	Larrbuf = g_strsplit (gstr->str, "\n", 0);
 
 	ptrinfo = (INFO_M4A *)g_malloc0 (sizeof (INFO_M4A));
@@ -92,7 +102,6 @@ INFO_M4A *tagsm4a_get_info (DETAIL *detail, gchar *namefile)
 		g_string_free (gstr, TRUE);
 		return (NULL);
 	}
-	ptrinfo->namefile = g_strdup (namefile);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 
 	for (cpt=0; Larrbuf[cpt]; cpt++) {
@@ -109,13 +118,13 @@ INFO_M4A *tagsm4a_get_info (DETAIL *detail, gchar *namefile)
 			ptrinfo->SecTime = atoi (ptr);
 
 			if (detail != NULL) {
-				detail->ValuePlay.SecTime = ptrinfo->SecTime;
+				// detail->ValuePlay.SecTime = ptrinfo->SecTime;
 			}
 
 			ptrinfo->ValueMark.SecTime    = atoi (ptr);
-			ptrinfo->ValueMark.ValueMarkA = 0.0;
-			ptrinfo->ValueMark.ValueMarkB = 100.0;
-			ptrinfo->ValueMark.Value = 0.0;
+			// ptrinfo->ValueMark.ValueMarkA = 0.0;
+			// ptrinfo->ValueMark.ValueMarkB = 100.0;
+			// ptrinfo->ValueMark.Value = 0.0;
 			
 			/* --> 44100 Hz */
 			ptr = strstr (ptr, " Hz");
@@ -166,7 +175,7 @@ INFO_M4A *tagsm4a_get_info (DETAIL *detail, gchar *namefile)
 	g_strfreev(Larrbuf);
 	g_string_free (gstr, TRUE);
 
-	tags_set (namefile, ptrinfo->tags);
+	tags_set (detail->namefile, ptrinfo->tags);
 
 	return ((INFO_M4A *)ptrinfo);
 }
