@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,13 +50,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
-#include "level.h"
-#include "utils.h"
+#include "get_info.h"
 
 
 /*
@@ -70,57 +79,6 @@ typedef struct  {
 	unsigned char	style;
 } ID3TAG;
 
-/*
-*---------------------------------------------------------------------------
-* FILE IS MP3 ?
-*---------------------------------------------------------------------------
-*/
-gboolean tagsmp3_file_is_mp3 (gchar *namefile)
-{
-	FILE    *fp = NULL;
-	gchar   *buf = NULL;
-	ID3TAG   begin;
-	ID3TAG   end;
-	gboolean bool = FALSE;
-	gint     i;
-	size_t   size;
-	size_t   Dummy;
-
-	/*PRINT_FUNC_LF();*/
-
-	fp = fopen (namefile, "rb");
-	if (!fp) return (FALSE);
-
-	Dummy = fread ( &begin, 128, 1, fp );
-	fseek ( fp, 0, SEEK_END );
-	fseek ( fp, ftell( fp ) - 128, SEEK_SET );
-	Dummy = fread ( &end, 128, 1, fp );
-	fclose (fp);
-
-	if (begin.magic[0] == 'I' && begin.magic[1] == 'D' && begin.magic[2] == '3') return (TRUE);
-	if (end.magic[0] == 'T' && end.magic[1] == 'A' && end.magic[2] == 'G') return (TRUE);
-	
-	size = infosong_get_size_file (namefile);
-	buf = g_malloc0 (sizeof (gchar) * (size + 10));
-	if ((fp = fopen (namefile, "rb"))) {
-		Dummy = fread (buf, 1, size, fp);
-		fclose (fp);
-		for (i = 0; i < size; i ++) {
-			if (buf[i+0] == 'L' && buf[i+1] == 'A' && buf[i+2] == 'M' && buf[i+3] == 'E') {
-				bool = TRUE;
-				break;
-			}
-		}
-	}
-	else {
-		PRINT_FUNC_LF();
-		g_print ("------ERREUR DE LECTURE DE: %s\n", namefile);
-	}
-	g_free (buf);
-	buf = NULL;
-
-	return (bool);
-}
 
 /*
 *---------------------------------------------------------------------------
@@ -129,11 +87,10 @@ gboolean tagsmp3_file_is_mp3 (gchar *namefile)
 */
 INFO_MP3 *tagsmp3_remove_info (INFO_MP3 *info)
 {
-	if (info) {
-		g_free (info->namefile);
-		g_free (info->bitrate);
-		g_free (info->time);
-		g_free (info->size);
+	if (NULL != info) {
+		if (NULL != info->bitrate)	{ g_free (info->bitrate);	info->bitrate = NULL;	}
+		if (NULL != info->time)		{ g_free (info->time);		info->time = NULL;	}
+		if (NULL != info->size)		{ g_free (info->size);		info->size = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -162,27 +119,27 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 	gchar        *Lout = NULL;
 	gchar        *ptr = NULL;
 #define MAX_STR 256
-	static gchar  str [ MAX_STR + 4];
+	static gchar  str [ MAX_STR + 4 ];
 	gint          cpt = 0;
 	gchar        *term[] = {"MPV_1", "MPV_2", "MPV_25"};
 	gint          i;
 	GString      *gstr = NULL;
-	gint          Ret = -1;
+	gint          Ret = NONE_MPEG;	// NONE_MPEG = -1
 
-	gstr = get_with_checkmp3 (namefile);
+	gstr = GetInfo_checkmp3 (namefile);
 	Lout = gstr->str;
-//g_print("lout=%s\n",Lout);
 	for (i = 0; i < 3; i ++) {
 		if ((ptr = strstr (Lout, term[ i ]))) {
+			
 			/* Init la chaine de stockage */
 			for (cpt=0; cpt < MAX_STR; cpt++) str [ cpt ] = '\0';
-			cpt = 0;
 
 			/* Passe l'intro */
 			while (*ptr != ' ') ptr ++;
 			while (*ptr == ' ') ptr ++;
 
 			/* Copie */
+			cpt = 0;
 			while (*ptr != '\n') {
 				if (cpt > MAX_STR) break;
 				str [ cpt ++ ] = *ptr ++;
@@ -192,15 +149,15 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 			switch ( i ) {
 			case 0 :
 				// g_print ("----------------------------MPV_1  str=%s\n", str);
-				if (str[0] == '1') Ret = 0;
+				if (str[0] == '1') Ret = MPEG_1;	// MPEG_1 = 0
 				break;
 			case 1 :
 				// g_print ("----------------------------MPV_2  str=%s\n", str);
-				if (str[0] == '1') Ret = 1;
+				if (str[0] == '1') Ret = MPEG_2;	// MPEG_2 = 1
 				break;
 			case 2 :
 				// g_print ("----------------------------MPV_25 str=%s\n", str);
-				if (str[0] == '1') Ret = 2;
+				if (str[0] == '1') Ret =  MPEG_25;	// MPEG_25 = 2
 				break;
 			}
 			if (Ret > -1) break;
@@ -208,11 +165,11 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 	}
 	g_string_free (gstr, TRUE);
 	Lout = NULL;
-
+	
 	return (Ret);
 }
 
-INFO_MP3 *tagsmp3_get_info (DETAIL *detail, gchar *namefile)
+INFO_MP3 *tagsmp3_get_info (DETAIL *detail)
 {
 	INFO_MP3     *ptrinfo = NULL;
 	TagLib_File  *file;
@@ -227,55 +184,54 @@ INFO_MP3 *tagsmp3_get_info (DETAIL *detail, gchar *namefile)
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 	
-	if ((file = taglib_file_new (namefile))) {
+	if ((file = taglib_file_new (detail->namefile))) {
 	
 		taglib_set_strings_unicode(FALSE);
 		tag = taglib_file_tag(file);
 		properties = taglib_file_audioproperties(file);
 		
-		/*ptrinfo->tags->Title     = g_strdup (utils_convert_string (taglib_tag_title(tag), TRUE));*/
-		ptrinfo->tags->Title     = utils_convert_string (taglib_tag_title(tag), TRUE);
+		ptrinfo->tags->Title     = g_strdup (taglib_tag_title(tag));
+		// ptrinfo->tags->Title     = utils_convert_string (taglib_tag_title(tag), TRUE);
 		
 		
-		/*ptrinfo->tags->Artist    = g_strdup (utils_convert_string (taglib_tag_artist(tag), TRUE));*/
-		ptrinfo->tags->Artist    = utils_convert_string (taglib_tag_artist(tag), TRUE);
+		ptrinfo->tags->Artist    = g_strdup (taglib_tag_artist(tag));
+		// ptrinfo->tags->Artist    = utils_convert_string (taglib_tag_artist(tag), TRUE);
 		
 		
-		/*ptrinfo->tags->Album     = g_strdup (utils_convert_string (taglib_tag_album(tag), TRUE));*/
-		ptrinfo->tags->Album     = utils_convert_string (taglib_tag_album(tag), TRUE);
+		ptrinfo->tags->Album     = g_strdup (taglib_tag_album(tag));
+		// ptrinfo->tags->Album     = utils_convert_string (taglib_tag_album(tag), TRUE);
 		
 		
 		ptrinfo->tags->IntYear   = taglib_tag_year(tag);
 		ptrinfo->tags->Year      = g_strdup_printf ("%d", ptrinfo->tags->IntYear);
-		/*ptrinfo->tags->Comment   = g_strdup (utils_convert_string (taglib_tag_comment(tag), TRUE));*/
-		ptrinfo->tags->Comment   = utils_convert_string (taglib_tag_comment(tag), TRUE);
+		ptrinfo->tags->Comment   = g_strdup (taglib_tag_comment(tag));
+		// ptrinfo->tags->Comment   = utils_convert_string (taglib_tag_comment(tag), TRUE);
 		
 		ptrinfo->tags->IntNumber = taglib_tag_track(tag);
 		ptrinfo->tags->Number    = g_strdup_printf ("%d", ptrinfo->tags->IntNumber);
-		/*ptrinfo->tags->Genre     = g_strdup (utils_convert_string (taglib_tag_genre(tag), TRUE));*/
-		ptrinfo->tags->Genre     = utils_convert_string (taglib_tag_genre(tag), TRUE);
+		ptrinfo->tags->Genre     = g_strdup (taglib_tag_genre(tag));
+		// ptrinfo->tags->Genre     = utils_convert_string (taglib_tag_genre(tag), TRUE);
 		
 		
-		ptrinfo->tags->IntGenre  = infosong_get_genre_by_value (ptrinfo->tags->Genre);
+		ptrinfo->tags->IntGenre  = tags_get_genre_by_value (ptrinfo->tags->Genre);
 
 		seconds = taglib_audioproperties_length(properties) % 60;
 		minutes = (taglib_audioproperties_length(properties) - seconds) / 60;
 		ptrinfo->SecTime =  taglib_audioproperties_length(properties);
 
 		if (detail != NULL) {
-			detail->ValuePlay.SecTime = ptrinfo->SecTime;
+			// detail->ValuePlay.SecTime = ptrinfo->SecTime;
 		}
 
 		ptrinfo->ValueMark.SecTime    = taglib_audioproperties_length(properties);
-		ptrinfo->ValueMark.ValueMarkA = 0.0;
-		ptrinfo->ValueMark.ValueMarkB = 100.0;
-		ptrinfo->ValueMark.Value = 0.0;
+		// ptrinfo->ValueMark.ValueMarkA = 0.0;
+		// ptrinfo->ValueMark.ValueMarkB = 100.0;
+		// ptrinfo->ValueMark.Value = 0.0;
 
-		ptrinfo->namefile = g_strdup (namefile);
 		ptrinfo->time     = g_strdup_printf ("%02d:%02d", minutes, seconds);
 		ptrinfo->bitrate  = g_strdup_printf ("%d", taglib_audioproperties_bitrate(properties));
-		ptrinfo->mpeg_is  = tagsmp3_type_mpeg (namefile);
-		ptrinfo->size     = g_strdup_printf ("%d Ko", (gint)infosong_get_size_file (namefile) / 1024);
+		ptrinfo->mpeg_is  = tagsmp3_type_mpeg (detail->namefile);
+		ptrinfo->size     = g_strdup_printf ("%d Ko", (gint)libutils_get_size_file (detail->namefile) / 1024);
 			
 		taglib_tag_free_strings();
 		taglib_file_free (file);
