@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,6 +50,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
@@ -185,37 +196,6 @@ void tagsmpc_print_entete_mpc (gchar *namefile, MPC_HEADER *fm)
 	g_print ("\n");
 }
 
-gboolean tagsmpc_file_is_mpc (gchar *namefile)
-{
-	FILE        *fp = NULL;
-	size_t       lenread = 0;
-	gchar       *buf = NULL;
-	gint         cpt;
-	gboolean     bool_signature = FALSE;
-	
-	/*PRINT_FUNC_LF();*/
-
-	buf = (gchar *)g_malloc0 (sizeof(gchar) * 1034);
-	if((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (buf, 1, 1024, fp);
-		fclose (fp);
-	}
-	
-	for (cpt = 0; cpt < 1024; cpt ++) {
-		if (
-		    buf [ cpt + 0 ] == 0x4d &&	// M
-		    buf [ cpt + 1 ] == 0x50 &&	// P
-		    buf [ cpt + 2 ] == 0x2b	// +
-		    ) {
-		    bool_signature = TRUE;
-		    break;
-		}
-	}
-	g_free (buf);
-	buf = NULL;
-	
-	return (bool_signature);
-}
 
 /*
 *---------------------------------------------------------------------------
@@ -226,7 +206,6 @@ gboolean tagsmpc_file_is_mpc (gchar *namefile)
 INFO_MPC *tagsmpc_remove_info (INFO_MPC *info)
 {
 	if (info) {
-		g_free (info->namefile);
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -236,7 +215,7 @@ INFO_MPC *tagsmpc_remove_info (INFO_MPC *info)
 	return ((INFO_MPC *)NULL);
 }
 
-INFO_MPC *tagsmpc_get_info (gchar *namefile)
+INFO_MPC *tagsmpc_get_info (DETAIL *detail)
 {
 	INFO_MPC     *ptrinfo = NULL;
 	TagLib_File  *file;
@@ -246,7 +225,7 @@ INFO_MPC *tagsmpc_get_info (gchar *namefile)
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 	
-	if ((file = taglib_file_new (namefile))) {
+	if ((file = taglib_file_new (detail->namefile))) {
 	
 		taglib_set_strings_unicode(FALSE);
 		tag = taglib_file_tag(file);
@@ -260,7 +239,7 @@ INFO_MPC *tagsmpc_get_info (gchar *namefile)
 		ptrinfo->tags->IntNumber = taglib_tag_track(tag);
 		ptrinfo->tags->Number    = g_strdup_printf ("%d", ptrinfo->tags->IntNumber);
 		ptrinfo->tags->Genre     = g_strdup (taglib_tag_genre(tag));
-		ptrinfo->tags->IntGenre  = infosong_get_genre_by_value (ptrinfo->tags->Genre);
+		ptrinfo->tags->IntGenre  = tags_get_genre_by_value (ptrinfo->tags->Genre);
 		/*
 		printf("title   - \"%s\"\n", taglib_tag_title(tag));
 		printf("artist  - \"%s\"\n", taglib_tag_artist(tag));
@@ -274,9 +253,8 @@ INFO_MPC *tagsmpc_get_info (gchar *namefile)
 		taglib_file_free (file);
 	}
 	else {
-		ptrinfo->namefile = g_strdup (namefile);
 		ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-		tags_set (namefile, ptrinfo->tags);
+		tags_set (detail->namefile, ptrinfo->tags);
 	}
 	
 	return (ptrinfo);
