@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,34 +50,18 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
+#include "get_info.h"
 
 
 
-/*
-*---------------------------------------------------------------------------
-* FILE IS SHN ?
-*---------------------------------------------------------------------------
-*/
-gboolean tagsshn_file_is_shn (gchar *namefile)
-{
-	FILE      *fp = NULL;
-	gchar      str [ 8 ] = {'\0','\0','\0','\0','\0','\0','\0','\0'};
-	size_t     lenread = 0;
-
-	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (&str[0], 1, 4, fp);
-		fclose (fp);
-	}
-
-	if (str [0] == 'a' && str [1] == 'j' && str [2] == 'k' && str [3] == 'g') return (TRUE);
-
-	return (FALSE);
-}
 
 
 /*
@@ -81,9 +72,8 @@ gboolean tagsshn_file_is_shn (gchar *namefile)
 INFO_SHN *tagsshn_remove_info (INFO_SHN *info)
 {
 	if (info) {
-		g_free (info->namefile);
-		g_free (info->time);
-		g_free (info->size);
+		if (NULL != info->time)		{ g_free (info->time); info->time = NULL;	}
+		if (NULL != info->size)		{ g_free (info->size);info->size = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -99,22 +89,20 @@ INFO_SHN *tagsshn_remove_info (INFO_SHN *info)
 * GET HEADER
 *---------------------------------------------------------------------------
 */
-INFO_SHN *tagsshn_get_info (gchar *namefile)
+INFO_SHN *tagsshn_get_info (DETAIL *detail)
 {
 	INFO_SHN	*ptrinfo = NULL;
-	SHNTAG		*ShnTag = get_with_shntool (namefile);
+	SHNTAG		*ShnTag = GetInfo_shntool (detail->namefile);
 
 	ptrinfo = (INFO_SHN *)g_malloc0 (sizeof (INFO_SHN));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 
-	ptrinfo->namefile = g_strdup (namefile);
-	
 	ptrinfo->SecTime  = ShnTag->SecTime;
 	ptrinfo->time     = g_strdup (ShnTag->time);
 	ptrinfo->size     = g_strdup (ShnTag->size);
 	
-	ShnTag = get_free_shntool (ShnTag);
+	ShnTag = GetInfo_free_shntool (ShnTag);
 	
 	return ((INFO_SHN *)ptrinfo);
 }
