@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,11 +50,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
-#include "get.h"
+#include "get_info.h"
 
 
 /*
@@ -87,38 +98,6 @@ typedef struct {
 } TAGS_WAVPACK;
 */
 
-/*
-*---------------------------------------------------------------------------
-* FILE IS WAVPACK ?
-*---------------------------------------------------------------------------
-*/
-
-gboolean tagswavpack_file_is_wavpack (gchar *namefile)
-{
-	FILE      *fp = NULL;
-	gchar      str [ 42 ] = {'\0','\0','\0','\0','\0','\0','\0','\0'};
-	size_t     lenread = 0;
-
-	if ((fp = fopen (namefile, "rb")) != NULL) {
-		lenread = fread (&str[0], 1, 40, fp);
-		fclose (fp);
-	}
-
-	if (str [0]  == 'w' &&
-	    str [1]  == 'v' &&
-	    str [2]  == 'p' &&
-	    str [3]  == 'k' &&
-	    
-	    str [34] == 'R' &&
-	    str [35] == 'I' &&
-	    str [36] == 'F' &&
-	    str [37] == 'F') return (TRUE);
-
-	PRINT_FUNC_LF();
-	g_print ("\tNO WAVPACK FILE: %s\n", namefile);
-
-	return (FALSE);
-}
 
 /*
 *---------------------------------------------------------------------------
@@ -126,72 +105,12 @@ gboolean tagswavpack_file_is_wavpack (gchar *namefile)
 *---------------------------------------------------------------------------
 */
 
-/*
-void infosong_id3_readtag_wavpack (gchar *namefile)
-{
-	FILE          *fp = NULL;
-	gchar         *buf = NULL;
-	gint           ind = 0;
-	TAGS_WAVPACK   tw;
-
-	buf = (gchar *)g_malloc0 (sizeof (gchar) * 1500);
-	if (buf == NULL) {
-		return;
-	}
-	g_print ("OUVERTURE DE: %s\n", namefile);
-	fp = fopen (namefile, "rb");
-	if (!fp) return;
-
-	fseek (fp, 0, SEEK_END);
-	fseek (fp, ftell( fp ) - 1000, SEEK_SET);
-	fread (buf, 1, 1000, fp);
-	fclose (fp);
-	g_print ("FERMETURE DE: %s\n", namefile);
-
-	ind = 0;
-	while (ind < 1000) {
-		if (buf [ ind+0 ] == 'A' &&
-		    buf [ ind+1 ] == 'P' &&
-		    buf [ ind+2 ] == 'E' &&
-		    buf [ ind+3 ] == 'T' &&
-		    buf [ ind+4 ] == 'A' &&
-		    buf [ ind+5 ] == 'G' &&
-		    buf [ ind+6 ] == 'E' &&
-		    buf [ ind+7 ] == 'X') {
-
-		    	g_print ("TAGS WAVPACK TROUVES\n");
-			g_memmove (&tw,  &buf [ ind+12 ], 128);
-			ind = -1;
-			break;
-		}
-		ind ++;
-	}
-	if (ind > -1) {
-		g_print ("PAS DE TAGS WAVPACK\n");
-		g_free (buf);
-		buf = NULL;
-		return;
-	}
-
-	g_print ("tw.id [ 3 ]          = %s\n", tw.id);
-	g_print ("tw.title [ 30 ]      = %s\n", tw.title);
-	g_print ("tw.interprete [ 30 ] = %s\n", tw.interprete);
-	g_print ("tw.album [ 30 ]      = %s\n", tw.album);
-	g_print ("tw.annee [ 4 ]       = %s\n", tw.annee);
-	g_print ("tw.comment [ 30 ]    = %s\n", tw.comment);
-	g_print ("tw.genre [ 1 ]       = %s\n", tw.genre);
-
-	g_free (buf);
-	buf = NULL;
-}
-*/
 
 INFO_WAVPACK *tagswavpack_remove_info (INFO_WAVPACK *info)
 {
 	if (info) {
-		g_free (info->namefile);
-		g_free (info->time);
-		g_free (info->size);
+		if (NULL != info->time)		{ g_free (info->time);		info->time = NULL;	}
+		if (NULL != info->size)		{ g_free (info->size);		info->size = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -201,33 +120,29 @@ INFO_WAVPACK *tagswavpack_remove_info (INFO_WAVPACK *info)
 	return ((INFO_WAVPACK *)NULL);
 }
 
-INFO_WAVPACK *tagswavpack_get_info (DETAIL *detail, gchar *namefile)
+INFO_WAVPACK *tagswavpack_get_info (DETAIL *detail)
 {
 	INFO_WAVPACK	*ptrinfo = NULL;
-	SHNTAG		*ShnTag = get_with_shntool (namefile);
+	SHNTAG		*ShnTag = GetInfo_shntool (detail->namefile);
 
 	ptrinfo = (INFO_WAVPACK *)g_malloc0 (sizeof (INFO_WAVPACK));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 
-	ptrinfo->namefile = g_strdup (namefile);
-	
 	ptrinfo->SecTime  = ShnTag->SecTime;
 	ptrinfo->time     = g_strdup (ShnTag->time);
 	ptrinfo->size     = g_strdup (ShnTag->size);
 
 	if (detail != NULL) {
-		detail->ValuePlay.SecTime = ptrinfo->SecTime;
+		// detail->ValuePlay.SecTime = ptrinfo->SecTime;
 	}
 	
 	ptrinfo->ValueMark.SecTime    = ptrinfo->SecTime;
-	ptrinfo->ValueMark.ValueMarkA = 0.0;
-	ptrinfo->ValueMark.ValueMarkB = 100.0;
-	ptrinfo->ValueMark.Value = 0.0;
+	// ptrinfo->ValueMark.ValueMarkA = 0.0;
+	// ptrinfo->ValueMark.ValueMarkB = 100.0;
+	// ptrinfo->ValueMark.Value = 0.0;
 	
-	/*infosong_id3_readtag_wavpack (namefile);*/
-
-	ShnTag = get_free_shntool (ShnTag);
+	ShnTag = GetInfo_free_shntool (ShnTag);
 	
 	return (ptrinfo);
 }
