@@ -29,12 +29,19 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  * 
  */
+ 
+ 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
 
-
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-
 #include <pthread.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -43,6 +50,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
 #include "file.h"
 #include "tags.h"
@@ -72,7 +83,6 @@
 INFO_WMA *tagswma_remove_info (INFO_WMA *info)
 {
 	if (info) {
-		g_free (info->namefile);
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
@@ -88,18 +98,15 @@ INFO_WMA *tagswma_remove_info (INFO_WMA *info)
 * GET HEADER
 *---------------------------------------------------------------------------
 */
-INFO_WMA *tagswma_get_info (gchar *namefile)
+INFO_WMA *tagswma_get_info (DETAIL *detail)
 {
 	INFO_WMA     *ptrinfo = NULL;
 
 	ptrinfo = (INFO_WMA *)g_malloc0 (sizeof (INFO_WMA));
 	if (ptrinfo == NULL) return (NULL);
 
-	ptrinfo->namefile = g_strdup (namefile);
-
-	/*ptrinfo->tag = info_tag_get (FILE_IS_WMA, namefile);*/
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-	tags_set (namefile, ptrinfo->tags);
+	tags_set (detail->namefile, ptrinfo->tags);
 
 	return ((INFO_WMA *)ptrinfo);
 }
