@@ -27,18 +27,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
+#ifndef web_h
+#define web_h 1
 
-#ifndef __web_h__
-#define __web_h__ 1
-
-
-void web_goto_xcfa_page (gchar *str_web);
-void web_goto_manpage (gchar *PathManPage);
 void web_remove_temporary_rep (void);
-
+void web_goto_url (gchar *str_web);
 
 #endif
 
