@@ -1,11 +1,11 @@
  /*
  * file      : win_info.c
- * project   : xcfa
+ * project   : BaseBuild
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2010 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
+ * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,19 +31,33 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+	#include <config.h>
+#endif
+
+#ifdef ENABLE_NLS
+	#include <libintl.h>
+	#define _(String) gettext (String)
+#endif
+
+
 #include <gtk/gtk.h>
 #include <string.h>
 
+#ifdef ENABLE_STATIC_LIBRARY
+	#include "../lib/lib.h"
+#endif
+
 #include "global.h"
-#include "win_control.h"
-#include "utils.h"
 #include "win_info.h"
 
+
 /*
 *---------------------------------------------------------------------------
 * VARIABLES
 *---------------------------------------------------------------------------
 */
+/*
 
 typedef struct {
 
@@ -55,42 +69,34 @@ typedef struct {
 WININFO wininfo;
 
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
-
+// QUIT WITH delete_event
+// 
 gboolean wininfo_on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	GtkWidget *AdrWin = GTK_WIDGET(user_data);
 	
-	// PRINT_FUNC_LF();
-	// gtk_widget_destroy (wincontrol_get_last_adr ());
 	gtk_widget_destroy (AdrWin);
-	wincontrol_remove_last ();
 	return FALSE;
 }
+// QUIT WITH destroy_event
+// 
 gboolean wininfo_on_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	GtkWidget *AdrWin = GTK_WIDGET(user_data);
 	
-	// PRINT_FUNC_LF();
-	// gtk_widget_destroy (wincontrol_get_last_adr ());
 	gtk_widget_destroy (AdrWin);
-	wincontrol_remove_last ();
 	return FALSE;
 }
+// QUIT WITH button
+//
 void wininfo_on_ok_button_clicked (GtkButton *button, gpointer user_data)
 {
 	GtkWidget *AdrWin = GTK_WIDGET(user_data);
 	
-	// PRINT_FUNC_LF();
-	// gtk_widget_destroy (wincontrol_get_last_adr ());
 	gtk_widget_destroy (AdrWin);
-	wincontrol_remove_last ();
 }
-
+// CREATION DE LA FENETRE
+// 
 void wininfo_create_window (void)
 {
 	GtkWidget *dialog;
@@ -99,21 +105,14 @@ void wininfo_create_window (void)
 	GtkWidget *label_text;
 	GtkWidget *dialog_action_area1;
 	GtkWidget *ok_button;
-	/*GtkWidget *ok_cancel;*/
 
-	/* PRINT_FUNC_LF(); */
+	// PRINT_FUNC_LF();
 
 	dialog = gtk_dialog_new ();
 
-	wincontrol_set_adr (
-		dialog,			/* Window adress                */
-		"wininfo_create",	/* Window name			*/
-		TRUE,			/* gtk_window_set_transient_for */
-		TRUE			/* gtk_window_set_modal         */
-		);
-
 	gtk_window_set_title (GTK_WINDOW (dialog), wininfo.title);
-	/*gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);*/
+	gtk_window_set_transient_for (GTK_WINDOW(WindMain), GTK_WINDOW(dialog));
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
@@ -124,7 +123,6 @@ void wininfo_create_window (void)
 	gtk_widget_show (vbox1);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox1), vbox1, TRUE, TRUE, 0);
 
-	/*label_text = gtk_label_new (wininfo.text->str);*/
 	label_text = gtk_label_new (NULL);
 	gtk_label_set_use_markup (GTK_LABEL (label_text), TRUE);
 	gtk_label_set_markup (GTK_LABEL (label_text), wininfo.text->str);
@@ -134,10 +132,6 @@ void wininfo_create_window (void)
 	dialog_action_area1 = GTK_DIALOG (dialog)->action_area;
 	gtk_widget_show (dialog_action_area1);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_SPREAD);
-
-	/*ok_cancel = gtk_button_new_from_stock ("gtk-cancel");
-	gtk_widget_show (ok_cancel);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), ok_cancel, 0);*/
 	
 	ok_button = gtk_button_new_from_stock ("gtk-ok");
 	gtk_widget_show (ok_button);
@@ -155,8 +149,8 @@ void wininfo_create_window (void)
 			G_CALLBACK (wininfo_on_ok_button_clicked),
 			(gpointer)dialog);
 
-	/* Store pointers to all widgets, for use by lookup_widget().
-	*/
+	// Store pointers to all widgets, for use by lookup_widget().
+
 	GLADE_HOOKUP_OBJECT_NO_REF (dialog, dialog, "dialog");
 	GLADE_HOOKUP_OBJECT_NO_REF (dialog, dialog_vbox1, "dialog_vbox1");
 	GLADE_HOOKUP_OBJECT (dialog, vbox1, "vbox1");
@@ -164,40 +158,96 @@ void wininfo_create_window (void)
 	GLADE_HOOKUP_OBJECT_NO_REF (dialog, dialog_action_area1, "dialog_action_area1");
 	// GLADE_HOOKUP_OBJECT (dialog, ok_button, "ok_button");
 
-	utils_set_default_icone_xcfa (dialog);
+	libutils_set_default_icone_to_win (dialog);
+	
 	gtk_widget_show (dialog);
 }
-
+// DEMANDE DE CREATION DE LA FENETRE
+// 
 void wininfo_create (gchar *title, ...)
 {
 	va_list    Arguments;
 	gchar     *PtrArg = NULL;
 	
-	// PRINT_FUNC_LF();
-
-	wininfo.title = g_strdup (title);				/* Stokage du titre		*/
-	wininfo.text  = g_string_new (NULL);				/* Creation du GString		*/
+	wininfo.title = g_strdup (title);				// Stokage du titre
+	wininfo.text  = g_string_new (NULL);				//  Creation du GString
 	
-	g_string_sprintfa (wininfo.text, "\n<b>   %s</b>\n\n", title);	/* Titre -> en-tete en gras	*/
+	g_string_sprintfa (wininfo.text, "\n<b>   %s</b>\n\n", title);	//  Titre -> en-tete en gras
 	
-	va_start (Arguments, title);					/* Debut des arguments		*/
-	while ( *(PtrArg = va_arg (Arguments, gchar *)) != '\0') {	/* TANSQUE message ALORS	*/
-		g_string_sprintfa (wininfo.text, "%s", &PtrArg[0]);	/* 	message.stock		*/
-	}								/* FIN_TANSQUE			*/
-	va_end (Arguments);						/* Fin des arguments		*/
+	va_start (Arguments, title);					//  Debut des arguments
+	while ( *(PtrArg = va_arg (Arguments, gchar *)) != '\0') {	//  TANSQUE message ALORS
+		g_string_sprintfa (wininfo.text, "%s", &PtrArg[0]);	//  	message.stock
+	}								//  FIN_TANSQUE
+	va_end (Arguments);						//  Fin des arguments
 	
-	wininfo_create_window ();					/* Creation fenetre		*/
+	wininfo_create_window ();					//  Creation fenetre
 	
-	/*
-	g_print ("%s\n",  wininfo.title);
-	g_print ("%s", wininfo.text->str);
-	*/
-	
-	g_free (wininfo.title);						/* Suppression des informations	*/
-	wininfo.title = NULL;						/* de la structure		*/
+	g_free (wininfo.title);						//  Suppression des informations
+	wininfo.title = NULL;						//  de la structure
 	g_string_free (wininfo.text, TRUE);
 	wininfo.text = NULL;
 }
+*/
+
+
+typedef struct {
+
+	GtkWidget	*AdrWin;
+	gboolean	IsShow;
+	
+} VAR_WININFO;
+
+VAR_WININFO	VarWinInfo = { NULL, FALSE };
+
+// QUITTER
+// 
+void on_button_quitter_wininfo_clicked (GtkButton *button, gpointer user_data)
+{
+	VarWinInfo.IsShow = FALSE;
+	gtk_widget_hide (VarWinInfo.AdrWin);
+}
+// WIN-READER OPEN
+// 
+void wininfo_create (gchar *title, ...)
+{
+	gchar		*StrTitle = NULL;
+	va_list		Arguments;
+	gchar		*PtrArg = NULL;
+	GString		*StrTxt = NULL;
+	
+	if (TRUE == VarWinInfo.IsShow) {
+		gdk_window_raise (VarWinInfo.AdrWin->window);
+	}
+	else {		
+		if (NULL == VarWinInfo.AdrWin) {
+			VarWinInfo.AdrWin = GTK_WIDGET (GLADE_GET_OBJECT("wind_info"));
+			gtk_builder_connect_signals (GtkXcfaProjet, NULL);
+		}
+		gtk_window_set_transient_for (GTK_WINDOW(VarWinInfo.AdrWin), GTK_WINDOW(WindMain));
+		gtk_window_set_modal (GTK_WINDOW (VarWinInfo.AdrWin), TRUE);
+		libutils_set_default_icone_to_win (VarWinInfo.AdrWin);
+		
+		StrTitle = g_strdup_printf ("\n          <span font_desc=\"Courier bold 14\"><b>%s</b></span>          \n", title);
+		gtk_label_set_markup (GTK_LABEL (GLADE_GET_OBJECT("label_titre_wininfo")), StrTitle);
+		g_free (StrTitle);	StrTitle = NULL;
+	
+		StrTxt = g_string_new (NULL);					//  Creation du GString
+		va_start (Arguments, title);					//  Debut des arguments
+		while ( *(PtrArg = va_arg (Arguments, gchar *)) != '\0') {	//  TANSQUE message ALORS
+			g_string_sprintfa (StrTxt, "%s", &PtrArg[0]);		//  	message.stock
+		}								//  FIN_TANSQUE
+		va_end (Arguments);						//  Fin des arguments
+		g_string_sprintfa (StrTxt, "\n\n");
+		
+		gtk_label_set_markup (GTK_LABEL (GLADE_GET_OBJECT("label_texte_wininfo")), StrTxt->str);
+		g_string_free (StrTxt, TRUE);
+		
+		gtk_window_set_title (GTK_WINDOW(VarWinInfo.AdrWin), title);
+		
+		gtk_widget_show (VarWinInfo.AdrWin);
+	}
+	VarWinInfo.IsShow = TRUE;
+}
 
 
 
@@ -208,5 +258,3 @@ void wininfo_create (gchar *title, ...)
 
 
 
-
-
