@@ -1,11 +1,11 @@
  /*
  * file      : win_info.h
- * project   : xcfa
+ * project   : BaseBuild
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2010 by Claude Bulin
+ * copyright : (C) 2010 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
+ * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,8 +31,8 @@
  */
 
 
-#ifndef __win_info_h__
-#define __win_info_h__ 1
+#ifndef win_info_h
+#define win_info_h 1
 
 
 void wininfo_create (gchar *title, ...);
